<?php
/*
 * Copyright (C) 2006 Tobias Toedter <t.toedter@gmx.net>
 *
 * This file is part of the Drupal Weather module.
 *
 * Weather is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Weather is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Weather; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */



function _weather_get_countries() {
  $icao_codes = _weather_setup_icao_codes();
  $result = array_keys($icao_codes);
  array_unshift($result, t('- None -'));
  return $result;
}



function _weather_get_places($country) {
  $icao_codes = _weather_setup_icao_codes();
  $result = array('- none -' => t('- None -'));
  return array_merge($result, $icao_codes[$country]);
}



function _weather_get_country_from_icao($wanted_icao) {
  $icao_codes = _weather_setup_icao_codes();
  $wanted_icao = strtoupper($wanted_icao);
  foreach ($icao_codes as $country => $data) {
    foreach ($data as $icao => $place) {
      if ($icao == $wanted_icao) {
        return $country;
      }
    }
  }
  # Add a safety fallback (country for EDDH)
  return 'Germany';
}



function _weather_setup_icao_codes() {
  $icao_codes['Afghanistan'] = array(
    'OAHR' => 'Herat',
    'OAKB' => 'Kabul Airport',
  );
  
  $icao_codes['Albania'] = array(
    'LATI' => 'Tirana',
  );
  
  $icao_codes['Algeria'] = array(
    'DAUA' => 'Adrar',
    'DABB' => 'Annaba',
    'DABT' => 'Batna',
    'DAOR' => 'Bechar',
    'DAAE' => 'Bejaia',
    'DAUB' => 'Biskra',
    'DAAD' => 'Bou-Saada',
    'DABC' => 'Constantine',
    'DAAG' => 'Dar-El-Beida',
    'DAAJ' => 'Djanet',
    'DAUE' => 'El Golea',
    'DAUO' => 'El Oued',
    'DAUG' => 'Ghardaia',
    'DAUH' => 'Hassi-Messaoud',
    'DAAP' => 'Illizi',
    'DAUZ' => 'In Amenas',
    'DAUI' => 'In Salah North',
    'DAAV' => 'Jijel Achouat',
    'DAUL' => 'Laghouat',
    'DAOV' => 'Mascara-Ghriss',
    'DAAY' => 'Mecheria',
    'DAOO' => 'Oran / Es Senia',
    'DAOL' => 'Oran/Tafaraoui',
    'DAUU' => 'Ouargla',
    'DAAS' => 'Setif',
    'DAAT' => 'Tamanrasset / Aguenna',
    'DABS' => 'Tebessa',
    'DAOB' => 'Tiaret',
    'DAFH' => 'Tilrempt/Hassi R\'mel',
    'DAUT' => 'Timimoun',
    'DAOF' => 'Tindouf',
    'DAON' => 'Tlemcen Zenata',
    'DAUK' => 'Touggourt',
  );
  
  $icao_codes['Angola'] = array(
    'FNHU' => 'Huambo Nova Lisboa',
    'FNLU' => 'Luanda',
    'FNBG' => 'Monbaca Benguela',
  );
  
  $icao_codes['Anguilla'] = array(
    'TQPF' => 'Wallblake',
  );
  
  $icao_codes['Antarctica'] = array(
    'NZSP' => 'Amundsen-Scott South Pole Station',
  );
  
  $icao_codes['Antigua and Barbuda'] = array(
    'TKPN' => 'Charlestown / Newcast',
    'TAPA' => 'Vc Bird International Airport Antigua',
  );
  
  $icao_codes['Argentina'] = array(
    'SABE' => 'Aeroparque Bs. As. Aerodrome',
    'SAZS' => 'Bariloche Aerodrome',
    'SAVC' => 'Comodoro Rivadavia Aerodrome',
    'SAAC' => 'Concordia Aerodrome',
    'SACO' => 'Cordoba Aerodrome',
    'SARC' => 'Corrientes Aero.',
    'SAEZ' => 'Ezeiza Aerodrome',
    'SARF' => 'Formosa Aerodrome',
    'SARI' => 'Iguazu Aerodrome',
    'SASJ' => 'Jujuy Aerodrome',
    'SAZM' => 'Mar Del Plata Aerodrome',
    'SAME' => 'Mendoza Aerodrome',
    'SARL' => 'Paso De Los Libres Aerodrome',
    'SARP' => 'Posadas Aero.',
    'SATR' => 'Reconquista, SF',
    'SARE' => 'Resistencia Aero.',
    'SAWG' => 'Rio Gallegos Aerodrome',
    'SAWE' => 'Rio Grande B. A.',
    'SAAR' => 'Rosario Aerodrome',
    'SASA' => 'Salta Aerodrome',
    'SAST' => 'Tartagal Aerodrome',
    'SAVT' => 'Trelew Aerodrome',
    'SANT' => 'Tucuman Aerodrome',
    'SAWH' => 'Ushuaia Aerodrome',
  );
  
  $icao_codes['Aruba'] = array(
    'TNCA' => 'Queen Beatrix Airport',
  );
  
  $icao_codes['Australia'] = array(
    'YPAD' => 'Adelaide Airport',
    'YBAS' => 'Alice Springs Aerodrome',
    'YMAV' => 'Avalon, Avalon Airport',
    'YAYE' => 'Ayers Rock',
    'YPPH' => 'Belmont Perth Airport',
    'YBBN' => 'Brisbane Airport M. O',
    'YBRM' => 'Broome Airport',
    'YPEA' => 'Bullsbrook Pearce Amo',
    'YBCS' => 'Cairns Airport',
    'YSCB' => 'Canberra',
    'YBCG' => 'Coolangatta Airport Aws',
    'YPDN' => 'Darwin Airport',
    'YSDU' => 'Dubbo',
    'YMHB' => 'Hobart Airport',
    'YPKG' => 'Kalgoorlie Boulder Amo',
    'YPKU' => 'Kununurra Kununurra Aws',
    'YMLT' => 'Launceston Airport',
    'YPLM' => 'Learmonth Airport',
    'YBMA' => 'Mount Isa Amo',
    'YSNF' => 'Norfolk Island Airport',
    'YPPD' => 'Port Hedland Pardoo',
    'YSRI' => 'Richmond Aus-Afb',
    'YBRK' => 'Rockhampton Airport',
    'YSSY' => 'Sydney Airport',
    'YSTW' => 'Tamworth Airport',
    'YPTN' => 'Tindal / Katherine',
    'YBTL' => 'Townsville Amo',
    'YSWG' => 'Wagga Airport',
  );
  
  $icao_codes['Austria'] = array(
    'LOXA' => 'Aigen Im Ennstal',
    'LOWG' => 'Graz-Thalerhof-Flughafen',
    'LOIH' => 'Hohenems-Dornbirn',
    'LOWI' => 'Innsbruck-Flughafen',
    'LOWK' => 'Klagenfurt-Flughafen',
    'LOAG' => 'Krems-Langenlois',
    'LOWL' => 'Linz / Hoersching-Flughafen',
    'LOAV' => 'Niederosterreich / Flugplatz Voslau',
    'LOAN' => 'Niederosterreich / Wiener Neustadt-Ost Flugplatz',
    'LOLF' => 'Oberosterreich / Freistadt Flugplatz',
    'LOGG' => 'Punitz-Gussing',
    'LOWS' => 'Salzburg-Flughafen',
    'LOXT' => 'Tulln',
    'LOWW' => 'Wien / Schwechat-Flughafen',
    'LOWZ' => 'Zell Am See',
    'LOXZ' => 'Zeltweg',
  );
  
  $icao_codes['Azerbaijan'] = array(
    'UBBB' => 'Baku / Bine Airport',
    'UBBG' => 'Gyanca Airport',
  );
  
  $icao_codes['Bahamas, The'] = array(
    'MYGF' => 'Freeport, Grand Bahama',
    'MYEG' => 'Georgetown, Exuma',
    'MYNN' => 'Nassau Airport',
  );
  
  $icao_codes['Bahrain'] = array(
    'OBBI' => 'Bahrain International Airport',
  );
  
  $icao_codes['Barbados'] = array(
    'TBPB' => 'Grantley Adams',
  );
  
  $icao_codes['Belarus'] = array(
    'UMBB' => 'Brest',
    'UMGG' => 'Gomel\'',
    'UMMG' => 'Grodno',
    'UMMM' => 'Loshitsa / Minsk International 1',
    'UMMS' => 'Minsk',
    'UMII' => 'Vitebsk',
  );
  
  $icao_codes['Belgium'] = array(
    'EBAW' => 'Antwerpen / Deurne',
    'EBLG' => 'Bierset',
    'EBBR' => 'Bruxelles National',
    'EBCI' => 'Charleroi / Gosselies',
    'EBLB' => 'Elsenborn',
    'EBOS' => 'Oostende Airport',
  );
  
  $icao_codes['Belize'] = array(
    'MZBZ' => 'Belize / Phillip Goldston Intl. Airport',
  );
  
  $icao_codes['Benin'] = array(
    'DBBB' => 'Cotonou',
  );
  
  $icao_codes['Bermuda'] = array(
    'TXKF' => 'Bermuda',
  );
  
  $icao_codes['Bolivia'] = array(
    'SLAS' => 'Ascencion De Guarayos',
    'SLCA' => 'Camiri',
    'SLCO' => 'Cobija',
    'SLCB' => 'Cochabamba',
    'SLCP' => 'Concepcion',
    'SLLP' => 'La Paz / Alto',
    'SLMG' => 'Magdalena',
    'SLOR' => 'Oruro',
    'SLPO' => 'Potosi',
    'SLPS' => 'Puerto Suarez',
    'SLRY' => 'Reyes',
    'SLRI' => 'Riberalta',
    'SLRB' => 'Robore',
    'SLRQ' => 'Rurrenabaque',
    'SLSI' => 'San Ignacio De Velasco',
    'SLJV' => 'San Javier',
    'SLJO' => 'San Joaquin',
    'SLJE' => 'San Jose De Chiquitos',
    'SLSA' => 'Santa Ana',
    'SLET' => 'Santa Cruz / El Trompillo',
    'SLSU' => 'Sucre',
    'SLTJ' => 'Tarija',
    'SLTR' => 'Trinidad',
    'SLVM' => 'Villamontes',
    'SLVR' => 'Viru-Viru',
    'SLYA' => 'Yacuiba',
  );
  
  $icao_codes['Bosnia and Herzegovina'] = array(
    'LQBK' => 'Banja Luka',
    'LQMO' => 'Mostar',
    'LQSA' => 'Sarajevo',
    'LQTZ' => 'Tuzla',
  );
  
  $icao_codes['Botswana'] = array(
    'FBFT' => 'Francistown',
    'FBGZ' => 'Ghanzi',
    'FBJW' => 'Jwaneng',
    'FBKE' => 'Kasane',
    'FBLT' => 'Letlhakane',
    'FBMN' => 'Maun',
    'FBSP' => 'Selebi Phikwe',
    'FBSK' => 'Seretse Khama International Airport',
    'FBSW' => 'Shakawe',
    'FBSN' => 'Sua-Pan',
    'FBTS' => 'Tsabong',
    'FBTE' => 'Tshane',
  );
  
  $icao_codes['Brazil'] = array(
    'SBBG' => 'Bage Aeroporto',
    'SBBE' => 'Belem Aeroporto',
    'SBCF' => 'Belo Horizonte',
    'SBBV' => 'Boa Vista, Boa Vista Intl',
    'SBBR' => 'Brasilia Aeroporto',
    'SBKP' => 'Campinas Aeroporto',
    'SBCG' => 'Campo Grande Aeroporto',
    'SBCJ' => 'Carajas / Maraba',
    'SBCR' => 'Corumba',
    'SBCZ' => 'Cruzeiro Do Sul',
    'SBCY' => 'Cuiaba Aeroporto',
    'SBCT' => 'Curitiba Aeroporto',
    'SBEG' => 'Eduardo Gomes International',
    'SBFN' => 'Fernando De Noronha',
    'SBFL' => 'Florianopolis Aeroporto',
    'SBFZ' => 'Fortaleza / pinto Martins',
    'SBFI' => 'Foz Do Iguacu Aeroporto',
    'SBGL' => 'Galeao',
    'SBGR' => 'Guarulhos Civ / Mil',
    'SBJP' => 'Joao Pessoa',
    'SBRP' => 'Leite Lopes / Ribeir',
    'SBLO' => 'Londrina Aeroporto',
    'SBMQ' => 'Macapa',
    'SBMO' => 'Maceio Aeroporto',
    'SBMA' => 'Maraba',
    'SBNT' => 'Natal Aeroporto',
    'SBPK' => 'Pelotas',
    'SBPP' => 'Ponta Pora Intl',
    'SBPA' => 'Porto Alegre Aero-Porto',
    'SBPV' => 'Porto Velho Aeroporto',
    'SBRF' => 'Recife Aeroporto',
    'SBRB' => 'Rio Branco',
    'SBRJ' => 'Rio De Janeiro Aeroporto',
    'SBSV' => 'Salvador Aeroporto',
    'SBSN' => 'Santarem-Aeroporto',
    'SBSJ' => 'Sao Jose Dos Campo',
    'SBSL' => 'Sao Luiz Aeroporto',
    'SBSP' => 'Sao Paulo/Congonhas Aeroporto',
    'SBTT' => 'Tabatinga',
    'SBTF' => 'Tefe',
    'SBTE' => 'Teresina Aeroporto',
    'SBUG' => 'Uruguaiana Aeroporto',
  );
  
  $icao_codes['British Indian Ocean Territory'] = array(
    'FJDG' => 'Diego Garcia',
  );
  
  $icao_codes['British Virgin Islands'] = array(
    'TUPJ' => 'Beef Island, Tortola',
    'TIST' => 'Charlotte Amalie St. Thomas, Cyril E. King Airport',
    'TISX' => 'Christiansted, Henry E. Rohlsen Airport',
  );
  
  $icao_codes['Brunei'] = array(
    'WBSB' => 'Brunei Airport',
  );
  
  $icao_codes['Bulgaria'] = array(
    'LBBG' => 'Burgas',
    'LBGO' => 'Gorna Orechovista',
    'LBPD' => 'Plovdiv',
    'LBSF' => 'Sofia Observ.',
    'LBWN' => 'Varna',
  );
  
  $icao_codes['Burkina Faso'] = array(
    'DFOO' => 'Bobo-Dioulasso',
    'DFFD' => 'Ouagadougou',
  );
  
  $icao_codes['Burundi'] = array(
    'HBBA' => 'Bujumbura',
  );
  
  $icao_codes['Cambodia'] = array(
    'VDPP' => 'Phnom-Penh / Pochentong',
    'VDSR' => 'Siemreap',
  );
  
  $icao_codes['Cameroon'] = array(
    'FKKD' => 'Douala Obs.',
    'FKKR' => 'Garoua',
    'FKKN' => 'Ngaoundere',
    'FKYS' => 'Yaounde',
  );
  
  $icao_codes['Canada'] = array(
    'CYXX' => 'Abbotsford, B. C.',
    'CYNC' => 'Aeroport de Wemindji, Que.',
    'CYKD' => 'Aklavik Airport',
    'CYKO' => 'Akulivik Airport',
    'CYLT' => 'Alert Airport',
    'CYEK' => 'Arviat Airport',
    'CYBG' => 'Bagotville, Que.',
    'CYBC' => 'Baie Comeau, Que.',
    'CYBK' => 'Baker Lake, N. W. T.',
    'CZBF' => 'Bathurst Airport Aviation Weather Reporting Station',
    'CYXQ' => 'Beaver Creek Airport',
    'CYBD' => 'Bella Coola Airport',
    'CYBV' => 'Berens River Airport',
    'CYTL' => 'Big Trout Lake',
    'CYBX' => 'Blanc Sablon, Que.',
    'CYCP' => 'Blue River, B. C.',
    'CYBN' => 'Borden, Ont.',
    'CYBR' => 'Brandon, Man.',
    'CWOB' => 'Brevoort Island',
    'CWIK' => 'Broadview, Sask.',
    'CWVD' => 'Broughton Island',
    'CYVM' => 'Broughton Island Airport',
    'CYVT' => 'Buffalo Narrows Man',
    'CYDB' => 'Burwash Airport',
    'CYBW' => 'Calgary / Springbank',
    'CYYC' => 'Calgary International, Alta.',
    'CYCB' => 'Cambridge Bay, N. W. T.',
    'CYBL' => 'Campbell River Airport',
    'CYTE' => 'Cape Dorset, N. W. T.',
    'CWFD' => 'Cape Dyer, N. W. T.',
    'CWUP' => 'Cape Hooper, N. W. T.',
    'CWKW' => 'Cape Kakkiviak',
    'CWYK' => 'Cape Kiglapait, Nfld.',
    'CWYM' => 'Cape Mercy',
    'CZCP' => 'Cape Parry, N. W. T.',
    'CWCA' => 'Cartwright, Nfld.',
    'CYCG' => 'Castlegar Airport',
    'CYLD' => 'Chapleau, Ont.',
    'CYYG' => 'Charlottetown, P. E. I.',
    'CYCS' => 'Chesterfield Inlet',
    'CYCQ' => 'Chetwynd Airport',
    'CYMT' => 'Chibougamau-Chapais, Que',
    'CZUM' => 'Churchill Falls, Nfld.',
    'CYYQ' => 'Churchill, Man.',
    'CWCL' => 'Clinton, B. C.',
    'CYCY' => 'Clyde, N. W. T.',
    'CYOD' => 'Cold Lake, Alta.',
    'CYQQ' => 'Comox, B. C.',
    'CYCO' => 'Coppermine, N. W. T.',
    'CYZS' => 'Coral Harbour, N. W. T.',
    'CYXC' => 'Cranbrook, B. C.',
    'CWXR' => 'Croker River, N. W. T.',
    'CYDN' => 'Dauphin, Man.',
    'CYDQ' => 'Dawson Creek Airport',
    'CYDA' => 'Dawson, Y. T.',
    'CWDL' => 'Dease Lake B. C.',
    'CYDF' => 'Deer Lake, Nfld.',
    'CWUW' => 'Dewar Lakes, N. W. T.',
    'CYHD' => 'Dryden Airport',
    'CYXR' => 'Earlton, Ont.',
    'CZEM' => 'Eastmain River Airport',
    'CYEG' => 'Edmonton International, Alta.',
    'CYXD' => 'Edmonton Municipal Alta.',
    'CYED' => 'Edmonton Namao Alta.',
    'CYET' => 'Edson, Alta.',
    'CYOA' => 'Ekati, N. W. T.',
    'CYEL' => 'Elliot Lake Supplementary Aviation Weather Reporting Station',
    'CYEN' => 'Estevan, Sask.',
    'CWEU' => 'Eureka, N. W. T.',
    'CZFA' => 'Faro Airport',
    'CYFO' => 'Flin Flon Airport',
    'CYPY' => 'Fort Chipewyan, Alta.',
    'CYWJ' => 'Fort Franklin Airport',
    'CYGH' => 'Fort Good Hope Airport',
    'CYJF' => 'Fort Liard Airport',
    'CYMM' => 'Fort Mcmurray, Alta.',
    'CZFM' => 'Fort Mcpherson Airport',
    'CZFN' => 'Fort Norman Airport',
    'CYFR' => 'Fort Resolution',
    'CYFS' => 'Fort Simpson, N. W. T.',
    'CYSM' => 'Fort Smith, N. W. T.',
    'CYXJ' => 'Fort St John, B. C.',
    'CYFC' => 'Fredericton, N. B.',
    'CYCX' => 'Gagetown Can-Mil',
    'CYQX' => 'Gander Int. Airport, Nfld.',
    'CYGP' => 'Gaspe, Que.',
    'CYND' => 'Gatineau Airport',
    'CYGQ' => 'Geraldton, Ont.',
    'CYGX' => 'Gillam, Man.',
    'CYHK' => 'Gjoa Haven Airport',
    'CYGE' => 'Golden Airport',
    'CYYR' => 'Goose, Nfld.',
    'CYZE' => 'Gore Bay, Ont.',
    'CYQU' => 'Grande Prairie, Alta.',
    'CYZX' => 'Greenwood, N. S.',
    'CWGZ' => 'Grise Fiord Airport',
    'CYHZ' => 'Halifax International Airport',
    'CYUX' => 'Hall Beach, N. W. T.',
    'CYHM' => 'Hamilton Airport',
    'CWIL' => 'Hat Island, N. W. T.',
    'CYGV' => 'Havre St Pierre',
    'CYHY' => 'Hay River, N. W. T.',
    'CYOJ' => 'High Level, Alta',
    'CYHI' => 'Holman Island Airport',
    'CYHE' => 'Hope, B. C.',
    'CYGT' => 'Igloolik Airport',
    'CYGR' => 'Iles De La Madeleineque',
    'CWWU' => 'Ingenika Point',
    'CYPH' => 'Inukjuak Airport Supplementary Aviation Weather Reporting Station',
    'CYEV' => 'Inuvik, N. W. T.',
    'CYFB' => 'Iqaluit, N. W. T.',
    'CYIV' => 'Island Lake, Man.',
    'CYIK' => 'Ivujivik Airport Supplementary Aviation Weather Reporting Station',
    'CWHN' => 'Jimmy Lake',
    'CYKA' => 'Kamloops, B. C.',
    'CYLU' => 'Kangiksualujjuaq A',
    'CYKG' => 'Kangiqsujuaq Supplementary Aviation Weather Reporting Station',
    'CYAS' => 'Kangirsuk Supplementary Aviation Weather Reporting Station',
    'CYYU' => 'Kapuskasing, Ont.',
    'CYLW' => 'Kelowna Airport',
    'CYQK' => 'Kenora, Ont.',
    'CYKJ' => 'Key Lake',
    'CYKY' => 'Kindersley, Sask.',
    'CYGK' => 'Kingston, Ont.',
    'CWKM' => 'Komakuk Beach, Y. T.',
    'CYVP' => 'Kuujjuaq, Que.',
    'CYGW' => 'Kuujjuarapik, Que.',
    'CYAH' => 'La Grande Iv, Que.',
    'CYGL' => 'La Grande Riviere, Que',
    'CYVC' => 'La Ronge, Sask',
    'CWMT' => 'Lac La Martre',
    'CYQL' => 'Lethbridge, Alta.',
    'CWLI' => 'Liverpool Bay',
    'CYLL' => 'Lloydminister, Alta.',
    'CYXU' => 'London, Ont.',
    'CWLX' => 'Longstaff Bluff, N. W. T.',
    'CYWO' => 'Lupin Airport Supplementary Aviation Weather Reporting Station',
    'CYLK' => 'Lutsel KE, N. W. T.',
    'CYYL' => 'Lynn Lake, Man.',
    'CWLY' => 'Lytton, B. C.',
    'CYZY' => 'Mackenzie, B. C.',
    'CYFT' => 'Makkovik Airport',
    'CYMH' => 'Mary\'s Harbour',
    'CYNM' => 'Matagami, Que.',
    'CYMA' => 'Mayo Airport',
    'CYLJ' => 'Meadow Lake, Sask.',
    'CYXH' => 'Medicine Hat, Alta.',
    'CYQM' => 'Moncton, N. B.',
    'CYYY' => 'Mont Joli, Que.',
    'CYMX' => 'Montreal / Mirabel',
    'CYUL' => 'Montreal / Pierre Elliot Trudeau International Airport, Que',
    'CYMJ' => 'Moose Jaw, Sask.',
    'CYMO' => 'Moosonee, Ont.',
    'CYQA' => 'Muskoka, Ont.',
    'CYDP' => 'Nain, Nfld',
    'CYCD' => 'Nanaimo Airport',
    'CYSR' => 'Nanisivik Airport',
    'CYNA' => 'Natashquan, Que.',
    'CYHH' => 'Nemiscau Airport Supplementary Aviation Weather Reporting Station',
    'CYBU' => 'Nipawin, Sask.',
    'CYVQ' => 'Norman Wells, N. W. T.',
    'CYQW' => 'North Battleford, Sask.',
    'CYYB' => 'North Bay, Ont.',
    'CYNE' => 'Norway House, Man.',
    'CYOC' => 'Old Crow Airport',
    'CYOW' => 'Ottawa Int\'l. Ont.',
    'CYXP' => 'Pangnirtung Airport',
    'CYPC' => 'Paulatuk Airport',
    'CYPE' => 'Peace River, Alta.',
    'CYBB' => 'Pelly Bay Airport',
    'CYYF' => 'Penticton, B. C.',
    'CYWA' => 'Petawawa, Ont.',
    'CYPQ' => 'Peterborough Airport',
    'CYPL' => 'Pickle Lake Man',
    'CZPC' => 'Pincher Creek Airport',
    'CYIO' => 'Pond Inlet, N. W. T.',
    'CYZT' => 'Port Hardy, B. C.',
    'CYPG' => 'Portage Southport A',
    'CYPX' => 'Povungnituq',
    'CYPW' => 'Powell River Airport',
    'CYPA' => 'Prince Albert, Sask.',
    'CYXS' => 'Prince George, B. C.',
    'CYPR' => 'Prince Rupert, B. C.',
    'CYDC' => 'Princeton Airport',
    'CYHA' => 'Quaqtaq Airport',
    'CYQB' => 'Quebec, Que',
    'CYQZ' => 'Quesnel Airport',
    'CYRT' => 'Rankin Inlet, N. W. T.',
    'CYQF' => 'Red Deer, Alta.',
    'CYRL' => 'Red Lake, Ont.',
    'CYQR' => 'Regina, Sask.',
    'CYUT' => 'Repulse Bay Airport',
    'CYRB' => 'Resolute, N. W. T.',
    'CYRV' => 'Revelstoke, B. C.',
    'CYRJ' => 'Roberval, Que.',
    'CYUY' => 'Rouyn Airport',
    'CWRX' => 'Rowley Island, N. W. T.',
    'CWSA' => 'Sable Island, N. S.',
    'CYSY' => 'Sachs Harbour Airport',
    'CWZZ' => 'Saglek Bay',
    'CYAY' => 'Saint Anthony Airport',
    'CYSN' => 'Saint Catharines Airport',
    'CYHU' => 'Saint Hubert Airport',
    'CYSJ' => 'Saint John, N. B.',
    'CYSL' => 'Saint Leonard Airport',
    'CYZG' => 'Salliut Airport Supplementary Aviation Weather Reporting Station',
    'CYZP' => 'Sandspit, B. C.',
    'CYSK' => 'Sanikiluaq Airport',
    'CYZR' => 'Sarnia Airport',
    'CYXE' => 'Saskatoon, Sask.',
    'CYAM' => 'Sault Ste Marie, Ont.',
    'CYKL' => 'Schefferville, Que.',
    'CYZV' => 'Sept-Iles, Que.',
    'CYAW' => 'Shearwater, N. S.',
    'CYUS' => 'Shepherd Bay, N. W. T.',
    'CYSC' => 'Sherbrooke, Que.',
    'CYUA' => 'Shingle Point, Y. T.',
    'CYXL' => 'Sioux Lookout, Ont.',
    'CYZH' => 'Slave Lake, Alta',
    'CYYD' => 'Smithers, B. C.',
    'CWSW' => 'Sparwood / Elk Valley',
    'CYYH' => 'Spence Bay Airport',
    'CYYT' => 'St. John\'s, Nfld',
    'CYJT' => 'Stephenville, Nfld.',
    'CZST' => 'Stewart Airport',
    'CYSF' => 'Stony Rapids Airport',
    'CWVH' => 'Storm Hills , N. W. T.',
    'CYSB' => 'Sudbury, Ont.',
    'CYSD' => 'Suffield Airport',
    'CYYN' => 'Swift Current, Sask.',
    'CYQY' => 'Sydney, N. S.',
    'CYTQ' => 'Tasiujaq A',
    'CYTJ' => 'Terrace Bay Supplementary Aviation Weather Reporting Station',
    'CYXT' => 'Terrace, B. C.',
    'CYZW' => 'Teslin, Y. T.',
    'CYQD' => 'The Pas, Man.',
    'CYTH' => 'Thompson Weather Office, Man',
    'CYQT' => 'Thunder Bay, Ont.',
    'CYTS' => 'Timmins, Ont.',
    'CYAZ' => 'Tofino Airport',
    'CYKZ' => 'Toronto Buttonville',
    'CYTZ' => 'Toronto Island Airport Automated Reporting Station',
    'CYYZ' => 'Toronto Pearson Int\'l. Ont.',
    'CYTR' => 'Trenton, Ont.',
    'CWTU' => 'Tukialik Bay, Nfld.',
    'CYUB' => 'Tuktoyaktuk',
    'CYMU' => 'Umiujaq',
    'CYVO' => 'Val D\'Or, Que.',
    'CYOY' => 'Valcartier Airport',
    'CYVR' => 'Vancouver International Air-Port, B. C.',
    'CYWH' => 'Victoria Harbour',
    'CYYJ' => 'Victoria Int. Airport, B. C.',
    'CYWK' => 'Wabush Lake, Nfld.',
    'CYKQ' => 'Waskaganish Airport',
    'CYKF' => 'Waterloo Well',
    'CYQH' => 'Watson Lake, Y. T.',
    'CYXZ' => 'Wawa, Ont.',
    'CYXN' => 'Whale Cove Airport',
    'CWAE' => 'Whistler',
    'CYZU' => 'Whitecourt, Alta.',
    'CYXY' => 'Whitehorse, Y. T.',
    'CYVV' => 'Wiarton, Ont.',
    'CYWL' => 'Williams Lake, B. C.',
    'CYQG' => 'Windsor, Ont.',
    'CYWG' => 'Winnipeg Int. Airportman.',
    'CYQI' => 'Yarmouth, N. S.',
    'CYZF' => 'Yellowknife, N. W. T.',
    'CYQV' => 'Yorkton, Sask.',
  );
  
  $icao_codes['Cape Verde'] = array(
    'GVAC' => 'Sal',
  );
  
  $icao_codes['Cayman Islands'] = array(
    'MWCB' => 'Gerrard Smith Intl. / Cayman Brac',
    'MWCR' => 'Owen Roberts Airportgrand Cayman',
  );
  
  $icao_codes['Central African Republic'] = array(
    'FEFG' => 'Bangassou',
    'FEFF' => 'Bangui',
    'FEFT' => 'Berberati',
  );
  
  $icao_codes['Chad'] = array(
    'FTTD' => 'Moundou',
    'FTTJ' => 'Ndjamena',
    'FTTA' => 'Sarh',
  );
  
  $icao_codes['Chile'] = array(
    'SCFA' => 'Antofagasta',
    'SCAR' => 'Arica',
    'SCBA' => 'Balmaceda',
    'SCCH' => 'Chillan',
    'SCIE' => 'Concepcion',
    'SCDA' => 'Iquique / Diego Arac',
    'SCIP' => 'Isla De Pascua',
    'SCSE' => 'La Serena',
    'SCEL' => 'Pudahuel',
    'SCTE' => 'Puerto Montt',
    'SCCI' => 'Punta Arenas',
    'SCTC' => 'Temuco',
  );
  
  $icao_codes['China'] = array(
    'ZBAA' => 'Beijing',
    'ZYCC' => 'Changchun',
    'ZGHA' => 'Changsha',
    'ZUUU' => 'Chengdu',
    'ZUCK' => 'Chongqing',
    'ZYTL' => 'Dalian',
    'ZGGG' => 'Guangzhou',
    'ZGKL' => 'Guilin',
    'ZSHC' => 'Hangzhou',
    'ZYHB' => 'Harbin',
    'ZSOF' => 'Hefei',
    'ZBHH' => 'Hohhot',
    'ZWSH' => 'Kashi',
    'ZPPP' => 'Kunming',
    'ZLLL' => 'Lanzhou / Zhongchuan',
    'ZSNJ' => 'Nanjing',
    'ZGNN' => 'Nanning',
    'ZSQD' => 'Qingdao',
    'ZJSY' => 'Sanya/Fenghuang',
    'ZSSS' => 'Shanghai / Hongqiao',
    'ZSPD' => 'Shanghai / Pudong',
    'ZGOW' => 'Shantou',
    'ZYTX' => 'Shenyang / Taokian',
    'ZGSZ' => 'Shenzhen',
    'ZBYN' => 'Taiyuan',
    'ZBTJ' => 'Tianjin / Zhangguizhu',
    'ZWWW' => 'Urum-Qi / Diwopu',
    'ZHHH' => 'Wuhan',
    'ZSAM' => 'Xiamen',
    'ZLXY' => 'Xian/Xianyang',
  );
  
  $icao_codes['Christmas Island'] = array(
    'YPXM' => 'Christmas Island Aerodrome',
    'YPCC' => 'Cocos Island Airport',
  );
  
  $icao_codes['Colombia'] = array(
    'SKLC' => 'Apartado / Los Cedros',
    'SKUC' => 'Arauca / Santiago Perez',
    'SKAR' => 'Armenia / El Eden',
    'SKEJ' => 'Barrancabermeja / Yariguies',
    'SKBQ' => 'Barranquilla / Ernestocortissoz',
    'SKBO' => 'Bogota / Eldorado',
    'SKBG' => 'Bucaramanga / Palonegro',
    'SKCL' => 'Cali / Alfonso Bonillaaragon',
    'SKCG' => 'Cartagena / Rafael Nunez',
    'SKCC' => 'Cucuta / Camilo Daza',
    'SKIB' => 'Ibague / Perales',
    'SKIP' => 'Ipiales / San Luis',
    'SKLT' => 'Leticia / Vasquez Cobo',
    'SKMD' => 'Medellin / Olaya Herrera',
    'SKMR' => 'Monteria / Los Garzones',
    'SKNV' => 'Neiva / Benito Salas',
    'SKPE' => 'Pereira / Matecana',
    'SKPV' => 'Providencia Isla / El Embrujo',
    'SKPC' => 'Puerto Carreno / A. Guauquea',
    'SKUI' => 'Quibdo / El Carano',
    'SKRH' => 'Riohacha / Almirante Padilla',
    'SKRG' => 'Rionegro / J. M. Cordova',
    'SKSP' => 'San Andres Isla / Sesquicentenario',
    'SKSM' => 'Santa Marta / Simon Bolivar',
    'SKVP' => 'Valledupar / Alfonso Lopez',
    'SKVV' => 'Villavicencio / Vanguardia',
  );
  
  $icao_codes['Comoros'] = array(
    'FMCZ' => 'Dzaoudzi / Pamanzi Mayotte',
    'FMCH' => 'Hahaya International Airport',
  );
  
  $icao_codes['Congo, Democratic Republic of the'] = array(
    'FZOA' => 'Kindu',
    'FZAA' => 'Kinshasa / N\'Djili',
    'FZQA' => 'Lubumbashi-Luano',
  );
  
  $icao_codes['Congo, Republic of the'] = array(
    'FCBB' => 'Brazzaville / Maya-Maya',
    'FCPP' => 'Pointe-Noire',
  );
  
  $icao_codes['Cook Islands'] = array(
    'NIUE' => 'Alofi / Niue',
    'NCRG' => 'Rarotonga',
  );
  
  $icao_codes['Costa Rica'] = array(
    'MROC' => 'Juan Santamaria',
    'MRLB' => 'Liberia',
    'MRLM' => 'Puerto Limon',
    'MRPV' => 'Tobias Bolanos International',
  );
  
  $icao_codes['Cote d\'Ivoire'] = array(
    'DIAP' => 'Abidjan',
  );
  
  $icao_codes['Croatia'] = array(
    'LDSB' => 'Brac',
    'LDDU' => 'Dubrovnik / Cilipi',
    'LDLO' => 'Losinj Island',
    'LDOS' => 'Osijek / Cepin',
    'LDPL' => 'Pula Aerodrome',
    'LDRI' => 'Rijeka / Omisalj',
    'LDSP' => 'Split / Resnik',
    'LDZD' => 'Zadar / Zemunik',
    'LDZA' => 'Zagreb / Pleso',
  );
  
  $icao_codes['Cuba'] = array(
    'MUHA' => 'Aeropuerto Jose Marti, Rancho-Boyeros, Habana',
    'MUCM' => 'Camaguey Aeropuerto',
    'MUCC' => 'Cayo Coco / Jardines Del Ray',
    'MUCL' => 'Cayo Largo Del Sur',
    'MUCF' => 'Cienfuegos, Las Villas',
    'MUGM' => 'Guantanamo, Leeward Point Field',
    'MUHG' => 'Holguin Civ / Mil',
    'MUMZ' => 'Manzanillo, Oriente',
    'MUCU' => 'Santiago De Cuba, Oriente',
    'MUVR' => 'Varadero, Matanzas',
    'MUCA' => 'Venezuela, Ciego De Avila',
  );
  
  $icao_codes['Cyprus'] = array(
    'LCRA' => 'Akrotiri',
    'LCEN' => 'Ercan',
    'LCLK' => 'Larnaca Airport',
    'LCPH' => 'Paphos Airport',
  );
  
  $icao_codes['Czech Republic'] = array(
    'LKTB' => 'Brno / Turany',
    'LKHO' => 'Holesov',
    'LKKV' => 'Karlovy Vary',
    'LKKU' => 'Kunovice',
    'LKLB' => 'Liberec',
    'LKMT' => 'Ostrava / Mosnov',
    'LKPR' => 'Praha / Ruzyne',
  );
  
  $icao_codes['Denmark'] = array(
    'EKYT' => 'Aalborg',
    'EKBI' => 'Billund Lufthavn',
    'EKEB' => 'Esbjerg',
    'EKKA' => 'Karup',
    'EKCH' => 'Koebenhavn / Kastrup',
    'EKRK' => 'Koebenhavn / Roskilde',
    'EKMB' => 'Maribo Lufthavn',
    'EKOD' => 'Odense / Beldringe',
    'EKRN' => 'Roenne',
    'EKSN' => 'Sindal Flyveplads',
    'EKSP' => 'Skrydstrup',
    'EKSB' => 'Soenderborg Lufthavn',
    'EKVG' => 'Soervaag / Vagar',
    'EKVJ' => 'Stauning Lufthavn',
    'EKTS' => 'Thisted Lufthavn',
    'EKAH' => 'Tirstrup',
    'EKVD' => 'Vamdrup',
  );
  
  $icao_codes['Djibouti'] = array(
    'HDAM' => 'Djibouti \ Ambouli',
  );
  
  $icao_codes['Dominica'] = array(
    'TDCF' => 'Canefield Airport',
    'TDPD' => 'Melville Hall Airport',
  );
  
  $icao_codes['Dominican Republic'] = array(
    'MDHE' => 'Herrera',
    'MDLR' => 'La Romana International Airport',
    'MDSD' => 'Las Americas',
    'MDPP' => 'Puerto Plata International',
    'MDPC' => 'Punta Cana',
    'MDST' => 'Santiago',
  );
  
  $icao_codes['Ecuador'] = array(
    'SEGU' => 'Guayaquil / Simon Bolivar',
    'SELT' => 'Latacunga',
    'SEMT' => 'Manta',
    'SEQU' => 'Quito / Mariscal Sucre',
  );
  
  $icao_codes['Egypt'] = array(
    'HEAX' => 'Alexandria / Nouzha',
    'HEBA' => 'Alexandria Borg El Arab',
    'HESN' => 'Asswan',
    'HEAT' => 'Asyut',
    'HECA' => 'Cairo Airport',
    'HEAR' => 'El Arish',
    'HEGN' => 'Hurguada',
    'HELX' => 'Luxor',
    'HEMM' => 'Mersa Matruh',
    'HEPS' => 'Port Said',
    'HESH' => 'Sharm El Sheikhintl',
    'HETB' => 'Taba',
  );
  
  $icao_codes['El Salvador'] = array(
    'MSAC' => 'Acajutla',
    'MSLP' => 'El Salvador Intl. Airport / Comalapa',
    'MSSM' => 'San Miguel / El Papalon',
    'MSSS' => 'San Salvador / Ilopango',
    'MSSA' => 'Santa Ana / El Palmar',
  );
  
  $icao_codes['Equatorial Guinea'] = array(
    'FGSL' => 'Malabo/Fernando Poo',
  );
  
  $icao_codes['Estonia'] = array(
    'EEKA' => 'Kardla',
    'EEKE' => 'Kuressaare',
    'EEPU' => 'Parnu',
    'EETN' => 'Tallinn',
    'EETU' => 'Tartu/Ulenurme',
  );
  
  $icao_codes['Fiji'] = array(
    'NFFN' => 'Nandi',
    'NFNA' => 'Nausori',
  );
  
  $icao_codes['Finland'] = array(
    'EFET' => 'Enontekio',
    'EFHA' => 'Halli',
    'EFHF' => 'Helsinki-Malmi',
    'EFHK' => 'Helsinki-Vantaa',
    'EFIV' => 'Ivalo',
    'EFJO' => 'Joensuu',
    'EFJY' => 'Jyvaskyla',
    'EFKI' => 'Kajaani',
    'EFKA' => 'Kauhava',
    'EFKE' => 'Kemi',
    'EFKT' => 'Kittila',
    'EFKK' => 'Kruunupyy',
    'EFKU' => 'Kuopio',
    'EFKS' => 'Kuusamo',
    'EFLP' => 'Lappeenranta',
    'EFMA' => 'Mariehamn / Aland Island',
    'EFMI' => 'Mikkeli',
    'EFOU' => 'Oulu',
    'EFPO' => 'Pori',
    'EFRO' => 'Rovaniemi',
    'EFSA' => 'Savonlinna',
    'EFSI' => 'Seinajoki-Ilmajok',
    'EFTP' => 'Tampere / Pirkkala',
    'EFTU' => 'Turku',
    'EFUT' => 'Utti',
    'EFVA' => 'Vaasa',
    'EFVR' => 'Varkaus',
  );
  
  $icao_codes['France'] = array(
    'LFBA' => 'Agen',
    'LFKJ' => 'Ajaccio',
    'LFOA' => 'Avord',
    'LFSB' => 'Bale-Mulhouse',
    'LFKB' => 'Bastia',
    'LFOB' => 'Beauvais',
    'LFBE' => 'Bergerac',
    'LFMU' => 'Beziers / Vias',
    'LFBZ' => 'Biarritz',
    'LFBD' => 'Bordeaux / Merignac',
    'LFLD' => 'Bourges',
    'LFRB' => 'Brest',
    'LFRK' => 'Caen',
    'LFKC' => 'Calvi',
    'LFQI' => 'Cambrai',
    'LFMD' => 'Cannes',
    'LFMK' => 'Carcassonne',
    'LFBC' => 'Cazaux',
    'LFOK' => 'Chalons-Vatry',
    'LFLB' => 'Chambery / Aix-Les-Bains',
    'LFLX' => 'Chateauroux',
    'LFRC' => 'Cherbourg / Maupertus',
    'LFLC' => 'Clermont-Ferrand',
    'LFBG' => 'Cognac',
    'LFSC' => 'Colmar',
    'LFSD' => 'Dijon',
    'LFRD' => 'Dinard',
    'LFGJ' => 'Dole Tavaux',
    'LFOE' => 'Evreux',
    'LFKF' => 'Figari',
    'LFLS' => 'Grenoble / St. Geoirs',
    'NLWW' => 'Hihifo Ile Wallis',
    'LFTH' => 'Hyeres',
    'LFMI' => 'Istres',
    'LFOH' => 'La Heve',
    'LFBH' => 'La Rochelle',
    'LFRH' => 'Lann Bihoue',
    'LFRO' => 'Lannion / Servel',
    'LFRM' => 'Le Mans',
    'LFQQ' => 'Lille',
    'LFBL' => 'Limoges',
    'LFSX' => 'Luxeuil',
    'LFLY' => 'Lyon / Bron',
    'LFLL' => 'Lyon / Satolas',
    'LFML' => 'Marseille / Marignane',
    'LFSF' => 'Metz / Frescaty',
    'LFJL' => 'Metz-Nancy-Lorraine',
    'LFMT' => 'Montpellier',
    'LFSO' => 'Nancy / Ochey',
    'LFRS' => 'Nantes',
    'LFMN' => 'Nice',
    'LFTW' => 'Nimes / Garons',
    'LFMO' => 'Orange',
    'LFOJ' => 'Orleans',
    'LFPB' => 'Paris / Le Bourget',
    'LFPG' => 'Paris-Aeroport Charles De Gaulle',
    'LFPO' => 'Paris-Orly',
    'LFBP' => 'Pau',
    'LFMP' => 'Perpignan',
    'LFBI' => 'Poitiers',
    'LFRQ' => 'Quimper',
    'LFSR' => 'Reims',
    'LFRN' => 'Rennes',
    'LFCR' => 'Rodez',
    'LFOP' => 'Rouen',
    'LFRT' => 'Saint-Brieuc',
    'LFSI' => 'St-Dizier',
    'LFMH' => 'St-Etienne Boutheon',
    'LFRZ' => 'St-Nazaire',
    'LFST' => 'Strasbourg',
    'LFBT' => 'Tarbes Ossun Lourdes',
    'LFBO' => 'Toulouse / Blagnac',
    'LFOT' => 'Tours',
    'LFPN' => 'Toussus Le Noble',
    'LFQB' => 'Troyes',
    'LFLV' => 'Vichy',
    'LFPV' => 'Villacoublay',
  );
  
  $icao_codes['French Guiana'] = array(
    'SOCA' => 'Cayenne / Rochambeau',
  );
  
  $icao_codes['French Polynesia'] = array(
    'NTAA' => 'Tahiti-Faaa',
  );
  
  $icao_codes['Gabon'] = array(
    'FOOB' => 'Bitam',
    'FOON' => 'Franceville / Mvengue',
    'FOGR' => 'Lambarene',
    'FOOR' => 'Lastoursville',
    'FOOL' => 'Libreville',
    'FOOK' => 'Makokou',
    'FOOG' => 'Port-Gentil',
    'FOOT' => 'Tchibanga',
  );
  
  $icao_codes['Georgia'] = array(
    'UGGG' => 'Tbilisi',
  );
  
  $icao_codes['Germany'] = array(
    'EDAC' => 'Altenburg Nobitz',
    'ETHA' => 'Altenstadt',
    'EDMA' => 'Augsburg',
    'EDFM' => 'Baden Wurttemberg, Neuostheim',
    'EDQD' => 'Bayreuth',
    'EDDB' => 'Berlin-Schoenefeld',
    'EDDT' => 'Berlin-Tegel',
    'EDDI' => 'Berlin-Tempelhof',
    'EDVE' => 'Braunschweig',
    'EDDW' => 'Bremen',
    'ETSB' => 'Buechel',
    'ETHB' => 'Bueckeburg',
    'ETHC' => 'Celle',
    'ETND' => 'Diepholz',
    'EDTD' => 'Donaueschingen / Villingen',
    'EDLW' => 'Dortmund / Wickede',
    'EDDC' => 'Dresden-Klotzsche',
    'EDDL' => 'Duesseldorf',
    'ETSE' => 'Erding',
    'EDDE' => 'Erfurt-Bindersleben',
    'EDDF' => 'Frankfurt / M-Flughafen',
    'EDNY' => 'Friedrichshafen',
    'ETHF' => 'Fritzlar',
    'ETGG' => 'Gluecksburg / Meierwik',
    'ETUO' => 'Guetersloh',
    'EDFH' => 'Hahn',
    'EDHI' => 'Hamburg-Finkenwerder',
    'EDDH' => 'Hamburg-Fuhlsbuettel',
    'EDDV' => 'Hannover',
    'EDAH' => 'Heringsdorf',
    'EDGS' => 'Hessen',
    'EDQM' => 'Hof',
    'ETNH' => 'Hohn',
    'ETSH' => 'Holzdorf',
    'ETSI' => 'Ingolstadt',
    'ETNJ' => 'Jever',
    'ETGY' => 'Kalkar',
    'EDSB' => 'Karlsruhe, Baden Wurttemberg',
    'EDVK' => 'Kassel / Calden',
    'EDHK' => 'Kiel / Holtenau Civilian',
    'EDDK' => 'Koeln / Bonn',
    'ETNL' => 'Laage',
    'EDTL' => 'Lahr, CAN-AFB',
    'ETSA' => 'Landsberg',
    'ETHL' => 'Laupheim',
    'ETSL' => 'Lechfeld',
    'EDDP' => 'Leipzig-Schkeuditz',
    'EDHL' => 'Luebeck-Blankensee',
    'EDBM' => 'Magdeburg, Sachsen-Anhalt',
    'EDOP' => 'Mecklenburg-Vorpommern, Parchim',
    'ETHM' => 'Mendig',
    'ETWM' => 'Meppen-Mil',
    'ETGZ' => 'Messstetten',
    'EDLN' => 'Monchengladbach',
    'EDDG' => 'Muenster / Osnabrueck',
    'EDDM' => 'Munchen',
    'ETSN' => 'Neuburg / Donau',
    'EDLV' => 'Niederrhein',
    'ETHN' => 'Niederstetten',
    'ETNN' => 'Noervenich',
    'ETMN' => 'Nordholz',
    'EDDN' => 'Nuernberg',
    'EDMO' => 'Oberpfaffenhofen',
    'EDLP' => 'Paderborn / Lippstadt',
    'ETAR' => 'Ramstein',
    'ETHE' => 'Rheine-Bentlage',
    'ETHR' => 'Roth',
    'EDDR' => 'Saarbruecken / Ensheim',
    'ETNS' => 'Schleswig-Jagel',
    'ETAD' => 'Spangdahlem',
    'EDDS' => 'Stuttgart-Echterdingen',
    'ETNU' => 'Trollenhagen',
    'EDXW' => 'Westerland / Sylt',
    'ETOU' => 'Wiesbaden',
    'ETNT' => 'Wittmundhaven',
    'ETNW' => 'Wunstorf',
    'EDRZ' => 'Zweibrucken, Rheinland-Pfalz',
  );
  
  $icao_codes['Ghana'] = array(
    'DGAA' => 'Accra',
    'DGSI' => 'Kumasi',
  );
  
  $icao_codes['Gibraltar'] = array(
    'LXGB' => 'Gibraltar',
  );
  
  $icao_codes['Greece'] = array(
    'LGPZ' => 'Aktion Airport',
    'LGAL' => 'Alexandroupoli Airport',
    'LGAD' => 'Andravida Airport',
    'LGRX' => 'Araxos Airport',
    'LGAV' => 'Athens Eleftherios Venizelos International Airport',
    'LGHI' => 'Chios Airport',
    'LGKV' => 'Chrysoupoli Airport',
    'LGNX' => 'Cyclades Islands, Naxos Airport',
    'LGEL' => 'Elefsis Airport',
    'LGIR' => 'Heraklion Airport',
    'LGKL' => 'Kalamata Airport',
    'LGKP' => 'Karpathos Airport',
    'LGKF' => 'Kefalhnia Airport',
    'LGKR' => 'Kerkyra Airport',
    'LGKC' => 'Kithira Airport',
    'LGKO' => 'Kos Airport',
    'LGKZ' => 'Kozani Airport',
    'LGLM' => 'Limnos Airport',
    'LGMK' => 'Mikonos Island, Mikonos Airport',
    'LGMT' => 'Mytilini Airport',
    'LGPA' => 'Paros Community Airport',
    'LGRP' => 'Rhodes Airport',
    'LGSM' => 'Samos Airport',
    'LGSR' => 'Santorini Island',
    'LGSK' => 'Skiathos Island',
    'LGSA' => 'Souda Airport',
    'LGSO' => 'Syros Airport',
    'LGTS' => 'Thessaloniki Airport',
    'LGZA' => 'Zakinthos Airport',
  );
  
  $icao_codes['Greenland'] = array(
    'BGCO' => 'Constable Pynt',
    'BGGH' => 'Godthaab / Nuuk',
    'BGJN' => 'Jacobshavn Lufthavn',
    'BGKK' => 'Kulusuk Lufthavn',
    'BGBW' => 'Narsarsuaq',
    'BGSF' => 'Sdr Stroemfjord',
    'BGTL' => 'Thule A. B.',
  );
  
  $icao_codes['Grenada'] = array(
    'TGPY' => 'Point Salines Airport',
  );
  
  $icao_codes['Guadeloupe'] = array(
    'TFFR' => 'Le Raizet, Guadeloupe',
  );
  
  $icao_codes['Guatemala'] = array(
    'MGGT' => 'Guatemala Aeropuertola Aurora',
    'MGHT' => 'Huehuetenango',
    'MGPB' => 'Puerto Barrios',
    'MGSJ' => 'San Jose',
    'MGTK' => 'Tikal',
  );
  
  $icao_codes['Guinea'] = array(
    'GUCY' => 'Conakry / Gbessia',
  );
  
  $icao_codes['Guyana'] = array(
    'SYCJ' => 'Georgetown/Cheddi Jagan International Airport',
  );
  
  $icao_codes['Haiti'] = array(
    'MTPP' => 'Port-Au-Prince / Aeroport International',
  );
  
  $icao_codes['Honduras'] = array(
    'MHAM' => 'Amapala',
    'MHCA' => 'Catacamas',
    'MHCH' => 'Choluteca',
    'MHSC' => 'Coronel Enrique Soto Cano Air Base',
    'MHNO' => 'Guanaja',
    'MHLC' => 'La Ceiba Airport',
    'MHLE' => 'La Esperanza',
    'MHLM' => 'La Mesa San Pedro Sula',
    'MHPL' => 'Puerto Lempira',
    'MHRO' => 'Roatan',
    'MHSR' => 'Santa Rosa De Copan',
    'MHTG' => 'Tegucigalpa',
    'MHTE' => 'Tela',
    'MHYR' => 'Yoro',
  );
  
  $icao_codes['Hong Kong'] = array(
    'VHHH' => 'Hong Kong Inter-National Airport',
  );
  
  $icao_codes['Hungary'] = array(
    'LHBP' => 'Budapest / Ferihegy',
    'LHDC' => 'Debrecen',
    'LHKE' => 'Kecskemet',
    'LHPP' => 'Pecs / Pogany',
    'LHUD' => 'Szeged',
    'LHSN' => 'Szolnok',
  );
  
  $icao_codes['Iceland'] = array(
    'BIAR' => 'Akureyri',
    'BIEG' => 'Egilsstadir',
    'BIKF' => 'Keflavikurflugvollur',
    'BIRK' => 'Reykjavik',
  );
  
  $icao_codes['India'] = array(
    'VAAH' => 'Ahmadabad',
    'VIAR' => 'Amritsar',
    'VOBG' => 'Bangalore / Hindustan',
    'VABB' => 'Bombay / Santacruz',
    'VOHY' => 'Hyderabad Airport',
    'VIJP' => 'Jaipur / Sanganer',
    'VILK' => 'Lucknow / Amausi',
    'VOMM' => 'Madras / Minambakkam',
    'VANP' => 'Nagpur Sonegaon',
    'VIDP' => 'New Delhi / Palam',
    'VOTV' => 'Thiruvananthapuram',
    'VOTR' => 'Tiruchchirapalli',
    'VIBN' => 'Varanasi / Babatpur',
  );
  
  $icao_codes['Indonesia'] = array(
    'WABB' => 'Biak / Mokmer',
    'WIII' => 'Jakarta / Soekarno-Hatta',
    'WIMM' => 'Medan / Polonia',
    'WAAA' => 'Ujung Pandang / Hasanuddin',
  );
  
  $icao_codes['Iran'] = array(
    'OIAA' => 'Abadan',
    'OIAW' => 'Ahwaz',
    'OITL' => 'Ardabil',
    'OIKB' => 'Bandarabbass',
    'OIBB' => 'Bushehr Civ / Afb',
    'OIFM' => 'Esfahan',
    'OIHH' => 'Hamadan',
    'OIIP' => 'Karaj / Payam',
    'OIKK' => 'Kerman',
    'OICC' => 'Kermanshah',
    'OICK' => 'Khorram Abad',
    'OIBK' => 'Kish Island / Kish',
    'OIMM' => 'Mashhad',
    'OINN' => 'Noshahr',
    'OITR' => 'Orumieh',
    'OINR' => 'Ramsar',
    'OIGG' => 'Rasht',
    'OICS' => 'Sanandaj',
    'OISS' => 'Shiraz',
    'OITT' => 'Tabriz',
    'OIII' => 'Tehran-Mehrabad',
    'OIYY' => 'Yazd',
    'OIZH' => 'Zahedan',
  );
  
  $icao_codes['Ireland'] = array(
    'EIKN' => 'Connaught',
    'EICK' => 'Cork Airport',
    'EIDW' => 'Dublin Airport',
    'EINN' => 'Shannon Airport',
  );
  
  $icao_codes['Israel'] = array(
    'LLBG' => 'Ben-Gurion International Airport',
    'LLET' => 'Eilat',
    'LLIB' => 'Galilee / Pina',
    'LLOV' => 'Ovda',
    'LLSD' => 'Tel Aviv / Sde-Dov Airport',
  );
  
  $icao_codes['Italy'] = array(
    'LIMG' => 'Albenga',
    'LIEA' => 'Alghero',
    'LIBA' => 'Amendola',
    'LIPA' => 'Aviano',
    'LIYW' => 'Aviano Usaf',
    'LIBD' => 'Bari / Palese Macchie',
    'LIME' => 'Bergamo / Orio Al Serio',
    'LIPE' => 'Bologna / Borgo Panigale',
    'LIPB' => 'Bolzano',
    'LIPL' => 'Brescia / Ghedi',
    'LIPO' => 'Brescia / Montichia',
    'LIBR' => 'Brindisi',
    'LIEE' => 'Cagliari / Elmas',
    'LIMU' => 'Capo Mele',
    'LICC' => 'Catania / Fontanarossa',
    'LICZ' => 'Catania / Sigonella',
    'LIPC' => 'Cervia',
    'LIBC' => 'Crotone',
    'LIMZ' => 'Cuneo / Levaldigi',
    'LIED' => 'Decimomannu',
    'LIVD' => 'Dobbiaco',
    'LIPY' => 'Falconara',
    'LIPF' => 'Ferrara',
    'LIRQ' => 'Firenze / Peretola',
    'LIPK' => 'Forli',
    'LIVF' => 'Frontone',
    'LIRH' => 'Frosinone',
    'LIMJ' => 'Genova / Sestri',
    'LIBV' => 'Gioia Del Colle',
    'LIRM' => 'Grazzanise',
    'LIRS' => 'Grosseto',
    'LIBG' => 'Grottaglie',
    'LIRG' => 'Guidonia',
    'LICA' => 'Lamezia Terme',
    'LICD' => 'Lampedusa',
    'LIRL' => 'Latina',
    'LIBN' => 'Lecce',
    'LIML' => 'Milano / Linate',
    'LIMC' => 'Milano / Malpensa',
    'LIQO' => 'Monte Argentario',
    'LIVC' => 'Monte Cimone',
    'LIMY' => 'Monte Malanotte',
    'LIBQ' => 'Monte Scuro',
    'LIRK' => 'Monte Terminillo',
    'LIRN' => 'Napoli / Capodichino',
    'LIMN' => 'Novara / Cameri',
    'LIEO' => 'Olbia / Costa Smeralda',
    'LIVP' => 'Paganella',
    'LICJ' => 'Palermo / Punta Raisi',
    'LICP' => 'Palermo Boccadifalco',
    'LICG' => 'Pantelleria',
    'LIMP' => 'Parma',
    'LIMV' => 'Passo Dei Giovi',
    'LIMT' => 'Passo Della Cisa',
    'LIVR' => 'Passo Rolle',
    'LIRZ' => 'Perugia',
    'LIBP' => 'Pescara',
    'LIMS' => 'Piacenza',
    'LIMH' => 'Pian Rosa',
    'LIRP' => 'Pisa / S. Giusto',
    'LIRE' => 'Pratica Di Mare',
    'LIVM' => 'Punta Marina',
    'LICR' => 'Reggio Calabria',
    'LIVE' => 'Resia Pass',
    'LIQN' => 'Rieti',
    'LIPR' => 'Rimini',
    'LIRA' => 'Roma / Ciampino',
    'LIRU' => 'Roma / Urbe',
    'LIRF' => 'Roma Fiumicino',
    'LIPQ' => 'Ronchi Dei Legionari',
    'LIQW' => 'Sarzana / Luni',
    'LIVO' => 'Tarvisio',
    'LIMK' => 'Torino / Bric Della Croce',
    'LIMF' => 'Torino / Caselle',
    'LICT' => 'Trapani / Birgi',
    'LIRT' => 'Trevico',
    'LIPS' => 'Treviso / Istrana',
    'LIPH' => 'Treviso / S. Angelo',
    'LIVT' => 'Trieste',
    'LIPI' => 'Udine / Rivolto',
    'LIPZ' => 'Venezia / Tessera',
    'LIPX' => 'Verona / Villafranca',
    'LIPT' => 'Vicenza',
    'LIRV' => 'Viterbo',
  );
  
  $icao_codes['Jamaica'] = array(
    'MKJP' => 'Kingston / Norman Manley',
    'MKJS' => 'Montego Bay / Sangster',
  );
  
  $icao_codes['Japan'] = array(
    'RJOE' => 'Akeno Ab',
    'RJSK' => 'Akita Airport',
    'RJKA' => 'Amami Airport',
    'RJSA' => 'Aomori Airport',
    'RJCA' => 'Asahikawa Ab',
    'RJEC' => 'Asahikawa Airport',
    'RJFA' => 'Ashiya Ab',
    'RJTA' => 'Atsugi United States Naval Air Station',
    'RJCC' => 'Chitose Ab',
    'RJCJ' => 'Chitose Japanese Air Self Defense Force',
    'RJTF' => 'Chofu Airport',
    'RJAT' => 'Fuji Ab',
    'RJFE' => 'Fukue Airport',
    'RJNF' => 'Fukui Airport',
    'RJFF' => 'Fukuoka Airport',
    'RJSF' => 'Fukushima Airport',
    'ROTM' => 'Futenma Marine Corps Air Facility',
    'RJNG' => 'Gifu Ab',
    'RJTH' => 'Hachijojima Airport',
    'RJSH' => 'Hachinohe Ab',
    'RJCH' => 'Hakodate Airport',
    'RJNH' => 'Hamamatsu Ab',
    'RJSI' => 'Hanamaki Airport',
    'RJOA' => 'Hiroshima Airport',
    'RJBH' => 'Hiroshimanishi',
    'RJOF' => 'Hofu Ab',
    'RJAH' => 'Hyakuri Ab',
    'RJTJ' => 'Iruma Ab',
    'ROIG' => 'Ishigakijima',
    'RJOI' => 'Iwakuni Marine Corps Air Station',
    'RJOW' => 'Iwami Airport',
    'RJAW' => 'Iwojima',
    'RJOC' => 'Izumo Airport',
    'RODN' => 'Kadena Ab',
    'RJFK' => 'Kagoshima Airport',
    'RJFY' => 'Kanoya Ab',
    'RJBB' => 'Kansai International Airport',
    'RJAK' => 'Kasumigaura Ab',
    'RJSU' => 'Kasuminome Ab',
    'RJTK' => 'Kisarazu Ab',
    'RJFR' => 'Kitakyushu Airport',
    'RJOK' => 'Kochi Airport',
    'RJNK' => 'Komatsu Ab',
    'RJOP' => 'Komatsujima Ab',
    'RJFT' => 'Kumamoto Airport',
    'ROKJ' => 'Kumejima',
    'RJAF' => 'Matsumoto Airport',
    'RJST' => 'Matsushima Ab',
    'RJOM' => 'Matsuyama Airport',
    'RJCM' => 'Memambetsu Airport',
    'RJDM' => 'Metabaru Ab',
    'RJOH' => 'Miho Ab',
    'RJSM' => 'Misawa Ab',
    'ROMY' => 'Miyakojima',
    'RJFM' => 'Miyazaki Airport',
    'RJEB' => 'Mombetsu Airport',
    'RJFU' => 'Nagasaki Airport',
    'RJGG' => 'Nagoya Airport',
    'ROAH' => 'Naha Airport',
    'RJCN' => 'Nakashibetsu Airport',
    'RJBD' => 'Nankishirahama Airport',
    'RJAA' => 'New Tokyo Inter-National Airport',
    'RJSN' => 'Niigata Airport',
    'RJFN' => 'Nyutabaru Ab',
    'RJCB' => 'Obihiro Airport',
    'RJSR' => 'Odate-Noshiro Airport',
    'RJFO' => 'Oita Airport',
    'RJOB' => 'Okayama Airport',
    'RJKB' => 'Okinoerabu',
    'RJSO' => 'Ominato Ab',
    'RJOO' => 'Osaka International Airport',
    'RJTO' => 'Oshima Airport',
    'RJOZ' => 'Ozuki Ab',
    'RJFS' => 'Saga Airport',
    'RJCO' => 'Sapporo Ab',
    'RJSS' => 'Sendai Airport',
    'RJTL' => 'Shimofusa Ab',
    'RORS' => 'Shimoji-Shima Island',
    'RJNY' => 'Shizuhama Ab',
    'RJSY' => 'Shonai',
    'RJTC' => 'Tachikawa Ab',
    'RJBT' => 'Tajima',
    'RJOT' => 'Takamatsu Airport',
    'RJFG' => 'Tanegashima Airport',
    'RJTE' => 'Tateyama Ab',
    'RJOS' => 'Tokushima Ab',
    'RJTI' => 'Tokyo Heliport',
    'RJTT' => 'Tokyo International Airport',
    'RJOR' => 'Tottori Airport',
    'RJNT' => 'Toyama Airport',
    'RJFZ' => 'Tsuiki Ab',
    'RJDT' => 'Tsushima Airport',
    'RJTU' => 'Utsunomiya Ab',
    'RJCW' => 'Wakkanai Airport',
    'RJFC' => 'Yakushima',
    'RJSC' => 'Yamagata Airport',
    'RJDC' => 'Yamaguchi Ube Airport',
    'RJOY' => 'Yao Airport',
    'RJTY' => 'Yokota Ab',
    'RJTR' => 'Zama Airfield',
  );
  
  $icao_codes['Jordan'] = array(
    'OJAM' => 'Amman Airport',
    'OJAQ' => 'Aqaba Airport',
    'OJAI' => 'Queen Alia Airport',
  );
  
  $icao_codes['Kazakhstan'] = array(
    'UATE' => 'Aktau',
    'UATT' => 'Aktjubinsk',
    'UAAA' => 'Almaty',
    'UACC' => 'Astana',
    'UAKK' => 'Karaganda',
    'UAUU' => 'Kostanay',
    'UAOO' => 'Kzyl-Orda',
    'UAII' => 'Shymkent',
    'UARR' => 'Uralsk',
  );
  
  $icao_codes['Kenya'] = array(
    'HKEL' => 'Eldoret',
    'HKEM' => 'Embu',
    'HKGA' => 'Garissa',
    'HKKI' => 'Kisumu',
    'HKLO' => 'Lodwar',
    'HKML' => 'Malindi',
    'HKMO' => 'Mombasa',
    'HKNC' => 'Nairobi / Dagoretti',
    'HKNW' => 'Nairobi / Wilson',
    'HKJK' => 'Nairobi/Jomo Kenyatta Airport TWR/APP/NOF/Civil Airlines',
    'HKNK' => 'Nakuru',
    'HKNO' => 'Narok',
    'HKNI' => 'Nyeri',
    'HKWJ' => 'Wajir',
  );
  
  $icao_codes['Kiribati'] = array(
    'NGTA' => 'Tarawa',
  );
  
  $icao_codes['Korea, South'] = array(
    'RKPC' => 'Cheju International Airport',
    'RKTU' => 'Chongju Ab',
    'RKSI' => 'Incheon International Airport',
    'RKJK' => 'Kunsan Ab',
    'RKSO' => 'Osan Ab',
    'RKPK' => 'Pusan / Kimhae International Airport',
    'RKSG' => 'Pyongtaek Ab',
    'RKSS' => 'Seoul / Kimp\'O International Airport',
    'RKTN' => 'Taegu Ab',
    'RKJY' => 'Yosu Airport',
  );
  
  $icao_codes['Kuwait'] = array(
    'OKBK' => 'Kuwait Internationalairport',
  );
  
  $icao_codes['Kyrgyzstan'] = array(
    'UAFM' => 'Bishkek/Manas Airport',
  );
  
  $icao_codes['Laos'] = array(
    'VLVT' => 'Vientiane',
  );
  
  $icao_codes['Latvia'] = array(
    'EVLA' => 'Liepaja International Airport',
    'EVRA' => 'Riga International Airport',
  );
  
  $icao_codes['Lebanon'] = array(
    'OLBA' => 'Beyrouth Aeroport',
  );
  
  $icao_codes['Liberia'] = array(
    'GLRB' => 'Grand Bassa, Roberts Field',
  );
  
  $icao_codes['Libya'] = array(
    'HLLB' => 'Benina',
    'HLLT' => 'Tripoli Inter-National Airport',
  );
  
  $icao_codes['Lithuania'] = array(
    'EYKA' => 'Kaunas',
    'EYPA' => 'Palanga Intl.',
    'EYSA' => 'Siauliai Intl./Mil.',
    'EYVI' => 'Vilnius',
  );
  
  $icao_codes['Luxembourg'] = array(
    'ELLX' => 'Luxembourg / Luxembourg',
  );
  
  $icao_codes['Macau'] = array(
    'VMMC' => 'Taipa',
  );
  
  $icao_codes['Macedonia, The Republic of'] = array(
    'LWOH' => 'Ohrid',
    'LWSK' => 'Skopje-Petrovec',
  );
  
  $icao_codes['Madagascar'] = array(
    'FMMI' => 'Antananarivo / Ivato',
    'FMNA' => 'Diego-Suarez',
    'FMNN' => 'Fascene Nossi-Be',
    'FMSD' => 'Fort-Dauphin',
    'FMNM' => 'Majunga',
    'FMMS' => 'Sainte-Marie Aerodrome',
    'FMMT' => 'Tamatave',
    'FMST' => 'Tulear',
  );
  
  $icao_codes['Malaysia'] = array(
    'WBGB' => 'Bintulu',
    'WMKJ' => 'Johore Bharu / Senai',
    'WMKC' => 'Kota Bharu',
    'WBKK' => 'Kota Kinabalu',
    'WMKD' => 'Kuantan',
    'WBGG' => 'Kuching',
    'WBKT' => 'Kudat',
    'WBKL' => 'Labuan',
    'WMKL' => 'Langkawi',
    'WMKM' => 'Malacca',
    'WBGR' => 'Miri',
    'WMKP' => 'Penang / Bayan Lepas',
    'WBKS' => 'Sandakan',
    'WMKK' => 'Sepang/KL International Airport',
    'WBGS' => 'Sibu',
    'WMBA' => 'Sitiawan',
    'WMSA' => 'Subang/Sultan Abdul Aziz Shah Airport',
    'WBKW' => 'Tawau',
  );
  
  $icao_codes['Maldives'] = array(
    'VRMM' => 'Male',
  );
  
  $icao_codes['Mali'] = array(
    'GABS' => 'Bamako / Senou',
  );
  
  $icao_codes['Malta'] = array(
    'LMML' => 'Luqa',
  );
  
  $icao_codes['Marshall Islands'] = array(
    'PKWA' => 'Kwajalein, Bucholz AAF, Kwajalein KMR ATOL Airport',
    'PKMJ' => 'Majuro Atoll, Marshall Islands Int. Airp.',
    'PKMR' => 'Majuro Atoll, NWS Office',
  );
  
  $icao_codes['Martinique'] = array(
    'TFFF' => 'Le Lamentin',
  );
  
  $icao_codes['Mauritania'] = array(
    'GQPP' => 'Nouadhibou',
    'GQNN' => 'Nouakchott',
  );
  
  $icao_codes['Mauritius'] = array(
    'FIMP' => 'Plaisance Mauritius',
    'FIMR' => 'Rodrigues',
  );
  
  $icao_codes['Mexico'] = array(
    'MMAA' => 'Acapulco / G. Alvarez',
    'MMAN' => 'Aerop. Internacional Monterrey, N. L.',
    'MMAS' => 'Aguascalientes, Ags.',
    'MMBT' => 'Bahias De Huatulco',
    'MMCP' => 'Campeche, Camp.',
    'MMUN' => 'Cancun International Airport',
    'MMCM' => 'Chetumal, Q. Roo',
    'MMCT' => 'Chichen-Itza',
    'MMCU' => 'Chihuahua International Airport',
    'MMCE' => 'Ciudad Del Carmen',
    'MMCS' => 'Ciudad Juarez International',
    'MMCN' => 'Ciudad Obregon',
    'MMCV' => 'Ciudad Victoria Airport',
    'MMIA' => 'Colima',
    'MMCZ' => 'Cozumel Civ / Mil',
    'MMCB' => 'Cuernavaca, Mor.',
    'MMCL' => 'Culiacan, Sin.',
    'MMGL' => 'Don Miguel / Guadalaj',
    'MMDO' => 'Durango Airport',
    'MMGM' => 'Guaymas International Airport',
    'MMHO' => 'Hermosillo, Son.',
    'MMZH' => 'Ixtapa-Zihuatanejo',
    'MMIT' => 'Ixtepec Ox',
    'MMLP' => 'La Paz International Airport',
    'MMLT' => 'Loreto, B. C. S.',
    'MMLM' => 'Los Mochis Airport',
    'MMZO' => 'Manzanillo International',
    'MMMA' => 'Matamoros International',
    'MMMZ' => 'Mazatlan / G. Buelna',
    'MMMD' => 'Merida / lic Manuel Crecencio',
    'MMML' => 'Mexicali International Airport',
    'MMMX' => 'Mexico City / Licenci',
    'MMMT' => 'Minatitlan',
    'MMMV' => 'Monclova, Coah.',
    'MMMY' => 'Monterrey / Gen Maria',
    'MMMM' => 'Morelia New',
    'MMNL' => 'Nuevo Laredo International',
    'MMOX' => 'Oaxaca / Xoxocotlan',
    'MMPG' => 'Piedras Negras, Coah.',
    'MMPA' => 'Poza Rica / Palizada',
    'MMPB' => 'Puebla, Pue.',
    'MMPS' => 'Puerto Escondido',
    'MMPR' => 'Puerto Vallarta / Lic',
    'MMQT' => 'Queretaro, Qro.',
    'MMRX' => 'Reynosa International Airport',
    'MMIO' => 'Saltillo, Coah.',
    'MMSD' => 'San Jose Del Cabo',
    'MMSP' => 'San Luis Potosi, S. L. P.',
    'MMTM' => 'Tampico / Gen Fj Mina',
    'MMTP' => 'Tapachula',
    'MMEP' => 'Tepic, Nay.',
    'MMTJ' => 'Tijuana International Airport',
    'MMTO' => 'Toluca / Jose Maria',
    'MMTC' => 'Torreon, Coah.',
    'MMTG' => 'Tuxtla Gutierrez, Chis.',
    'MMPN' => 'Uruapan / Gen Rayon',
    'MMVR' => 'Veracruz / Las Bajadas / General Heriberto Jara',
    'MMVA' => 'Villahermosa',
    'MMZC' => 'Zacatecas Airport',
  );
  
  $icao_codes['Micronesia, Federated States of'] = array(
    'PTSA' => 'Kosrae Island, Kosrae Airport',
    'PTPN' => 'Pohnpei Island, Pohnpei Int. Airp.',
    'PTTP' => 'Pohnpei, NWS Office',
    'PTKK' => 'Weno Island, Chuuk Int. Airp.',
    'PTYA' => 'Yap Island, Yap Int. Airp.',
  );
  
  $icao_codes['Moldova'] = array(
    'LUKK' => 'Chisinau International Airport',
  );
  
  $icao_codes['Mongolia'] = array(
    'ZMUB' => 'Ulan-Bator',
  );
  
  $icao_codes['Morocco'] = array(
    'GMAD' => 'Agadir Al Massira',
    'GMTA' => 'Al Hoceima',
    'GMMC' => 'Casablanca',
    'GMFF' => 'Fes-Sais',
    'GMML' => 'Laayoune/Hassan Isl',
    'GMMX' => 'Marrakech',
    'GMFM' => 'Meknes',
    'GMMW' => 'Nador/Arwi',
    'GMMN' => 'Nouasseur',
    'GMMZ' => 'Ouarzazate',
    'GMFO' => 'Oujda',
    'GMME' => 'Rabat-Sale',
    'GMTT' => 'Tanger Aerodrome',
    'GMTN' => 'Tetuan / Sania Ramel',
  );
  
  $icao_codes['Mozambique'] = array(
    'FQBR' => 'Beira',
    'FQCH' => 'Chimoio',
    'FQIN' => 'Inhambane',
    'FQLC' => 'Lichinga',
    'FQMA' => 'Maputo / Mavalane',
    'FQNP' => 'Nampula',
    'FQPB' => 'Pemba',
    'FQQL' => 'Quelimane',
    'FQVL' => 'Vilanculos',
  );
  
  $icao_codes['Myanmar'] = array(
    'VYYY' => 'Yangon',
  );
  
  $icao_codes['Namibia'] = array(
    'FYOA' => 'Ondangwa',
    'FYWB' => 'Walvis Bay',
    'FYWW' => 'Windhoek, Town MET',
  );
  
  $icao_codes['Netherlands'] = array(
    'EHAM' => 'Amsterdam Airport Schiphol',
    'EHKD' => 'De Kooy',
    'EHDL' => 'Deelen',
    'EHEH' => 'Eindhoven',
    'EHGR' => 'Gilze-Rijen',
    'EHGG' => 'Groningen Airport Eelde',
    'EHLW' => 'Leeuwarden',
    'EHBK' => 'Maastricht Airport Zuid Limburg',
    'EHRD' => 'Rotterdam Airport Zestienhoven',
    'EHSB' => 'Soesterberg',
    'EHTW' => 'Twenthe',
    'EHVB' => 'Valkenburg',
    'EHVL' => 'Vlieland',
    'EHVK' => 'Volkel',
    'EHWO' => 'Woensdrecht',
  );
  
  $icao_codes['Netherlands Antilles'] = array(
    'TNCB' => 'Flamingo Airport, Bonaire',
    'TNCC' => 'Hato Airport, Curacao',
    'TNCM' => 'Juliana Airport, Saint Maarten',
    'TNCE' => 'Roosevelt Airport Saint Eustatius',
  );
  
  $icao_codes['New Caledonia'] = array(
    'NWWW' => 'La Tontouta Nlle-Caledonie',
  );
  
  $icao_codes['New Zealand'] = array(
    'NZAA' => 'Auckland Airport',
    'NZCH' => 'Christchurch',
    'PLCH' => 'Christmas / Cassidy',
    'NZOH' => 'Ohakea',
    'NZWN' => 'Wellington Airport',
  );
  
  $icao_codes['Nicaragua'] = array(
    'MNBL' => 'Bluefields',
    'MNCH' => 'Chinandega',
    'MNJG' => 'Jinotega',
    'MNJU' => 'Juigalpa',
    'MNMG' => 'Managua A. C. Sandino',
    'MNPC' => 'Puerto Cabezas',
    'MNRS' => 'Rivas',
  );
  
  $icao_codes['Niger'] = array(
    'DRZA' => 'Agadez',
    'DRRN' => 'Niamey-Aero',
    'DRZR' => 'Zinder',
  );
  
  $icao_codes['Nigeria'] = array(
    'DNCA' => 'Calabar',
    'DNEN' => 'Enugu',
    'DNIL' => 'Ilorin',
    'DNKA' => 'Kaduna',
    'DNKN' => 'Kano',
    'DNMM' => 'Lagos / Ikeja',
    'DNMA' => 'Maiduguri',
    'DNPO' => 'Port Harcourt',
    'DNSO' => 'Sokoto',
  );
  
  $icao_codes['Norway'] = array(
    'ENAL' => 'Alesund / Vigra',
    'ENAT' => 'Alta Lufthavn',
    'ENAN' => 'Andoya',
    'ENNA' => 'Banak',
    'ENDU' => 'Bardufoss',
    'ENBS' => 'Batsfjord',
    'ENBR' => 'Bergen / Flesland',
    'ENBV' => 'Berlevag',
    'ENBO' => 'Bodo Vi',
    'ENBN' => 'Bronnoysund / Bronnoy',
    'ENDR' => 'Draugen',
    'ENEK' => 'Ekofisk Oil Platform',
    'ENEV' => 'Evenes',
    'ENFG' => 'Fagernes Leirin',
    'ENFL' => 'Floro',
    'ENBL' => 'Forde / Bringeland',
    'ENFR' => 'Frigg',
    'ENGC' => 'Gullfax Platform',
    'ENHF' => 'Hammerfest',
    'ENHK' => 'Hasvik',
    'ENHD' => 'Haugesund / Karmoy',
    'ENHE' => 'Heidrun',
    'ENHV' => 'Honningsvag / Valan',
    'ENKR' => 'Kirkenes Lufthavn',
    'ENCN' => 'Kristiansand / Kjevik',
    'ENKB' => 'Kristiansund / Kvernberget',
    'ENLK' => 'Leknes',
    'ENLI' => 'Lista Flyplass',
    'ENMH' => 'Mehamn',
    'ENRA' => 'Mo I Rana / Rossvoll',
    'ENML' => 'Molde / Aro',
    'ENMS' => 'Mosjoen Kjaerstad',
    'ENNM' => 'Namsos Lufthavn',
    'ENNK' => 'Narvik Iii',
    'ENNO' => 'Notodden',
    'ENOL' => 'Orland Iii',
    'ENOV' => 'Orsta-Volda / Hovden',
    'ENOA' => 'Oseberg',
    'ENGM' => 'Oslo / Gardermoen',
    'ENRO' => 'Roros Lufthavn',
    'ENRM' => 'Rorvik / Ryum',
    'ENRS' => 'Rost Flyplass',
    'ENRY' => 'Rygge',
    'ENSD' => 'Sandane / Anda',
    'ENST' => 'Sandnessjoen / Stokka',
    'ENSN' => 'Skien-Geiteryggen',
    'ENSG' => 'Sogndal / Haukasen',
    'ENSR' => 'Sorkjosen',
    'ENZV' => 'Stavanger / Sola',
    'ENSO' => 'Stord / Soerstokken',
    'ENSK' => 'Storkmarknes / Skagen',
    'ENSB' => 'Svalbard Lufthavn',
    'ENSS' => 'Svartnes',
    'ENSH' => 'Svolvaer / Helle',
    'ENTO' => 'Torp',
    'ENTC' => 'Tromso / Langnes',
    'ENVA' => 'Trondheim / Vaernes',
    'ENVD' => 'Vadso',
  );
  
  $icao_codes['Oman'] = array(
    'OOSA' => 'Salalah',
    'OOMS' => 'Seeb, International Airport',
  );
  
  $icao_codes['Pakistan'] = array(
    'OPRN' => 'Islamabad Airport',
    'OPKC' => 'Karachi Airport',
    'OPLA' => 'Lahore Airport',
    'OPNH' => 'Nawabshah',
    'OPPS' => 'Peshawar',
  );
  
  $icao_codes['Palau'] = array(
    'PTRO' => 'Babelthuap Island, Babelthuap/Koror Airport',
    'PTKR' => 'Koror, Palau, NWS Office',
  );
  
  $icao_codes['Panama'] = array(
    'MPBO' => 'Bocas Del Toro International',
    'MPCH' => 'Changuinola / Captain Manuel Nino',
    'MPDA' => 'David',
    'MPMG' => 'Marcos A. Gelabert',
    'MPTO' => 'Tocumen',
  );
  
  $icao_codes['Papua New Guinea'] = array(
    'AYMO' => 'Manus Island/Momote',
    'AYPY' => 'Moresby',
  );
  
  $icao_codes['Paraguay'] = array(
    'SGES' => 'Aeropuerto Guarany',
    'SGAS' => 'Asuncion / Aeropuerto',
  );
  
  $icao_codes['Peru'] = array(
    'SPHY' => 'Andahuayla',
    'SPQU' => 'Arequipa',
    'SPHI' => 'Chiclayo',
    'SPZO' => 'Cuzco',
    'SPQT' => 'Iquitos',
    'SPIM' => 'Lima-Callao / Aerop. Internacional Jorgechavez',
    'SPSO' => 'Pisco',
    'SPTN' => 'Tacna',
    'SPYL' => 'Talara',
    'SPRU' => 'Trujillo',
  );
  
  $icao_codes['Philippines'] = array(
    'RPLC' => 'Clarkfield Pampanga International Airport',
    'RPMD' => 'Davao Airport',
    'RPLI' => 'Laoag',
    'RPVM' => 'Masbate',
    'RPLL' => 'Ninoy Aquino Inter-National Airport',
    'RPLB' => 'Subic Bay Weather Station',
    'RPMZ' => 'Zamboanga',
  );
  
  $icao_codes['Poland'] = array(
    'EPGD' => 'Gdansk-Rebiechowo',
    'EPKT' => 'Katowice',
    'EPKK' => 'Krakow',
    'EPPO' => 'Poznan',
    'EPRZ' => 'Rzeszow-Jasionka',
    'EPSC' => 'Szczecin',
    'EPWA' => 'Warszawa-Okecie',
    'EPWR' => 'Wroclaw Ii',
  );
  
  $icao_codes['Portugal'] = array(
    'LPMA' => 'Aeroporto Da Madeira',
    'LPFR' => 'Faro / Aeroporto',
    'LPFL' => 'Flores Acores',
    'LPHR' => 'Horta / Castelo Branco Acores',
    'LPLA' => 'Lajes Acores',
    'LPPT' => 'Lisboa / Portela',
    'LPPD' => 'Ponta Delgada / Nordela Acores',
    'LPPR' => 'Porto / Pedras Rubras',
    'LPPS' => 'Porto Santo',
    'LPAZ' => 'Santa Maria Acores',
  );
  
  $icao_codes['Qatar'] = array(
    'KQIR' => 'Al Udeid',
    'OTBD' => 'Doha International Airport',
  );
  
  $icao_codes['Reunion'] = array(
    'FMEE' => 'Saint-Denis / Gillot',
    'FMEP' => 'Saint-Pierre',
  );
  
  $icao_codes['Romania'] = array(
    'LRAR' => 'Arad',
    'LRBS' => 'Bucuresti / Imh',
    'LROP' => 'Bucuresti Otopeni',
    'LRCK' => 'Kogalniceanu',
    'LRTR' => 'Timisoara',
    'LRTM' => 'Tirgu Mures',
    'LRTC' => 'Tulcea',
  );
  
  $icao_codes['Russia'] = array(
    'UNAA' => 'Abakan',
    'URSS' => 'Adler',
    'UHMA' => 'Anadyr',
    'URKA' => 'Anapa / Vitiazevo',
    'ULAA' => 'Arhangel\'Sk',
    'URWA' => 'Astrakhan',
    'UNBB' => 'Barnaul',
    'UIBB' => 'Bratsk / Irkutsk',
    'UUBP' => 'Brjansk',
    'UHMD' => 'Buhta Providenja',
    'USCC' => 'Chelyabinsk-Balandino',
    'UIAA' => 'Chita',
    'UELL' => 'Cul\'Man',
    'USSS' => 'Ekaterinburg',
    'URWI' => 'Elista',
    'UHHH' => 'Habarovsk',
    'UIII' => 'Irkutsk',
    'UEEE' => 'Jakutsk',
    'UMKK' => 'Kaliningrad/Khrabrovo Airport',
    'UWKD' => 'Kazan\'',
    'UNEE' => 'Kemerovo',
    'URKK' => 'Krasnodar',
    'URMM' => 'Mineral\'Nye Vody',
    'UERR' => 'Mirny',
    'UUDD' => 'Moscow / Domodedovo',
    'UUEE' => 'Moscow / Sheremet\'Ye',
    'UUWW' => 'Moscow / Vnukovo',
    'ULMM' => 'Murmansk',
    'URMN' => 'Nalchik',
    'USNN' => 'Nizhnevartovsk',
    'UWGG' => 'Nizhny Novgorod/Strigino',
    'UNWW' => 'Novokuznetsk',
    'UNOO' => 'Omsk',
    'UWOO' => 'Orenburg / Tsentralny',
    'UWPP' => 'Penza',
    'USPP' => 'Perm\'/Bolshoe Savino',
    'UHPP' => 'Petropavlovsk-Kamchatskij',
    'UERP' => 'Polyarny',
    'URRR' => 'Rostov-Na-Donu',
    'UWWW' => 'Samara',
    'UWSS' => 'Saratov / Tsentralny',
    'ULLI' => 'St. Peterburg',
    'URMT' => 'Stavropol / Shpakovskoye',
    'USRR' => 'Surgut',
    'UUYY' => 'Syktyvkar',
    'UEST' => 'Tiksi',
    'UUEM' => 'Tver',
    'UWUU' => 'Ufa',
    'UIUU' => 'Ulan-Ude',
    'UWLW' => 'Ulyanovsk',
    'ULOL' => 'Velikie Luki',
    'UHWW' => 'Vladivostok',
    'URWW' => 'Volgograd',
    'ULWW' => 'Vologda',
    'UUOO' => 'Voronez',
    'UHSS' => 'Yuzhno-Sakhalinsk',
  );
  
  $icao_codes['Saint Helena'] = array(
    'FHAW' => 'Wide Awake Field Ascension Island',
  );
  
  $icao_codes['Saint Kitts and Nevis'] = array(
    'TKPK' => 'Golden Rock',
  );
  
  $icao_codes['Saint Lucia'] = array(
    'TLPL' => 'Hewanorra International Airport',
    'TLPC' => 'Vigie',
  );
  
  $icao_codes['Saint Pierre and Miquelon'] = array(
    'LFVP' => 'Saint-Pierre',
  );
  
  $icao_codes['Saint Vincent and the Grenadines'] = array(
    'TVSV' => 'Arnos Vale',
  );
  
  $icao_codes['Samoa'] = array(
    'NSFA' => 'Faleolo Intl / Apia',
  );
  
  $icao_codes['Saudi Arabia'] = array(
    'OEAB' => 'Abha',
    'OEAH' => 'Al Ahsa',
    'OEBA' => 'Al Baha',
    'OEPA' => 'Al Qaysumah',
    'OESK' => 'Al-Jouf',
    'OERR' => 'Arar',
    'OEBH' => 'Bisha',
    'OEDF' => 'Dammam-King Fahd International Airport',
    'OEDR' => 'Dhahran',
    'OEGS' => 'Gassim',
    'OEGN' => 'Gizan',
    'OEGT' => 'Guriat',
    'OEKK' => 'Hafr Al-Batin',
    'OEHL' => 'Hail',
    'OEJN' => 'Jeddah King Abdul Aziz International Airport',
    'OEKM' => 'Khamis Mushait',
    'OERK' => 'King Khaled International Airport',
    'OEMA' => 'Madinah',
    'OEMK' => 'Makkah',
    'OENG' => 'Najran',
    'OERF' => 'Rafha',
    'OERY' => 'Riyadh',
    'OESH' => 'Sharurah',
    'OETB' => 'Tabuk',
    'OETF' => 'Taif',
    'OETR' => 'Turaif',
    'OEWD' => 'Wadi Al Dawasser Airport',
    'OEWJ' => 'Wejh',
    'OEYN' => 'Yenbo',
  );
  
  $icao_codes['Senegal'] = array(
    'GOGS' => 'Cap-Skirring',
    'GOOY' => 'Dakar / Yoff',
    'GOSS' => 'Saint-Louis',
    'GOTT' => 'Tambacounda',
    'GOGG' => 'Ziguinchor',
  );
  
  $icao_codes['Serbia and Montenegro'] = array(
    'LYBE' => 'Beograd / Surcin',
    'KQUK' => 'Camp Bondsteel',
    'LYNI' => 'Nis',
    'LYPG' => 'Podgorica Titograd',
    'LYTV' => 'Tivat',
  );
  
  $icao_codes['Seychelles'] = array(
    'FSIA' => 'Seychelles Inter-National Airport',
  );
  
  $icao_codes['Sierra Leone'] = array(
    'GFLL' => 'Lungi',
  );
  
  $icao_codes['Singapore'] = array(
    'WSSS' => 'Singapore / Changi Airport',
    'WSAP' => 'Singapore / Paya Lebar',
  );
  
  $icao_codes['Slovakia'] = array(
    'LZIB' => 'Bratislava Ivanka',
    'LZZI' => 'Dolny Hricov',
    'LZKC' => 'Kamenica Nad Cirochou',
    'LZKZ' => 'Kosice, Barca',
    'LZLU' => 'Lucenec',
    'LZNI' => 'Nitra',
    'LZPP' => 'Piestany',
    'LZTT' => 'Poprad / Tatry',
    'LZPE' => 'Prievidza',
    'LZSL' => 'Sliac',
  );
  
  $icao_codes['Slovenia'] = array(
    'LJLJ' => 'Ljubljana / Brnik',
    'LJMB' => 'Maribor / Slivnica',
    'LJPZ' => 'Portoroz',
  );
  
  $icao_codes['Solomon Islands'] = array(
    'AGGH' => 'Honiara / Henderson',
  );
  
  $icao_codes['Somalia'] = array(
    'HCMI' => 'Berbera',
    'HCMV' => 'Burao',
    'HCMH' => 'Hargeisa',
  );
  
  $icao_codes['South Africa'] = array(
    'FAAB' => 'Alexander Bay',
    'FABL' => 'Bloemfontein, Bloemfontein Airport',
    'FACT' => 'Cape Town, Cape Town International Airport',
    'FADN' => 'Durban, Durban International Airport',
    'FAEL' => 'East London, East London Airport',
    'FAGG' => 'George, George Airport',
    'FAJS' => 'Johannesburg International Airport',
    'FAKM' => 'Kimberley, Kim-Apt',
    'FAKD' => 'Klerksdorp',
    'FALA' => 'Lanseria',
    'FAMM' => 'Mafikeng Intl. Ad',
    'FANS' => 'Nelspruit',
    'FAPE' => 'Port Elizabeth, Port E Apt',
    'FAPS' => 'Potchefstroom',
    'FAGM' => 'Rand',
    'FARG' => 'Rustenburg',
    'FASR' => 'Standerton',
    'FAUP' => 'Upington, Up-Apt',
    'FAVV' => 'Vereeniging',
    'FAWK' => 'Waterkloof (SAAF)',
  );
  
  $icao_codes['South Georgia and the Islands'] = array(
    'EGYP' => 'Mount Pleasant Airport',
  );
  
  $icao_codes['Spain'] = array(
    'LEAB' => 'Albacete / Los Llanos',
    'LEAL' => 'Alicante / El Altet',
    'LEAM' => 'Almeria / Aeropuerto',
    'LEAS' => 'Asturias / Aviles',
    'LEBZ' => 'Badajoz / Talavera La Real',
    'LEBL' => 'Barcelona / Aeropuerto',
    'LEBB' => 'Bilbao / Sondica',
    'LEBA' => 'Cordoba / Aeropuerto',
    'GCFV' => 'Fuerteventura / Aeropuerto',
    'LEGE' => 'Gerona / Costa Brava',
    'GCLP' => 'Gran Canaria - Canary Islands',
    'LEGR' => 'Granada / Aeropuerto',
    'LEGA' => 'Granada / Armilla',
    'GCHI' => 'Hierro / Aeropuerto',
    'LEIB' => 'Ibiza / Es Codola',
    'LEJR' => 'Jerez De La Fronteraaeropuerto',
    'LECO' => 'La Coruna / Alvedro',
    'GCLA' => 'La Palma / Aeropuerto',
    'GCRR' => 'Lanzarote / Aeropuerto',
    'LELN' => 'Leon / Virgen Del Camino',
    'LEMD' => 'Madrid / Barajas',
    'LEVS' => 'Madrid / Cuatro Vientos',
    'LEGT' => 'Madrid / Getafe',
    'LETO' => 'Madrid / Torrejon',
    'LEMG' => 'Malaga / Aeropuerto',
    'GEML' => 'Melilla',
    'LEMH' => 'Menorca / Mahon',
    'LEMO' => 'Moron De La Frontera',
    'LERI' => 'Murcia / Alcantarilla',
    'LELC' => 'Murcia / San Javier',
    'LEPA' => 'Palma De Mallorca / Son San Juan',
    'LEPP' => 'Pamplona / Noain',
    'LERS' => 'Reus / Aeropuerto',
    'LERT' => 'Rota',
    'LESA' => 'Salamanca / Matacan',
    'LESO' => 'San Sebastian / Fuenterrabia',
    'LEXJ' => 'Santander / Parayas',
    'LEST' => 'Santiago / Labacolla',
    'LEZL' => 'Sevilla / San Pablo',
    'GCXO' => 'Tenerife / Los Rodeos',
    'GCTS' => 'Tenerife Sur',
    'LEVC' => 'Valencia / Aeropuerto',
    'LEVD' => 'Valladolid / Villanubla',
    'LEVX' => 'Vigo / Peinador',
    'LEVT' => 'Vitoria',
    'LEZG' => 'Zaragoza / Aeropuerto',
  );
  
  $icao_codes['Sri Lanka'] = array(
    'VCBI' => 'Katunayake',
  );
  
  $icao_codes['Suriname'] = array(
    'SMJP' => 'Johan A. Pengel',
  );
  
  $icao_codes['Swaziland'] = array(
    'FDMS' => 'Manzini / Matsapa Airport',
  );
  
  $icao_codes['Sweden'] = array(
    'ESSD' => 'Borlange',
    'ESNG' => 'Gallivare',
    'ESGG' => 'Goteborg / Landvetter',
    'ESGP' => 'Goteborg / Save',
    'ESMT' => 'Halmstad Swedish Air Force Base',
    'ESSF' => 'Hultsfred Swedish Air Force Base',
    'ESGJ' => 'Jonkoping Flygplats',
    'ESMQ' => 'Kalmar',
    'ESOK' => 'Karlstad',
    'ESNQ' => 'Kiruna Airport',
    'ESNK' => 'Kramfors Flygplats',
    'ESMK' => 'Kristianstad / Everod',
    'ESSL' => 'Linkoping / Saab',
    'ESTL' => 'Ljungbyhed',
    'ESPA' => 'Lulea / Kallax',
    'ESNL' => 'Lycksele',
    'ESMS' => 'Malmo / Sturup',
    'ESSP' => 'Norrkoping',
    'ESOE' => 'Orebro Private',
    'ESPC' => 'Ostersund / Froson',
    'ESDF' => 'Ronneby',
    'ESNS' => 'Skelleftea Airport',
    'ESGR' => 'Skovde Flygplats',
    'ESNY' => 'Soderhamn',
    'ESSA' => 'Stockholm / Arlanda',
    'ESSB' => 'Stockholm / Bromma',
    'ESKN' => 'Stockholm/Skavsta',
    'ESNN' => 'Sundsvall-Harnosand Flygplats',
    'ESGT' => 'Trollhattan Private',
    'ESNU' => 'Umea Flygplats',
    'ESOW' => 'Vasteras / Hasslo',
    'ESMX' => 'Vaxjo',
    'ESSV' => 'Visby Flygplats',
  );
  
  $icao_codes['Switzerland'] = array(
    'LSZB' => 'Bern / Belp',
    'LSGG' => 'Geneve-Cointrin',
    'LSZA' => 'Lugano',
    'LSZH' => 'Zurich-Kloten',
  );
  
  $icao_codes['Syria'] = array(
    'OSAP' => 'Aleppo International Airport',
    'OSDI' => 'Damascus Int. Airport',
    'OSDZ' => 'Deir Ezzor',
    'OSKL' => 'Kamishli',
    'OSLK' => 'Lattakia',
  );
  
  $icao_codes['Taiwan'] = array(
    'RCTP' => 'Chiang Kai Shek',
    'RCKH' => 'Kaohsiung International Airport',
    'RCSS' => 'Sungshan / Taipei',
  );
  
  $icao_codes['Tajikistan'] = array(
    'UTDD' => 'Dushanbe',
  );
  
  $icao_codes['Thailand'] = array(
    'VTCC' => 'Chiang Mai',
    'VTBD' => 'Don Muang',
    'VTSS' => 'Hat Yai',
    'VTPH' => 'Hua Hin',
    'VTUK' => 'Khon Kaen',
    'VTCL' => 'Lampang',
    'VTUL' => 'Loei',
    'VTCH' => 'Mae Hong Son',
    'VTPM' => 'Mae Sot',
    'VTCN' => 'Nan',
    'VTCP' => 'Phrae',
    'VTSP' => 'Phuket Airport',
    'VTSR' => 'Ranong',
    'VTBU' => 'Rayong',
    'VTSB' => 'Surat Thani',
    'VTST' => 'Trang',
    'VTUU' => 'Ubon Ratchathani',
    'VTUD' => 'Udon Thani',
  );
  
  $icao_codes['Togo'] = array(
    'DXXX' => 'Lome',
    'DXNG' => 'Niamtougou',
  );
  
  $icao_codes['Tonga'] = array(
    'NFTF' => 'Fua\'Amotu',
  );
  
  $icao_codes['Trinidad and Tobago'] = array(
    'TTCP' => 'Crown Pt./ Scarborou',
    'TTPP' => 'Piarco International Airport, Trinidad',
  );
  
  $icao_codes['Tunisia'] = array(
    'DTTB' => 'Bizerte',
    'DTTJ' => 'Djerba Mellita',
    'DTTR' => 'El Borma',
    'DTTG' => 'Gabes',
    'DTTF' => 'Gafsa',
    'DTMB' => 'Habib Bourguiba',
    'DTTN' => 'Jendouba',
    'DTTK' => 'Kairouan',
    'DTTL' => 'Kelibia',
    'DTTD' => 'Remada',
    'DTTX' => 'Sfax El-Maou',
    'DTKA' => 'Tabarka',
    'DTTZ' => 'Tozeur',
    'DTTA' => 'Tunis-Carthage',
  );
  
  $icao_codes['Turkey'] = array(
    'LTAG' => 'Adana / Incirlik',
    'LTAF' => 'Adana / Sakirpasa',
    'LTAC' => 'Ankara / Esenboga',
    'LTAD' => 'Ankara / Etimesgut',
    'LTAB' => 'Ankara / Guvercin Lik',
    'LTAI' => 'Antalya',
    'LTBF' => 'Balikesir',
    'LTBG' => 'Bandirma',
    'LTCJ' => 'Batman',
    'LTFE' => 'Bodrum Milas Airport',
    'LTBR' => 'Bursa / Yenisehir, Mil-Civ',
    'LTBU' => 'Corlu',
    'LTBS' => 'Dalaman',
    'LTCC' => 'Diyarbakir',
    'LTCA' => 'Elazig',
    'LTCD' => 'Erzincan',
    'LTCE' => 'Erzurum',
    'LTBI' => 'Eskisehir',
    'LTAJ' => 'Gaziantep',
    'LTBA' => 'Istanbul / Ataturk',
    'LTFJ' => 'Istanbul / Sabiha Gokcen',
    'LTBJ' => 'Izmir / Adnan Menderes',
    'LTBL' => 'Izmir / Cigli',
    'LTCF' => 'Kars',
    'LTAU' => 'Kayseri / Erkilet',
    'LTAN' => 'Konya',
    'LTAT' => 'Malatya / Erhac',
    'LTAP' => 'Merzifon',
    'LTAE' => 'Murted Tur-Afb',
    'LTAZ' => 'Nevsehir',
    'LTFH' => 'Samsun / Carsamba',
    'LTFC' => 'Suleyman Demirel',
    'LTBQ' => 'Topel Tur-Afb',
    'LTCG' => 'Trabzon',
    'LTCI' => 'Van',
  );
  
  $icao_codes['Turkmenistan'] = array(
    'UTAA' => 'Ashgabat',
  );
  
  $icao_codes['Turks and Caicos Islands'] = array(
    'MBPV' => 'Providenciales',
  );
  
  $icao_codes['Tuvalu'] = array(
    'NGFU' => 'Funafuti',
  );
  
  $icao_codes['Uganda'] = array(
    'HUAR' => 'Arua',
    'HUEN' => 'Entebbe Airport',
    'HUGU' => 'Gulu',
    'HUJI' => 'Jinja',
    'HUKB' => 'Kabale',
    'HUKS' => 'Kasese',
    'HULI' => 'Lira',
    'HUMI' => 'Masindi',
    'HUMA' => 'Mbarara',
    'HUSO' => 'Soroti',
    'HUTO' => 'Tororo',
  );
  
  $icao_codes['Ukraine'] = array(
    'UKBB' => 'Boryspil',
    'UKLN' => 'Chernovsty',
    'UKDD' => 'Dnipropetrovs\'k',
    'UKCC' => 'Donetsk',
    'UKKM' => 'Hostomel',
    'UKLI' => 'Ivano-Frankivsk',
    'UKHH' => 'Kharkiv',
    'UKDR' => 'Krivyy Rih / Dnipropetrovs\'k',
    'UKKK' => 'Kyiv',
    'UKLL' => 'L\'Viv',
    'UKON' => 'Mykolaiv',
    'UKOO' => 'Odesa',
    'UKLR' => 'Rivne',
    'UKFF' => 'Simferopol',
    'UKLU' => 'Uzhhorod',
    'UKDE' => 'Zaporizhzhia / Mokraya',
  );
  
  $icao_codes['United Arab Emirates'] = array(
    'OMAA' => 'Abu Dhabi International Airport',
    'OMAL' => 'Al Ain International Airport',
    'OMDB' => 'Dubai International Airport',
    'OMFJ' => 'Fujairah',
    'OMRK' => 'Ras Al Khaimah International Airport',
    'OMSJ' => 'Sharjah International Airport',
  );
  
  $icao_codes['United Kingdom'] = array(
    'EGPD' => 'Aberdeen / Dyce',
    'EGJA' => 'Alderney / Channel Island',
    'EGYE' => 'Barkston Heath Royal Air Force Base',
    'EGAA' => 'Belfast / Aldergrove Airport',
    'EGAC' => 'Belfast / Harbour',
    'EGPL' => 'Benbecula',
    'EGUB' => 'Benson',
    'EGKB' => 'Biggin Hill',
    'EGBB' => 'Birmingham / Airport',
    'EGNH' => 'Blackpool Airport',
    'EGDM' => 'Boscombe Down',
    'EGHH' => 'Bournemouth Airport',
    'EGGD' => 'Bristol / Lulsgate',
    'EGVN' => 'Brize Norton',
    'EGSC' => 'Cambridge',
    'EGEC' => 'Campbeltown',
    'EGFF' => 'Cardiff-Wales Airport',
    'EGNC' => 'Carlisle',
    'EGXG' => 'Church Fenton',
    'EGXC' => 'Coningsby Royal Air Force Base',
    'EGWC' => 'Cosford Royal Air Force Base',
    'EGXJ' => 'Cottesmore',
    'EGBE' => 'Coventry Airport',
    'EGTC' => 'Cranfield',
    'EGYD' => 'Cranwell',
    'EGDR' => 'Culdrose',
    'EGXD' => 'Disforth',
    'EGPN' => 'Dundee / Riverside',
    'EGNX' => 'East Midlands',
    'EGPH' => 'Edinburgh Airport',
    'EGAE' => 'Eglinton / Londonderr',
    'EGTE' => 'Exeter Airport',
    'EGLF' => 'Farnborough',
    'EGTG' => 'Filton Private',
    'EGPF' => 'Glasgow Airport',
    'EGJB' => 'Guernsey Airport',
    'EGNR' => 'Hawarden',
    'EGYH' => 'Holbeach',
    'EGNJ' => 'Humberside',
    'EGPE' => 'Inverness / Dalcross',
    'EGPI' => 'Islay',
    'EGNS' => 'Isle Of Man / Ronaldsway Airport',
    'EGJJ' => 'Jersey Airport',
    'EGQK' => 'Kinloss',
    'EGPA' => 'Kirkwall Airport',
    'EGUL' => 'Lakenheath Royal Air Force Base',
    'EGNM' => 'Leeds And Bradford',
    'EGXE' => 'Leeming',
    'EGQL' => 'Leuchars',
    'EGXU' => 'Linton-On-Ouse',
    'EGGP' => 'Liverpool Airport',
    'EGKK' => 'London / Gatwick Airport',
    'EGLL' => 'London / Heathrow Airport',
    'EGLC' => 'London City Airport',
    'EGQS' => 'Lossiemouth',
    'EGGW' => 'Luton Airport',
    'EGMD' => 'Lydd Airport',
    'EGDL' => 'Lyneham',
    'EGCC' => 'Manchester Airport',
    'EGMH' => 'Manston, South East',
    'EGYM' => 'Marham',
    'EGVP' => 'Middle Wallop',
    'EGUN' => 'Mildenhall Royal Air Force Base',
    'EGNT' => 'Newcastle',
    'EGWU' => 'Northolt',
    'EGSH' => 'Norwich Weather Centre',
    'EGVO' => 'Odiham',
    'EGOP' => 'Pembrey Sands',
    'EGHD' => 'Plymouth / Roborough',
    'EGPK' => 'Prestwick Airport',
    'EGDG' => 'Saint Mawgan',
    'EGPM' => 'Scatsa / Shetland Island',
    'EGHE' => 'Scilly, Saint Mary\'S',
    'EGOS' => 'Shawbury',
    'EGKA' => 'Shoreham Airport',
    'EGHI' => 'Southampton / Weather Centre',
    'EGMC' => 'Southend-On-Sea',
    'EGOM' => 'Spadeadam',
    'EGDX' => 'St Athan Royal Air Force Base',
    'EGSS' => 'Stansted Airport',
    'EGBJ' => 'Staverton Private',
    'EGPO' => 'Stornoway',
    'EGPB' => 'Sumburgh Cape',
    'EGQA' => 'Tain Range',
    'EGNV' => 'Tees-Side',
    'EGXZ' => 'Topcliffe Royal Air Force Base',
    'EGOV' => 'Valley',
    'EGXW' => 'Waddington',
    'EGYW' => 'Wainfleet',
    'EGUW' => 'Wattisham',
    'EGPC' => 'Wick',
    'EGXT' => 'Wittering',
    'EGUY' => 'Wyton Royal Air Force Base',
    'EGDY' => 'Yeovilton',
  );
  
  $icao_codes['United States of America'] = array(
    'PADK' => 'AK - Adak Island, Adak Airport',
    'PAFM' => 'AK - Ambler, Ambler Airport',
    'PAKP' => 'AK - Anaktuvuk Pass, Anaktuvuk Pass Airport',
    'PAED' => 'AK - Anchorage, Elmendorf Air Force Base',
    'PALH' => 'AK - Anchorage, Lake Hood Seaplane Base',
    'PAMR' => 'AK - Anchorage, Merrill Field Airport',
    'PANC' => 'AK - Anchorage, Ted Stevens Anchorage International Airport',
    'PAGN' => 'AK - Angoon',
    'PANI' => 'AK - Aniak, Aniak Airport',
    'PANT' => 'AK - Annette, Annette Island Airport',
    'PANV' => 'AK - Anvik, Anvik Airport',
    'PARC' => 'AK - Arctic Village, Arctic Village Airport',
    'PAAK' => 'AK - Atka, Atka Airport',
    'PABR' => 'AK - Barrow, Wiley Post-Will Rogers Memorial Airport',
    'PABA' => 'AK - Barter Island, Barter Island LRRS Airport',
    'PABE' => 'AK - Bethel, Bethel Airport',
    'PABT' => 'AK - Bettles, Bettles Airport',
    'PALV' => 'AK - Big River Lake',
    'PABV' => 'AK - Birchwood, Birchwood Airport',
    'PABL' => 'AK - Buckland, Buckland Airport',
    'PATW' => 'AK - Cantwell, Cantwell Airport',
    'PALU' => 'AK - Cape Lisburne, Cape Lisburne LRRS Airport',
    'PAEH' => 'AK - Cape Newenham, Cape Newenham LRRS Airport',
    'PACZ' => 'AK - Cape Romanzof, Cape Romanzof LRRS Airport',
    'PARL' => 'AK - Central, Central Airport',
    'PALR' => 'AK - Chandalar Lake, Chandalar Lake Airport',
    'PAJC' => 'AK - Chignik, Chignik Airport',
    'PAEC' => 'AK - Chulitna, Chulitna Airport',
    'PACD' => 'AK - Cold Bay, Cold Bay Airport',
    'PACV' => 'AK - Cordova, Merle K (Mudhole) Smith Airport',
    'PALP' => 'AK - Deadhorse, Alpine Airstrip',
    'PASC' => 'AK - Deadhorse, Deadhorse Airport',
    'PADE' => 'AK - Deering, Deering/New Airport',
    'PABI' => 'AK - Delta Junction/Ft Greely, Allen Army Airfield',
    'PADL' => 'AK - Dillingham, Dillingham Airport',
    'PAEG' => 'AK - Eagle, Eagle Airport',
    'PAII' => 'AK - Egegik, Egegik Airport',
    'PAEL' => 'AK - Elfin Cove, Elfin Cove Seaplane Base',
    'PAEM' => 'AK - Emmonak, Emmonak Airport',
    'PAZK' => 'AK - Eureka, Skelton Airport',
    'PAEI' => 'AK - Fairbanks, Eielson Air Force Base',
    'PAFA' => 'AK - Fairbanks, Fairbanks International Airport',
    'PAFK' => 'AK - Farewell Lake, Farewell Lake Seaplane Base',
    'PAFB' => 'AK - Fort Wainwright AAF',
    'PFYU' => 'AK - Fort Yukon, Fort Yukon Airport',
    'PAGB' => 'AK - Galbraith Lake, Galbraith Lake Airport',
    'PAGA' => 'AK - Galena, Edward G. Pitka Sr. Airport',
    'PAGM' => 'AK - Gambell, Gambell Airport',
    'PAGL' => 'AK - Golovin, Golovin Airport',
    'PAGK' => 'AK - Gulkana, Gulkana Airport',
    'PAGS' => 'AK - Gustavus, Gustavus Airport',
    'PAHN' => 'AK - Haines, Haines Airport',
    'PAHZ' => 'AK - Hayes River, Hayes River Airport',
    'PAHV' => 'AK - Healy, Healy River Airport',
    'PAHO' => 'AK - Homer, Homer Airport',
    'PAOH' => 'AK - Hoonah, Hoonah Seaplane Base',
    'PAHP' => 'AK - Hooper Bay, Hooper Bay Airport',
    'PAHY' => 'AK - Hydaburg, Hydaburg Seaplane Base',
    'PAIL' => 'AK - Iliamna, Iliamna Airport',
    'PAJN' => 'AK - Juneau, Juneau International Airport',
    'PAFE' => 'AK - Kake, Kake Airport',
    'PAKV' => 'AK - Kaltag, Kaltag Airport',
    'PAEN' => 'AK - Kenai, Kenai Municipal Airport',
    'PAKT' => 'AK - Ketchikan, Ketchikan International Airport',
    'PAKN' => 'AK - King Salmon, King Salmon Airport',
    'PAKI' => 'AK - Kipnuk, Kipnuk Airport',
    'PAVL' => 'AK - Kivalina, Kivalina Airport',
    'PAKW' => 'AK - Klawock, Klawock Airport',
    'PADQ' => 'AK - Kodiak, Kodiak Airport',
    'PAOT' => 'AK - Kotzebue, Ralph Wien Memorial Airport',
    'PAKK' => 'AK - Koyuk, Koyuk Airport',
    'PAKU' => 'AK - Kuparuk, Ugnu-Kuparuk Airport',
    'PAML' => 'AK - Manley Hot Springs, Manly Hot Springs Airport',
    'PAMX' => 'AK - McCarthy',
    'PAMC' => 'AK - McGrath, McGrath Airport',
    'PAIN' => 'AK - McKinley Park, McKinley National Park Airport',
    'PAMY' => 'AK - Mekoryuk, Mekoryuk Airport',
    'PAER' => 'AK - Merrill Pass West',
    'PAMM' => 'AK - Metlakatla, Metlakatla Seaplane Base',
    'PAMD' => 'AK - Middleton Island, Middleton Island Airport',
    'PAMH' => 'AK - Minchumina, Minchumina Airport',
    'PABN' => 'AK - Nabesna, Devil Mountain Lodge Airport',
    'PANN' => 'AK - Nenana, Nenana Municipal Airport',
    'PAWN' => 'AK - Noatak, Noatak Airport',
    'PAOM' => 'AK - Nome, Nome Airport',
    'PAOR' => 'AK - Northway, Northway Airport',
    'PAQT' => 'AK - Nuiqsut, Nuiqsut Airport',
    'PAAQ' => 'AK - Palmer, Palmer Municipal Airport',
    'PAXK' => 'AK - Paxson',
    'PAPG' => 'AK - Petersburg',
    'PAPM' => 'AK - Platinum',
    'PAPO' => 'AK - Point Hope, Point Hope Airport',
    'PPIZ' => 'AK - Point Lay, Point Lay LRRS Airport',
    'PAAP' => 'AK - Port Alexander, Port Alexander Seaplane Base',
    'PALJ' => 'AK - Port Alsworth, Port Alsworth Airport',
    'PAPC' => 'AK - Port Clarence, Port Clarence Coast Guard Station',
    'PAPH' => 'AK - Port Heiden, Port Heiden Airport',
    'PATO' => 'AK - Portage, Portage Glacier',
    'PAPR' => 'AK - Prospect Creek, Prospect Creek Airport',
    'PAPT' => 'AK - Puntilla',
    'PARD' => 'AK - Red Dog, Red Dog Airport',
    'PASD' => 'AK - Sand Point',
    'PASA' => 'AK - Savoonga Airport',
    'PASK' => 'AK - Selawik',
    'PASO' => 'AK - Seldovia, Seldovia Airport',
    'PAWD' => 'AK - Seward',
    'PASP' => 'AK - Sheep Mountain, Sheep Mountain Airport',
    'PASY' => 'AK - Shemya, Eareckson AFB',
    'PASH' => 'AK - Shishmaref, Shishmaref Airport',
    'PASI' => 'AK - Sitka, Sitka Airport',
    'PAGY' => 'AK - Skagway',
    'PASW' => 'AK - Skwentna',
    'PADT' => 'AK - Slana Airport',
    'PASL' => 'AK - Sleetmute',
    'PALK' => 'AK - Snowshoe Lake',
    'PASX' => 'AK - Soldotna',
    'PASV' => 'AK - Sparrevohn Airways Facilities Sector',
    'PAPB' => 'AK - St. George, St. George Airport',
    'PASM' => 'AK - St. Mary\'s, St. Mary\'s Airport',
    'PASN' => 'AK - St. Paul Island, St. Paul Island Airport',
    'PAJV' => 'AK - Sutton',
    'PATL' => 'AK - Takotna, Tatalina LRRS Airport',
    'PATK' => 'AK - Talkeetna, Talkeetna Airport',
    'PATA' => 'AK - Tanana, Calhoun Memorial Airport',
    'PATC' => 'AK - Tin City Airways Facilities Sector',
    'PATG' => 'AK - Togiac Village, Togiak Airport',
    'PAUN' => 'AK - Unalakleet',
    'PADU' => 'AK - Unalaska, Unalaska Airport',
    'PAIM' => 'AK - Utopia Creek, Indian Mountain LRRS Airport',
    'PAVD' => 'AK - Valdez 2',
    'PAWI' => 'AK - Wainwright, Wainwright Airport',
    'PAWS' => 'AK - Wasilla, Wasilla Airport',
    'PAWR' => 'AK - Whittier',
    'PAUO' => 'AK - Willow Airport',
    'PAWG' => 'AK - Wrangell',
    'PAYA' => 'AK - Yakutat',
    'KEET' => 'AL - Alabaster, Shelby County Airport',
    'K8A0' => 'AL - Albertville, Albertville Municipal Airport',
    'KALX' => 'AL - Alexander City, Thomas C Russell Field Airport',
    'K79J' => 'AL - Andalusia, Andalusia-Opp Municipal Airport',
    'KANB' => 'AL - Anniston, Anniston Metropolitan Airport',
    'KAUO' => 'AL - Auburn-Opelika Airport',
    'KBHM' => 'AL - Birmingham, Birmingham International Airport',
    'KOZR' => 'AL - Cairns Army Air Field / Ozark',
    'K3A1' => 'AL - Cullman, Folsom Field Airport',
    'KDCU' => 'AL - Decatur, Pryor Field',
    'KDHN' => 'AL - Dothan, Dothan Regional Airport',
    'KGZH' => 'AL - Evergreen, Middleton Field',
    'K0J4' => 'AL - Florala, Florala Municipal Airport',
    'K4A9' => 'AL - Fort Payne, Isbell Field Airport',
    'KGAD' => 'AL - Gadsden, Gadsden Municipal Airport',
    'KHSV' => 'AL - Huntsville, Huntsville International / Jones Field',
    'KMDQ' => 'AL - Huntsville, Madison County Executive Airport',
    'KMXF' => 'AL - Maxwell Air Force Base / Montgomery',
    'KBFM' => 'AL - Mobile, Mobile Downtown Airport',
    'KMOB' => 'AL - Mobile, Mobile Regional Airport',
    'KMGM' => 'AL - Montgomery, Dannelly Field',
    'KMSL' => 'AL - Muscle Shoals, North West Alabama Regional Airport',
    'KTOI' => 'AL - Troy, Troy Municipal Airport',
    'KTCL' => 'AL - Tuscaloosa, Tuscaloosa Regional Airport',
    'KBVX' => 'AR - Batesville, Batesville Regional Airport',
    'KVBT' => 'AR - Bentonville, Bentonville Municipal Airport/Louise M Thaden Field',
    'KHKA' => 'AR - Blytheville, Blytheville Municipal Airport',
    'KDEQ' => 'AR - De Queen, J Lynn Helms Sevier County Airport',
    'KBYH' => 'AR - Eaker Air Force Base',
    'KELD' => 'AR - El Dorado, South Arkansas Regional at Goodwin Field Airport',
    'KFYV' => 'AR - Fayetteville, Drake Field',
    'KXNA' => 'AR - Fayetteville/Springdale, Northwest Arkansas Regional Airport',
    'KFLP' => 'AR - Flippin, Marion County Regional Airport',
    'KFSM' => 'AR - Fort Smith, Fort Smith Regional Airport',
    'KHRO' => 'AR - Harrison, Boone County Airport',
    'KHOT' => 'AR - Hot Springs, Memorial Field Airport',
    'KJBR' => 'AR - Jonesboro, Jonesboro Municipal Airport',
    'KLRF' => 'AR - Little Rock Air Force Base',
    'KLIT' => 'AR - Little Rock, Adams Field',
    'KMEZ' => 'AR - Mena, Mena Intermountain Municipal Airport',
    'KLLQ' => 'AR - Monticello, Monticello Municipal Airport/Ellis Field',
    'KMWT' => 'AR - Mount Ida',
    'KBPK' => 'AR - Mountain Home, Ozark Regional Airport',
    'KM19' => 'AR - Newport, Newport Municipal Airport',
    'KPBF' => 'AR - Pine Bluff, Grider Field Airport',
    'KROG' => 'AR - Rogers, Rogers Municipal Airport-Carter Field',
    'KRUE' => 'AR - Russellville, Russellville Regional Airport',
    'KSRC' => 'AR - Searcy, Searcy Municipal Airport',
    'KSLG' => 'AR - Siloam Springs, Smith Field Airport',
    'KASG' => 'AR - Springdale Municipal',
    'KSGT' => 'AR - Stuttgart, Stuttgart Municipal Airport',
    'KTXK' => 'AR - Texarkana, Texarkana Regional-Webb Field',
    'KARG' => 'AR - Walnut Ridge, Walnut Ridge Regional Airport',
    'KAWM' => 'AR - West Memphis, West Memphis Municipal Airport',
    'KIFP' => 'AZ - Bullhead City, Laughlin/Bullhead International Airport',
    'KCGZ' => 'AZ - Casa Grande, Casa Grande Municipal Airport',
    'KCHD' => 'AZ - Chandler, Chandler Municipal Airport',
    'KDMA' => 'AZ - Davis-Monthan Air Force Base',
    'KDUG' => 'AZ - Douglas Bisbee, Bisbee Douglas International Airport',
    'KFLG' => 'AZ - Flagstaff, Flagstaff Pulliam Airport',
    'KFHU' => 'AZ - Fort Huachuca, Libby AAF Ft Huachuca',
    'KGBN' => 'AZ - Gila Bend U. S. Army Airfield',
    'KGEU' => 'AZ - Glendale, Glendale Municipal Airport',
    'KGYR' => 'AZ - Goodyear Municipal',
    'KGCN' => 'AZ - Grand Canyon, Grand Canyon National Park Airport',
    'KIGM' => 'AZ - Kingman, Kingman Airport',
    'KLUF' => 'AZ - Luke Air Force Base / Phoenix',
    'KFFZ' => 'AZ - Mesa / Falcon Field',
    'KIWA' => 'AZ - Mesa, Williams Gateway Airport',
    'KOLS' => 'AZ - Nogales, Nogales International Airport',
    'KPGA' => 'AZ - Page, Page Municipal Airport',
    'KPHX' => 'AZ - Phoenix, Phoenix Sky Harbor International Airport',
    'KDVT' => 'AZ - Phoenix, Phoenix-Deer Valley Municipal Airport',
    'KPRC' => 'AZ - Prescott, Love Field',
    'KSAD' => 'AZ - Safford, Safford Municipal Airport',
    'KSDL' => 'AZ - Scottsdale, Scottsdale Airport',
    'KSOW' => 'AZ - Show Low, Show Low Regional Airport',
    'KSJN' => 'AZ - St. Johns, St. Johns Industrial Airpark',
    'KTUS' => 'AZ - Tucson, Tucson International Airport',
    'KRQE' => 'AZ - Window Rock, Window Rock Airport',
    'KINW' => 'AZ - Winslow, Winslow Municipal Airport',
    'KYUM' => 'AZ - Yuma / Yuma International',
    'KNYL' => 'AZ - Yuma, Marine Corps Air Station',
    'KAAT' => 'CA - Alturas',
    'KACV' => 'CA - Arcata / Eureka, Arcata Airport',
    'KAUN' => 'CA - Auburn, Auburn Municipal Airport',
    'KAVX' => 'CA - Avalon, Catalina Airport',
    'KBFL' => 'CA - Bakersfield, Meadows Field Airport',
    'KBIH' => 'CA - Bishop, Bishop Airport',
    'KBLH' => 'CA - Blythe, Blythe Airport',
    'KBUR' => 'CA - Burbank, Burbank-Glendale-Pasadena Airport',
    'KCMA' => 'CA - Camarillo, Camarillo Airport',
    'KCZZ' => 'CA - Campo',
    'KCRQ' => 'CA - Carlsbad, McClellan-Palomar Airport',
    'KCIC' => 'CA - Chico Municipal',
    'KNID' => 'CA - China Lake, Naval Air Facility',
    'KCNO' => 'CA - Chino, Chino Airport',
    'KCCR' => 'CA - Concord, Buchanan Field',
    'KCEC' => 'CA - Crescent City, Jack McNamara Field Airport',
    'KDAG' => 'CA - Daggett, Barstow-Daggett Airport',
    'KEDW' => 'CA - Edwards Air Force Base',
    'K9L2' => 'CA - Edwards, Edwards Air Force Auxiliary North Base',
    'KNJK' => 'CA - El Centro, Naval Air Facility',
    'KEMT' => 'CA - El Monte',
    'KBLU' => 'CA - Emigrant Gap, Blue Canyon Nyack Airport',
    'KEKA' => 'CA - Eureka',
    'KSUU' => 'CA - Fairfield / Travis Air Force Base',
    'KFAT' => 'CA - Fresno, Fresno Air Terminal',
    'KFUL' => 'CA - Fullerton, Fullerton Municipal Airport',
    'KHHR' => 'CA - Hawthorne, Hawthorne Municipal Airport',
    'KHWD' => 'CA - Hayward, Hayward Air Terminal',
    'KNRS' => 'CA - Imperial Beach, Naval Auxiliary Landing Field',
    'KIPL' => 'CA - Imperial, Imperial County Airport',
    'KIYK' => 'CA - Inyokern',
    'KPOC' => 'CA - La Verne / Brackett',
    'KWJF' => 'CA - Lancaster, General William J. Fox Airfield Airport',
    'KNLC' => 'CA - Lemoore, Naval Air Station',
    'KLVK' => 'CA - Livermore, Livermore Municipal Airport',
    'KLPC' => 'CA - Lompoc, Lompoc Airport',
    'KVBG' => 'CA - Lompoc, Vandenberg Air Force Base',
    'KLGB' => 'CA - Long Beach, Long Beach Airport',
    'KSLI' => 'CA - Los Alamitos U. S. Army Airfield',
    'KCQT' => 'CA - Los Angeles / USC Campus Downtown',
    'KLAX' => 'CA - Los Angeles, Los Angeles International Airport',
    'KWHP' => 'CA - Los Angeles, Whiteman Airport',
    'KMAE' => 'CA - Madera, Madera Municipal Airport',
    'KMMH' => 'CA - Mammoth / June Lakes',
    'KBAB' => 'CA - Marysville, Beale Air Force Base',
    'KMYV' => 'CA - Marysville, Yuba County Airport',
    'KMCE' => 'CA - Merced, Merced Municipal Airport',
    'KMOD' => 'CA - Modesto, Modesto City-County-Sham Field',
    'KMHV' => 'CA - Mojave',
    'KSIY' => 'CA - Montague, Siskiyou County Airport',
    'KMRY' => 'CA - Monterey, Monterey Peninsula Airport',
    'KMHS' => 'CA - Mount Shasta',
    'KMWS' => 'CA - Mount Wilson',
    'KNUQ' => 'CA - Mountain View, Moffett Field',
    'KAPC' => 'CA - Napa, Napa County Airport',
    'KEED' => 'CA - Needles, Needles Airport',
    'K3A6' => 'CA - Newhall',
    'KOAK' => 'CA - Oakland, Metro Oakland International Airport',
    'KNFG' => 'CA - Oceanside, Camp Pendleton, Marine Corps Air Station',
    'KONT' => 'CA - Ontario, Ontario International Airport',
    'KOVE' => 'CA - Oroville, Oroville Municipal Airport',
    'KOXR' => 'CA - Oxnard, Oxnard Airport',
    'KTRM' => 'CA - Palm Springs, Jacqueline Cochran Regional Airport',
    'KPSP' => 'CA - Palm Springs, Palm Springs Regional Airport',
    'KPMD' => 'CA - Palmdale, Palmdale Production Flight Plant',
    'KPAO' => 'CA - Palo Alto Airport',
    'KPRB' => 'CA - Paso Robles, Paso Robles Municipal Airport',
    'KNTD' => 'CA - Point Mugu, Naval Air Warfare Center',
    'KPTV' => 'CA - Porterville, Porterville Municipal Airport',
    'KRNM' => 'CA - Ramona, Ramona Airport',
    'KRBL' => 'CA - Red Bluff, Red Bluff Municipal Airport',
    'KRDD' => 'CA - Redding, Redding Municipal Airport',
    'KRIV' => 'CA - Riverside / March Air Force Base',
    'KRAL' => 'CA - Riverside, Riverside Municipal Airport',
    'KSAC' => 'CA - Sacramento, Sacramento Executive Airport',
    'KSMF' => 'CA - Sacramento, Sacramento International Airport',
    'KMHR' => 'CA - Sacramento, Sacramento Mather Airport',
    'KSNS' => 'CA - Salinas, Salinas Municipal Airport',
    'KSQL' => 'CA - San Carlos Airport',
    'KNUC' => 'CA - San Clemente Island, San Clemente Island NALF',
    'KSDM' => 'CA - San Diego, Brown Field Municipal Airport',
    'KNKX' => 'CA - San Diego, Miramar MCAS/Mitscher Field Airport',
    'KMYF' => 'CA - San Diego, Montgomery Field',
    'KNZY' => 'CA - San Diego, North Island, Naval Air Station',
    'KSAN' => 'CA - San Diego, San Diego International-Lindbergh Field',
    'KSEE' => 'CA - San Diego/El Cajon, Gillespie Field Airport',
    'KSFO' => 'CA - San Francisco, San Francisco International Airport',
    'KRHV' => 'CA - San Jose / Reid / Hillv',
    'KSJC' => 'CA - San Jose, San Jose International Airport',
    'KSBP' => 'CA - San Luis Obispo, San Luis Obispo County-Mc Chesney Field',
    'KNSI' => 'CA - San Nicholas Island',
    'KSDB' => 'CA - Sandberg',
    'KSNA' => 'CA - Santa Ana, John Wayne Airport-Orange County Airport',
    'KSBA' => 'CA - Santa Barbara, Santa Barbara Municipal Airport',
    'KSMX' => 'CA - Santa Maria, Santa Maria Public Airport',
    'KSMO' => 'CA - Santa Monica, Santa Monica Municipal Airport',
    'KSTS' => 'CA - Santa Rosa, Santa Rosa Sonoma County Airport',
    'KIZA' => 'CA - Santa Ynez, Santa Ynez Airport',
    'KO87' => 'CA - Shelter Cove',
    'KTVL' => 'CA - South Lake Tahoe, Lake Tahoe Airport',
    'KSCK' => 'CA - Stockton, Stockton Metropolitan Airport',
    'KTOA' => 'CA - Torrance, Zamperini Field Airport',
    'KTRK' => 'CA - Truckee-Tahoe',
    'KNXP' => 'CA - Twenty-Nine Palms, Marine Corps Air-Ground Combat Center',
    'KUKI' => 'CA - Ukiah, Ukiah Municipal Airport',
    'KVCB' => 'CA - Vacaville, Nut Tree Airport',
    'KVNY' => 'CA - Van Nuys, Van Nuys Airport',
    'KVCV' => 'CA - Victorville, Southern California Logistics Airport',
    'KVIS' => 'CA - Visalia, Visalia Municipal Airport',
    'KWVI' => 'CA - Watsonville, Watsonville Municipal Airport',
    'KAFF' => 'CO - Air Force Academy',
    'KAKO' => 'CO - Akron, Akron-Washington County Airport',
    'KALS' => 'CO - Alamosa, San Luis Valley Regional Airport',
    'KASE' => 'CO - Aspen, Aspen-Pitkin County Airport',
    'KBKF' => 'CO - Aurora, Buckley Air Force Base Airport',
    'KBJC' => 'CO - Broomfield / Jeffco',
    'KITR' => 'CO - Burlington, Carson County Airport',
    'KCOS' => 'CO - Colorado Springs, City Of Colorado Springs Municipal Airport',
    'KCCU' => 'CO - Copper Mountain, Red Cliff Pass',
    'KCEZ' => 'CO - Cortez, Cortez-Montezuma County Airport',
    'K7BM' => 'CO - Cottonwood Pass',
    'KCAG' => 'CO - Craig, Craig-Moffat Airport',
    'KFTG' => 'CO - Denver Nexrad',
    'KAPA' => 'CO - Denver, Centennial Airport',
    'KDEN' => 'CO - Denver, Denver International Airport',
    'KDRO' => 'CO - Durango, Durango-La Plata County Airport',
    'KEGE' => 'CO - Eagle County Regional',
    'KMNH' => 'CO - Elbert Mountain, Monument Pass',
    'KFCS' => 'CO - Fort Carson',
    'KFNL' => 'CO - Fort Collins/Loveland, Fort Collins-Loveland Municipal Airport',
    'KGJT' => 'CO - Grand Junction, Walker Field',
    'KGXY' => 'CO - Greeley, Greeley-Weld County Airport',
    'KGUC' => 'CO - Gunnison, Gunnison-Crested Butte Regional Airport',
    'KHDN' => 'CO - Hayden, Yampa Valley Airport',
    'K20V' => 'CO - Kremmling, Mc Elroy Airfield',
    'KLHX' => 'CO - La Junta, La Junta Municipal Airport',
    'KVTP' => 'CO - La Veta Mountain, La Veta Pass',
    'KLAA' => 'CO - Lamar, Lamar Municipal Airport',
    'KLXV' => 'CO - Leadville, Lake County Airport',
    'KLIC' => 'CO - Limon, Limon Municipal Airport',
    'KEEO' => 'CO - Meeker, Meeker Airport',
    'KMTJ' => 'CO - Montrose, Montrose Regional Airport',
    'K3MW' => 'CO - Mount Werner',
    'KCPW' => 'CO - Pagosa Springs, Wolf Creek Pass',
    'KPUB' => 'CO - Pueblo, Pueblo Memorial Airport',
    'KRIL' => 'CO - Rifle, Garfield County Regional Airport',
    'K04V' => 'CO - Saguache, Saguache Municipal Airport',
    'KMYP' => 'CO - Salida Mountain, Monarch Pass',
    'KSPD' => 'CO - Springfield, Comanche National Grassland',
    'K5SM' => 'CO - Sunlight',
    'KTEX' => 'CO - Telluride, Telluride Regional Airport',
    'KTAD' => 'CO - Trinidad, Perry Stokes Airport',
    'K4BM' => 'CO - Wilkerson Pass',
    'KBDR' => 'CT - Bridgeport, Sikorsky Memorial Airport',
    'KSNC' => 'CT - Chester, Chester Airport',
    'KDXR' => 'CT - Danbury, Danbury Municipal Airport',
    'KGON' => 'CT - Groton / New London, Groton / New London Airport',
    'KHFD' => 'CT - Hartford, Hartford-Brainard Airport',
    'KMMK' => 'CT - Meriden, Meriden Markham Municipal Airport',
    'KHVN' => 'CT - New Haven, Tweed-New Haven Airport',
    'KOXC' => 'CT - Oxford, Waterbury-Oxford Airport',
    'KIJD' => 'CT - Willimantic, Windham Airport',
    'KBDL' => 'CT - Windsor Locks, Bradley International Airport',
    'KDOV' => 'DE - Dover Air Force Base',
    'KGED' => 'DE - Georgetown, Sussex County Airport',
    'KILG' => 'DE - Wilmington, New Castle County Airport',
    'KAQR' => 'FL - Atoka, Atoka Municipal Airport',
    'KBOW' => 'FL - Bartow Municipal',
    'KBCT' => 'FL - Boca Raton, Boca Raton Airport',
    'KBKV' => 'FL - Brooksville, Hernando County Airport',
    'KCOF' => 'FL - Cocoa / Patrick Air Force Base',
    'KCEW' => 'FL - Crestview, Sikes Airport',
    'KCTY' => 'FL - Cross City, Cross City Airport',
    'KDAB' => 'FL - Daytona Beach, Daytona Beach Regional Airport',
    'KDTS' => 'FL - Destin, Destin-Ft. Walton Beach Airport',
    'KEGI' => 'FL - Duke Field / Eglin Auxiliary',
    'KFLL' => 'FL - Fort Lauderdale, Fort Lauderdale / Hollywood International Airport',
    'KFXE' => 'FL - Fort Lauderdale, Fort Lauderdale Executive Airport',
    'KFMY' => 'FL - Fort Myers, Page Field',
    'KRSW' => 'FL - Fort Myers, Southwest Florida International Airport',
    'KFPR' => 'FL - Fort Pierce, St. Lucie County International Airport',
    'KGNV' => 'FL - Gainesville, Gainesville Regional Airport',
    'KHWO' => 'FL - Hollywood, North Perry Airport',
    'KHST' => 'FL - Homestead Air Force Base',
    'KHRT' => 'FL - Hurlburt Field',
    'KVQQ' => 'FL - Jacksonville, Cecil Field Airport',
    'KCRG' => 'FL - Jacksonville, Craig Municipal Airport',
    'KJAX' => 'FL - Jacksonville, Jacksonville International Airport',
    'KNIP' => 'FL - Jacksonville, Naval Air Station',
    'KEYW' => 'FL - Key West, Key West International Airport',
    'KNQX' => 'FL - Key West, Naval Air Station',
    'KLAL' => 'FL - Lakeland Regional',
    'KLEE' => 'FL - Leesburg, Leesburg Regional Airport',
    'KMCF' => 'FL - Macdill Air Force Base, Fl.',
    'KMTH' => 'FL - Marathon, Marathon Airport',
    'KMAI' => 'FL - Marianna, Marianna Municipal Airport',
    'KNRB' => 'FL - Mayport, Mayport Naval Station, Adm David L. McDonald Field',
    'KMLB' => 'FL - Melbourne, Melbourne International Airport',
    'KTMB' => 'FL - Miami, Kendall-Tamiami Executive Airport',
    'KMIA' => 'FL - Miami, Miami International Airport',
    'KOPF' => 'FL - Miami, Opa Locka Airport',
    'KNSE' => 'FL - Milton, Whiting Field Naval Air Station North',
    'KAPF' => 'FL - Naples, Naples Municipal Airport',
    'KEVB' => 'FL - New Smyrna Beach, New Smyrna Beach Municipal Airport',
    'KOCF' => 'FL - Ocala, Ocala International Airport-Jim Taylor Field',
    'KSFB' => 'FL - Orlando / Sanford Airport',
    'KISM' => 'FL - Orlando, Kissimmee Municipal Airport',
    'KORL' => 'FL - Orlando, Orlando Executive Airport',
    'KMCO' => 'FL - Orlando, Orlando International Airport',
    'KOMN' => 'FL - Ormond Beach, Ormond Beach Municipal Airport',
    'KPFN' => 'FL - Panama City, Panama City-Bay County International Airport',
    'KNPA' => 'FL - Pensacola, Naval Air Station',
    'KPNS' => 'FL - Pensacola, Pensacola Regional Airport',
    'K40J' => 'FL - Perry-Foley, Perry-Foley Airport',
    'KPCM' => 'FL - Plant City, Plant City Municipal Airport',
    'KPMP' => 'FL - Pompano Beach, Pompano Beach Airpark',
    'KPGD' => 'FL - Punta Gorda, Charlotte County Airport',
    'KSRQ' => 'FL - Sarasota / Bradenton, Sarasota-Bradenton International Airport',
    'KSGJ' => 'FL - St. Augustine, St. Augustine Airport',
    'KPIE' => 'FL - St. Petersburg / Clearwater, St. Petersburg / Clearwater International Airport',
    'KSPG' => 'FL - St. Petersburg, Whitted Airport',
    'KSUA' => 'FL - Stuart, Witham Field Airport',
    'KTLH' => 'FL - Tallahassee, Tallahassee Regional Airport',
    'KTPF' => 'FL - Tampa, Peter O Knight Airport',
    'KTPA' => 'FL - Tampa, Tampa International Airport',
    'KVDF' => 'FL - Tampa, Vandenberg Airport',
    'KVVG' => 'FL - The Villages',
    'KTIX' => 'FL - Titusville',
    'KPAM' => 'FL - Tyndall Air Force Base',
    'KVPS' => 'FL - Valparaiso / Eglin Air Force Base',
    'KVRB' => 'FL - Vero Beach, Vero Beach Municipal Airport',
    'KPBI' => 'FL - West Palm Beach, Palm Beach International Airport',
    'KGIF' => 'FL - Winter Haven, Winter Haven\'s Gilbert Airport',
    'KABY' => 'GA - Albany, Southwest Georgia Regional Airport',
    'KAMG' => 'GA - Alma, Bacon County Airport',
    'KAHN' => 'GA - Athens, Athens Airport',
    'KPDK' => 'GA - Atlanta, De Kalb-Peachtree Airport',
    'KFTY' => 'GA - Atlanta, Fulton County Airport-Brown Field',
    'KATL' => 'GA - Atlanta, Hartsfield - Jackson Atlanta International Airport',
    'KFFC' => 'GA - Atlanta, Peachtree City-Falcon Field',
    'KAGS' => 'GA - Augusta, Bush Field',
    'KDNL' => 'GA - Augusta, Daniel Field',
    'KBGE' => 'GA - Bainbridge, Decatur County Industrial Air Park Airport',
    'KBIJ' => 'GA - Blakely, Early County Airport',
    'KBQK' => 'GA - Brunswick / Glynco',
    'KSSI' => 'GA - Brunswick, Malcolm McKinnon Airport',
    'K47A' => 'GA - Canton, Cherokee County Airport',
    'KVPC' => 'GA - Cartersville, Cartersville Airport',
    'KCSG' => 'GA - Columbus, Columbus Metropolitan Airport',
    'KDNN' => 'GA - Dalton, Dalton Municipal Airport',
    'KDQH' => 'GA - Douglas, Douglas Municipal Airport',
    'KDBN' => 'GA - Dublin, W H \'Bud\' Barron Airport',
    'KLSF' => 'GA - Fort Benning',
    'KLHW' => 'GA - Ft. Stewart',
    'KGVL' => 'GA - Gainesville, Gilmer Memorial Airport',
    'K3J7' => 'GA - Greensboro, Greene County Regional Airport',
    'KSVN' => 'GA - Hunter U. S. Army Airfield',
    'KLGC' => 'GA - La Grange, Callaway Airport',
    'KLZU' => 'GA - Lawrenceville, Gwinnett County-Briscoe Field Airport',
    'KMCN' => 'GA - Macon, Middle Georgia Regional Airport',
    'KMGE' => 'GA - Marietta / Dobbins Air Force Base',
    'KRYY' => 'GA - Marietta, Cobb County-McCollum Field Airport',
    'KMLJ' => 'GA - Milledgeville, Baldwin County Airport',
    'KVAD' => 'GA - Moody Air Force Base',
    'KMGR' => 'GA - Moultrie, Moultrie Municipal Airport',
    'KCCO' => 'GA - Newnan, Newnan Coweta County Airport',
    'KRMG' => 'GA - Rome, R. B. Russell Airport',
    'KSAV' => 'GA - Savannah, Savannah International Airport',
    'KTBR' => 'GA - Statesboro, Statesboro-Bulloch County Airport',
    'KJYL' => 'GA - Sylvania, Plantation Airpark',
    'KOPN' => 'GA - Thomaston, Thomaston-Upson County Airport',
    'KHQU' => 'GA - Thomson, Thomson-McDuffie County Airport',
    'KVLD' => 'GA - Valdosta, Valdosta Regional Airport',
    'KVDI' => 'GA - Vidalia, Vidalia Municipal Airport',
    'KWRB' => 'GA - Warner Robins Air Force Base',
    'KIIY' => 'GA - Washington, Washington-Wilkes County Airport',
    'KAYS' => 'GA - Waycross / Ware County, Ga',
    'KWDR' => 'GA - Winder, Winder-Barrow Airport',
    'PHSF' => 'HI - Bradshaw Army Air Field / Hawaii',
    'PHHN' => 'HI - Hana, Hana Airport',
    'PHIK' => 'HI - Hickam Air Force Base / Oahu',
    'PHTO' => 'HI - Hilo, Hilo International Airport',
    'PHNL' => 'HI - Honolulu, Honolulu International Airport',
    'PHOG' => 'HI - Kahului, Kahului Airport',
    'PHKO' => 'HI - Kailua / Kona, Keahole Airport',
    'PHNG' => 'HI - Kaneohe, Marine Corps Air Station',
    'PHMK' => 'HI - Kaunakakai, Molokai Airport',
    'PHBK' => 'HI - Kekaha, Pacific Missile Test Facility Barking Sands',
    'PHJH' => 'HI - Lahaina / West Maui',
    'PHNY' => 'HI - Lanai City, Lanai Airport',
    'PHLI' => 'HI - Lihue, Lihue Airport',
    'PHJR' => 'HI - Oahu, Kalaeloa Airport',
    'PMDY' => 'HI - Sand Island, Henderson Field Airport',
    'PHHI' => 'HI - Wheeler Air Force Base / Oahu',
    'KAXA' => 'IA - Algona',
    'KAMW' => 'IA - Ames, Ames Municipal Airport',
    'KIKV' => 'IA - Ankeny, Ankeny Regional Airport',
    'KAIO' => 'IA - Atlantic',
    'KADU' => 'IA - Audubon, Audubon County Airport',
    'KBNW' => 'IA - Boone Municipal',
    'KBRL' => 'IA - Burlington, Burlington Regional Airport',
    'KCIN' => 'IA - Carroll',
    'KCID' => 'IA - Cedar Rapids, The Eastern Iowa Airport',
    'KCNC' => 'IA - Chariton',
    'KCCY' => 'IA - Charles City',
    'KCKP' => 'IA - Cherokee, Cherokee Municipal Airport',
    'KICL' => 'IA - Clarinda',
    'KCAV' => 'IA - Clarion',
    'KCWI' => 'IA - Clinton, Clinton Municipal Airport',
    'KCBF' => 'IA - Council Bluffs',
    'KCSQ' => 'IA - Creston',
    'KDVN' => 'IA - Davenport, Davenport Municipal Airport',
    'KDEH' => 'IA - Decorah',
    'KDNS' => 'IA - Denison',
    'KDSM' => 'IA - Des Moines, Des Moines International Airport',
    'KDBQ' => 'IA - Dubuque, Dubuque Regional Airport',
    'KEST' => 'IA - Estherville, Estherville Municipal Airport',
    'KFFL' => 'IA - Fair Field',
    'KFOD' => 'IA - Fort Dodge',
    'KFSW' => 'IA - Fort Madison',
    'KHNR' => 'IA - Harlan, Harlan Municipal Airport',
    'KIIB' => 'IA - Independence, Independence Municipal Airport',
    'KIOW' => 'IA - Iowa City, Iowa City Municipal Airport',
    'KEOK' => 'IA - Keokuk Municipal',
    'KOXV' => 'IA - Knoxville',
    'KLWD' => 'IA - Lamoni, Lamoni Municipal Airport',
    'KLRJ' => 'IA - Le Mars, Le Mars Municipal Airport',
    'KMIW' => 'IA - Marshalltown, Marshalltown Municipal Airport',
    'KMCW' => 'IA - Mason City, Mason City Municipal Airport',
    'KMXO' => 'IA - Monticello Municipal',
    'KMPZ' => 'IA - Mount Pleasant, Mount Pleasant Municipal Airport',
    'KMUT' => 'IA - Muscatine',
    'KTNU' => 'IA - Newton Municipal',
    'KOLZ' => 'IA - Oelwein, Oelwein Municipal Airport',
    'KORC' => 'IA - Orange City',
    'KOOA' => 'IA - Oskaloosa, Oskaloosa Municipal Airport',
    'KOTM' => 'IA - Ottumwa, Ottumwa Industrial Airport',
    'KPEA' => 'IA - Pella, Pella Municipal Airport',
    'KRDK' => 'IA - Red Oak',
    'KSHL' => 'IA - Sheldon',
    'KSDA' => 'IA - Shenandoah Municipal',
    'KSUX' => 'IA - Sioux City, Sioux Gateway Airport',
    'KSPW' => 'IA - Spencer, Spencer Municipal Airport',
    'KSLB' => 'IA - Storm Lake',
    'KVTI' => 'IA - Vinton, Vinton Veterans Memorial Airpark Airport',
    'KAWG' => 'IA - Washington',
    'KALO' => 'IA - Waterloo, Waterloo Municipal Airport',
    'KEBS' => 'IA - Webster City',
    'KBOI' => 'ID - Boise, Boise Air Terminal',
    'KBYI' => 'ID - Burley, Burley Municipal Airport',
    'KEUL' => 'ID - Caldwell, Caldwell Industrial Airport',
    'KCOE' => 'ID - Coeur d\'Alene, Coeur d\'Alene Air Terminal',
    'KU59' => 'ID - Driggs, Driggs-Reed Memorial Airport',
    'KSUN' => 'ID - Hailey, Friedman Memorial Airport',
    'KIDA' => 'ID - Idaho Falls, Fanning Field',
    'KLWS' => 'ID - Lewiston, Lewiston-Nez Perce County Airport',
    'KP69' => 'ID - Lowell',
    'K77M' => 'ID - Malta',
    'KMYL' => 'ID - McCall, McCall Airport',
    'KMUO' => 'ID - Mountain Home Air Force Base',
    'KMLP' => 'ID - Mullan Pass, Mullan Pass Vor',
    'KPIH' => 'ID - Pocatello, Pocatello Regional Airport',
    'KRXE' => 'ID - Rexburg, Rexburg-Madison County Airport',
    'KSMN' => 'ID - Salmon, Lemhi County Airport',
    'KSZT' => 'ID - Sandpoint, Sandpoint Airport',
    'KU78' => 'ID - Soda Springs / Tigert',
    'KSNT' => 'ID - Stanley, Stanley Ranger Station',
    'KTWF' => 'ID - Twin Falls, Joslin Field-Magic Valley Regional Airport',
    'KALN' => 'IL - Alton/St. Louis, St. Louis Regional Airport',
    'KARR' => 'IL - Aurora, Aurora Municipal Airport',
    'KBLV' => 'IL - Belleville, Scott AFB/MidAmerica Airport',
    'KBMI' => 'IL - Bloomington/Normal, Central Illinois Regional Airport at Bloomington-Normal',
    'KCPS' => 'IL - Cahokia / St. Louis, St. Louis Downtown Airport',
    'KCIR' => 'IL - Cairo, Cairo Regional Airport',
    'KMDH' => 'IL - Carbondale / Murphysboro, Southern Illinois Airport',
    'KCUL' => 'IL - Carmi, Carmi Municipal Airport',
    'KENL' => 'IL - Centralia, Centralia Municipal Airport',
    'KCMI' => 'IL - Champaign / Urbana, University Of Illinois-Willard Airport',
    'KUGN' => 'IL - Chicago / Waukegan, Waukegan Regional Airport',
    'KDPA' => 'IL - Chicago / West Chicago, Dupage Airport',
    'KPWK' => 'IL - Chicago / Wheeling, Pal-Waukee Airport',
    'KMDW' => 'IL - Chicago, Chicago Midway Airport',
    'KORD' => 'IL - Chicago, Chicago-O\'Hare International Airport',
    'KIGQ' => 'IL - Chicago, Lansing Municipal Airport',
    'KLOT' => 'IL - Chicago/Romeoville, Lewis University Airport',
    'KDNV' => 'IL - Danville, Vermilion County Airport',
    'KDKB' => 'IL - De Kalb, De Kalb Taylor Municipal Airport',
    'KDEC' => 'IL - Decatur, Decatur Airport',
    'K1H2' => 'IL - Effingham, Effingham County Memorial Airport',
    'KFWC' => 'IL - Fairfield, Fairfield Municipal Airport',
    'KFOA' => 'IL - Flora, Flora Municipal Airport',
    'KFEP' => 'IL - Freeport, Albertus Airport',
    'KGBG' => 'IL - Galesburg, Galesburg Municipal Airport',
    'KHSB' => 'IL - Harrisburg, Harrisburg-Raleigh Airport',
    'KIJX' => 'IL - Jacksonville, Jacksonville Municipal Airport',
    'KJOT' => 'IL - Joliet, Joliet Regional Airport',
    'KIKK' => 'IL - Kankakee, Greater Kankakee Airport',
    'KC75' => 'IL - Lacon, Marshall County Airport',
    'KLWV' => 'IL - Lawrenceville, Lawrenceville-Vincennes International Airport',
    'KAAA' => 'IL - Lincoln, Logan County Airport',
    'K3LF' => 'IL - Litchfield, Litchfield Municipal Airport',
    'KMQB' => 'IL - Macomb, Macomb Municipal Airport',
    'KMWA' => 'IL - Marion, Williamson County Regional Airport',
    'KMTO' => 'IL - Mattoon / Charleston, Coles County Memorial Airport',
    'KM30' => 'IL - Metropolis, Metropolis Municipal Airport',
    'KMLI' => 'IL - Moline, Quad-City Airport',
    'KC09' => 'IL - Morris, Morris Municipal-James R Washburn Field Airport',
    'KAJG' => 'IL - Mount Carmel, Mount Carmel Municipal Airport',
    'KMVN' => 'IL - Mount Vernon, Mount Vernon Airport',
    'KOLY' => 'IL - Olney-Noble, Olney-Noble Airport',
    'KPRG' => 'IL - Paris, Edgar County Airport',
    'KPIA' => 'IL - Peoria, Greater Peoria Regional Airport',
    'KVYS' => 'IL - Peru, Illinois Valley Regional-Walter A Duncan Field Airport',
    'KPPQ' => 'IL - Pittsfield, Pittsfield Penstone Municipal Airport',
    'KPNT' => 'IL - Pontiac, Pontiac Municipal Airport',
    'KUIN' => 'IL - Quincy, Quincy Regional-Baldwin Field Airport',
    'KTIP' => 'IL - Rantoul, Rantoul National Aviation Center Airport-Frank Elliott Field',
    'KRSV' => 'IL - Robinson, Robinson Municipal Airport',
    'KRPJ' => 'IL - Rochelle, Rochelle Municipal-Koritz Field Airport',
    'KRFD' => 'IL - Rockford, Greater Rockford Airport',
    'KSLO' => 'IL - Salem, Salem-Leckrone Airport',
    'KSFY' => 'IL - Savanna, Tri-Township Airport',
    'KSAR' => 'IL - Sparta, Sparta Community-Hunter Field Airport',
    'KSPI' => 'IL - Springfield, Abraham Lincoln Capital Airport',
    'KSQI' => 'IL - Sterling Rockfalls',
    'KTAZ' => 'IL - Taylorville, Taylorville Municipal Airport',
    'KAID' => 'IN - Anderson Municipal',
    'KBMG' => 'IN - Bloomington, Monroe County Airport',
    'KBAK' => 'IN - Columbus / Bakalar',
    'KEKM' => 'IN - Elkhart Municipal',
    'KEVV' => 'IN - Evansville, Evansville Regional Airport',
    'KFWA' => 'IN - Fort Wayne, Fort Wayne International Airport',
    'KGYY' => 'IN - Gary Regional',
    'KGSH' => 'IN - Goshen, Goshen Municipal Airport',
    'KGUS' => 'IN - Grissom Air Force Base / Peru',
    'KHNB' => 'IN - Huntingburg',
    'KEYE' => 'IN - Indianapolis, Eagle Creek Airpark',
    'KIND' => 'IN - Indianapolis, Indianapolis International Airport',
    'KOKK' => 'IN - Kokomo, Kokomo Municipal Airport',
    'KLAF' => 'IN - Lafayette, Purdue University Airport',
    'KMIE' => 'IN - Muncie, Delaware County-Johnson Field',
    'KGEZ' => 'IN - Shelbyville, Shelbyville Municipal Airport',
    'KSBN' => 'IN - South Bend, South Bend Regional Airport',
    'KHUF' => 'IN - Terre Haute, Terre Haute International Airport - Hulman Field',
    'KVPZ' => 'IN - Valparaiso, Porter County Municipal Airport',
    'KASW' => 'IN - Warsaw, Warsaw Municipal Airport',
    'KCNU' => 'KS - Chanute, Chanute Martin Johnson Airport',
    'KCFV' => 'KS - Coffeyville, Coffeyville Municipal Airport',
    'KCNK' => 'KS - Concordia, Blosser Municipal Airport',
    'KDDC' => 'KS - Dodge City, Dodge City Regional Airport',
    'KEHA' => 'KS - Elkhart, Elkhart-Morton County Airport',
    'KEMP' => 'KS - Emporia, Emporia Municipal Airport',
    'KGCK' => 'KS - Garden City, Garden City Regional Airport',
    'KGLD' => 'KS - Goodland, Renner Field',
    'KGBD' => 'KS - Great Bend, Great Bend Municipal Airport',
    'KHYS' => 'KS - Hays, Hays Regional Airport',
    'KHLC' => 'KS - Hill City, Hill City Municipal Airport',
    'KHUT' => 'KS - Hutchinson, Hutchinson Municipal Airport',
    'KLWC' => 'KS - Lawrence, Lawrence Municipal Airport',
    'KLBL' => 'KS - Liberal, Liberal Municipal Airport',
    'KMHK' => 'KS - Manhattan, Manhattan Municipal Airport',
    'KIAB' => 'KS - McConnell Air Force Base',
    'KP28' => 'KS - Medicine Lodge, Medicine Lodge',
    'KEWK' => 'KS - Newton, Newton City/County Airport',
    'KOJC' => 'KS - Olathe, Johnson County Executive Airport',
    'KIXD' => 'KS - Olathe, New Century Aircenter',
    'KPPF' => 'KS - Parsons, Tri-City Airport',
    'KPTT' => 'KS - Pratt Municipal',
    'KRSL' => 'KS - Russell, Russell Municipal Airport',
    'KSLN' => 'KS - Salina, Salina Municipal Airport',
    'KFOE' => 'KS - Topeka, Forbes Field',
    'KTOP' => 'KS - Topeka, Philip Billard Municipal Airport',
    'KAAO' => 'KS - Wichita, Colonel James Jabara Airport',
    'KICT' => 'KS - Wichita, Wichita Mid-Continent Airport',
    'KWLD' => 'KS - Winfield / Arkansas City, Strother Field',
    'KBWG' => 'KY - Bowling Green, Bowling Green-Warren County Regional Airport',
    'KCVG' => 'KY - Covington / Cincinnati, Cincinnati / Northern Kentucky International Airport',
    'KHOP' => 'KY - Fort Campbell U. S. Army Airfield',
    'KFTK' => 'KY - Fort Knox',
    'KFFT' => 'KY - Frankfort, Capital City Airport',
    'KGLW' => 'KY - Glasgow, Glasgow Municipal Airport',
    'KEHR' => 'KY - Henderson City',
    'KJKL' => 'KY - Jackson, Carroll Airport',
    'KLEX' => 'KY - Lexington, Blue Grass Airport',
    'KLOZ' => 'KY - London, London-Corbin Airport-Magee Field',
    'KLOU' => 'KY - Louisville, Bowman Field Airport',
    'KSDF' => 'KY - Louisville, Standiford Field',
    'K1A6' => 'KY - Middlesboro, Middlesboro-Bell County Airport',
    'KEKQ' => 'KY - Monticello, Wayne County Airport',
    'KOWB' => 'KY - Owensboro, Owensboro-Daviess County Airport',
    'KPAH' => 'KY - Paducah, Barkley Regional Airport',
    'KSME' => 'KY - Somerset, Somerset-Pulaski County - J.T. Wilson Field Airport',
    'KESF' => 'LA - Alexandria, Alexandria Esler Regional Airport',
    'KAEX' => 'LA - Alexandria, Alexandria International Airport',
    'K7R3' => 'LA - Amelia / Lake Palourd',
    'KAUD' => 'LA - Audubon Park',
    'KBAD' => 'LA - Barksdale Air Force Base',
    'K2F8' => 'LA - Bastrop, Morehouse Memorial Airport',
    'KBTR' => 'LA - Baton Rouge, Baton Rouge Metropolitan, Ryan Field',
    'KBVE' => 'LA - Boothville',
    'K1B7' => 'LA - Boothville Heliport',
    'KCWF' => 'LA - Chenault Airpark',
    'KDRI' => 'LA - De Ridder, Beauregard Parish Airport',
    'K3B6' => 'LA - Eugene Island 330',
    'KPOE' => 'LA - Fort Polk, Polk AAF Ft Polk',
    'K9F2' => 'LA - Fourchon Supplementary Aviation Weather Reporting Station',
    'KBKB' => 'LA - Ft. Polk, Fullerton Landing Strip',
    'KAQV' => 'LA - Ft. Polk, Peason Ridge',
    'KDNK' => 'LA - Ft. Polk, Self Strip',
    'K2GL' => 'LA - Galliano, Galliano Heliport',
    'KAXO' => 'LA - Grand Isle Supplementary Aviation Weather Reporting Station',
    'KXCN' => 'LA - Green Canyon 184',
    'KHDC' => 'LA - Hammond, Hammond Municipal Airport',
    'KH08' => 'LA - High Island 264C',
    'KHUM' => 'LA - Houma-Terrebonne',
    'K7R4' => 'LA - Intracoastal City',
    'KLFT' => 'LA - Lafayette, Lafayette Regional Airport',
    'KLCH' => 'LA - Lake Charles, Lake Charles Regional Airport',
    'KMLU' => 'LA - Monroe, Monroe Regional Airport',
    'KIER' => 'LA - Natchitoches, Natchitoches Regional Airport',
    'KARA' => 'LA - New Iberia, Acadiana Regional Airport',
    'KNBG' => 'LA - New Orleans, Naval Air Station - Alvin Callender Field',
    'KMSY' => 'LA - New Orleans, New Orleans International Airport',
    'KNEW' => 'LA - New Orleans, New Orleans Lakefront Airport',
    'KPTN' => 'LA - Patterson Memorial',
    'KRSN' => 'LA - Ruston, Ruston Regional Airport',
    'KP92' => 'LA - Salt Point',
    'KGSM' => 'LA - Ship Shoal 207A',
    'KDTN' => 'LA - Shreveport, Shreveport Downtown Airport',
    'KSHV' => 'LA - Shreveport, Shreveport Regional Airport',
    'KASD' => 'LA - Slidell, Slidell Airport',
    'KSRN' => 'LA - South Marsh 268A',
    'KS58' => 'LA - South Timbalier',
    'KTVR' => 'LA - Vicksburg, Vicksburg / Tallulah Regional Airport',
    'KBED' => 'MA - Bedford, Hanscom Field',
    'KBVY' => 'MA - Beverly, Beverly Municipal Airport',
    'KBOS' => 'MA - Boston, Logan International Airport',
    'KCQX' => 'MA - Chatham, Chatham Municipal Airport',
    'KCEF' => 'MA - Chicopee Falls / Westover Air Force Base',
    'KMQE' => 'MA - East Milton',
    'KFIT' => 'MA - Fitchburg, Fitchburg Municipal Airport',
    'KHYA' => 'MA - Hyannis, Barnstable Municipal-Boardman Airport',
    'KLWM' => 'MA - Lawrence, Lawrence Municipal Airport',
    'K3B2' => 'MA - Marshfield Airport',
    'KACK' => 'MA - Nantucket, Nantucket Memorial Airport',
    'KEWB' => 'MA - New Bedford, New Bedford Regional Airport',
    'KAQW' => 'MA - North Adams, Harriman-And-West Airport',
    'KOWD' => 'MA - Norwood, Norwood Memorial Airport',
    'KORE' => 'MA - Orange, Orange Municipal Airport',
    'KFMH' => 'MA - Otis Air National Guard Base',
    'KPSF' => 'MA - Pittsfield, Pittsfield Municipal Airport',
    'KPYM' => 'MA - Plymouth, Plymouth Municipal Airport',
    'KPVC' => 'MA - Provincetown, Provincetown Municipal Airport',
    'KTAN' => 'MA - Taunton, Taunton Municipal Airport',
    'KMVY' => 'MA - Vineyard Haven, Marthas Vineyard Airport',
    'KBAF' => 'MA - Westfield, Barnes Municipal Airport',
    'KORH' => 'MA - Worcester, Worcester Regional Airport',
    'KNAK' => 'MD - Annapolis, United States Naval Academy',
    'KMTN' => 'MD - Baltimore / Martin',
    'KBWI' => 'MD - Baltimore, Baltimore-Washington International Airport',
    'KDMH' => 'MD - Baltimore, Inner Harbor',
    'KADW' => 'MD - Camp Springs / Andrews Air Force Base',
    'KCBE' => 'MD - Cumberland, Greater Cumberland Regional Airport',
    'KESN' => 'MD - Easton / Newman Field',
    'KFME' => 'MD - Fort Meade / Tipton',
    'KFDK' => 'MD - Frederick, Frederick Municipal Airport',
    'KHGR' => 'MD - Hagerstown, Washington County Regional Airport',
    'KOXB' => 'MD - Ocean City, Ocean City Municipal Airport',
    'KNHK' => 'MD - Patuxent River, Naval Air Station',
    'KAPG' => 'MD - Phillips Army Air Field / Aberdeen',
    'KSBY' => 'MD - Salisbury, Salisbury-Ocean City Wicomico County Regional Airport',
    'KNUI' => 'MD - St. Inigoes, Webster Field, Naval Electronic Systems Engineering Activity',
    'KLEW' => 'ME - Auburn-Lewiston',
    'KAUG' => 'ME - Augusta, Augusta State Airport',
    'KBGR' => 'ME - Bangor, Bangor International Airport',
    'KBHB' => 'ME - Bar Harbor, Hancock County-Bar Harbor Airport',
    'KNHZ' => 'ME - Brunswick, Naval Air Station',
    'KCAR' => 'ME - Caribou, Caribou Municipal Airport',
    'K40B' => 'ME - Clayton Lake',
    'KFVE' => 'ME - Frenchville, Northern Aroostook Regional Airport',
    'KIZG' => 'ME - Fryeburg, Eastern Slopes Regional Airport',
    'KGNR' => 'ME - Greenville',
    'KHUL' => 'ME - Houlton, Houlton International Airport',
    'KMLT' => 'ME - Millinocket, Millinocket Municipal Airport',
    'KPWM' => 'ME - Portland, Portland International Jetport',
    'KPQI' => 'ME - Presque Isle',
    'KRKD' => 'ME - Rockland, Knox County Regional Airport',
    'KSFM' => 'ME - Sanford, Sanford Regional Airport',
    'KWVL' => 'ME - Waterville, Waterville Robert LaFleur Airport',
    'KIWI' => 'ME - Wiscasset, Wiscasset Airport',
    'KADG' => 'MI - Adrian, Lenawee County Airport',
    'KAMN' => 'MI - Alma, Gratiot Community Airport',
    'KAPN' => 'MI - Alpena, Alpena County Regional Airport',
    'KARB' => 'MI - Ann Arbor, Ann Arbor Municipal Airport',
    'KBAX' => 'MI - Bad Axe, Huron County Memorial Airport',
    'KBTL' => 'MI - Battle Creek, Kellogg Airport',
    'KSJX' => 'MI - Beaver Island, Beaver Island Airport',
    'KACB' => 'MI - Bellaire, Antrim County Airport',
    'KBEH' => 'MI - Benton Harbor, Southwest Michigan Regional Airport',
    'KRQB' => 'MI - Big Rapids, Roben-Hood Airport',
    'KCAD' => 'MI - Cadillac / Wexford County',
    'KCFS' => 'MI - Caro, Tuscola Area Airport',
    'KCVX' => 'MI - Charlevoix, Charlevoix Municipal Airport',
    'KFPK' => 'MI - Charlotte, Fitch H Beach Airport',
    'KOEB' => 'MI - Coldwater, Branch County Memorial Airport',
    'KP59' => 'MI - Copper Harbor',
    'KDET' => 'MI - Detroit, Detroit City Airport',
    'KDTW' => 'MI - Detroit, Detroit Metropolitan Wayne County Airport',
    'KYIP' => 'MI - Detroit, Willow Run Airport',
    'KONZ' => 'MI - Detroit/Grosse Ile, Grosse Ile Airport',
    'KESC' => 'MI - Escanaba',
    'KFNT' => 'MI - Flint, Bishop International Airport',
    'KFKS' => 'MI - Frankfort, Frankfort Dow Memorial Field Airport',
    'KGLR' => 'MI - Gaylord, Otsego County Airport',
    'KGRR' => 'MI - Grand Rapids, Gerald R. Ford International Airport',
    'KGOV' => 'MI - Grayling, Grayling Army Airfield',
    'KCMX' => 'MI - Hancock, Houghton County Memorial Airport',
    'KMGN' => 'MI - Harbor Springs, Harbor Springs Airport',
    'KJYM' => 'MI - Hillsdale, Hillsdale Municipal Airport',
    'KBIV' => 'MI - Holland, Tulip City Airport',
    'KHTL' => 'MI - Houghton Lake, Roscommon County Airport',
    'KOZW' => 'MI - Howell, Livingston County Airport',
    'KIMT' => 'MI - Iron Mountain / Kingsford, Ford Airport',
    'KIWD' => 'MI - Ironwood, Gogebic-Iron County Airport',
    'KJXN' => 'MI - Jackson, Jackson County-Reynolds Field Airport',
    'KAZO' => 'MI - Kalamazoo, Kalamazoo / Battle Creek International Airport',
    'KDUH' => 'MI - Lambertville, Toledo Suburban Airport',
    'KLAN' => 'MI - Lansing, Capital City Airport',
    'KLDM' => 'MI - Ludington, Mason County Airport',
    'KMCD' => 'MI - Macinac Island, Mackinac Island Airport',
    'KMBL' => 'MI - Manistee, Manistee County-Blacker Airport',
    'KISQ' => 'MI - Manistique, Schoolcraft County Airport',
    'KSAW' => 'MI - Marquette, Sawyer International Airport',
    'KRMY' => 'MI - Marshall, Brooks Field Airport',
    'KTEW' => 'MI - Mason, Mason Jewett Field Airport',
    'KMNM' => 'MI - Menominee, Menominee-Marinette Twin County Airport',
    'KTTF' => 'MI - Monroe, Custer Airport',
    'KMOP' => 'MI - Mount Pleasant, Mount Pleasant Municipal Airport',
    'KP53' => 'MI - Munising, Munising Lakeshore Observation',
    'KMKG' => 'MI - Muskegon, Muskegon County Airport',
    'KERY' => 'MI - Newberry, Luce County Airport',
    'KOSC' => 'MI - Oscoda, Oscoda-Wurtsmith Airport',
    'KRNP' => 'MI - Owosso, Owosso Community Airport',
    'KPLN' => 'MI - Pellston, Pellston Regional Airport of Emmet County Airport',
    'KPTK' => 'MI - Pontiac, Oakland County International Airport',
    'KP58' => 'MI - Port Hope',
    'KPZQ' => 'MI - Rogers City, Presque Isle County Airport',
    'KMBS' => 'MI - Saginaw, MBS International Airport',
    'KHYX' => 'MI - Saginaw, Saginaw County H.W. Browne Airport',
    'KCIU' => 'MI - Sault Ste Marie, Chippewa County International Airport',
    'KANJ' => 'MI - Sault Ste. Marie',
    'KMTC' => 'MI - Selfridge Air National Guard Base',
    'KLWA' => 'MI - South Haven, South Haven Area Regional Airport',
    'KPHN' => 'MI - St. Clair County International',
    'KIRS' => 'MI - Sturgis, Kirsch Municipal Airport',
    'KTVC' => 'MI - Traverse City, Cherry Capital Airport',
    'KVLL' => 'MI - Troy, Oakland/Troy Airport',
    'KAIT' => 'MN - Aitkin, Aitkin Municipal Airport-Steve Kurtz Field',
    'KAEL' => 'MN - Albert Lea, Albert Lea Municipal Airport',
    'KAXN' => 'MN - Alexandria, Chandler Field',
    'KAQP' => 'MN - Appleton, Appleton Municipal Airport',
    'KAUM' => 'MN - Austin Municipal',
    'KBDE' => 'MN - Baudette, Baudette International Airport',
    'KBJI' => 'MN - Bemidji',
    'KBBB' => 'MN - Benson Municipal',
    'KFOZ' => 'MN - Bigfork, Bigfork Municipal Airport',
    'KBRD' => 'MN - Brainerd, Brainerd-Crow Wing County Regional Airport',
    'KCFE' => 'MN - Buffalo, Buffalo Municipal Airport',
    'KCBG' => 'MN - Cambridge Municipal',
    'KCOQ' => 'MN - Cloquet, Cloquet Carlton County Airport',
    'KCQM' => 'MN - Cook, Cook Municipal Airport',
    'KCDD' => 'MN - Crane Lake, Scotts Seaplane Base',
    'KCKN' => 'MN - Crookston Municipal Field',
    'KDTL' => 'MN - Detroit Lakes, Detroit Lakes Airport-Wething Field',
    'KTOB' => 'MN - Dodge Center, Dodge Center Airport',
    'KDLH' => 'MN - Duluth, Duluth International Airport',
    'KDYT' => 'MN - Duluth, Sky Harbor Airport',
    'KELO' => 'MN - Ely, Ely Municipal Airport',
    'KEVM' => 'MN - Eveleth, Eveleth-Virginia Municipal Airport',
    'KFRM' => 'MN - Fairmont, Fairmont Municipal Airport',
    'KFBL' => 'MN - Faribault, Faribault Municipal Airport',
    'KFFM' => 'MN - Fergus Falls, Fergus Falls Municipal Airport-Einar Mickelson Field',
    'KFGN' => 'MN - Flag Island',
    'KFSE' => 'MN - Fosston, Fosston Municipal Airport',
    'KGYL' => 'MN - Glencoe, Glencoe Municipal Airport',
    'KGHW' => 'MN - Glenwood, Glenwood Municipal Airport',
    'KCKC' => 'MN - Grand Marais, Grand Marais/Cook County Airport',
    'KGNA' => 'MN - Grand Marais, The Bay of Grand Marais',
    'KGPZ' => 'MN - Grand Rapids, Grand Rapids/Itasca County Airport-Gordon Newstrom Field',
    'KGDB' => 'MN - Granite Falls, Granite Falls Municipal Airport/Lenzen-Roe Memorial Field',
    'KHCO' => 'MN - Hallock, Hallock Municipal Airport',
    'KHIB' => 'MN - Hibbing, Chisholm-Hibbing Airport',
    'KHCD' => 'MN - Hutchinson, Hutchinson Municipal Airport-Butler Field',
    'KINL' => 'MN - International Falls, Falls International Airport',
    'KMJQ' => 'MN - Jackson, Jackson Municipal Airport',
    'KLJF' => 'MN - Litchfield, Litchfield Municipal Airport',
    'KLXL' => 'MN - Little Falls, Little Falls/Morrison County Airport-Lindbergh Field',
    'KXVG' => 'MN - Longville, Longville Municipal Airport',
    'KLYV' => 'MN - Luverne, Quentin Aanenson Field Airport',
    'KDXX' => 'MN - Madison, Madison-Lac Qui Parle County Airport',
    'KMKT' => 'MN - Mankato, Mankato Regional Airport',
    'KMGG' => 'MN - Maple Lake, Maple Lake Municipal Airport',
    'KMML' => 'MN - Marshall, Southwest Minnesota Regional Airport - Marshall/Ryan Field',
    'KHZX' => 'MN - Mc Gregor, Isedor Iverson Airport',
    'KANE' => 'MN - Minneapolis / Blaine',
    'KLVN' => 'MN - Minneapolis, Airlake Airport',
    'KMIC' => 'MN - Minneapolis, Crystal Airport',
    'KFCM' => 'MN - Minneapolis, Flying Cloud Airport',
    'KMSP' => 'MN - Minneapolis, Minneapolis-St. Paul International Airport',
    'KMVE' => 'MN - Montevideo, Montevideo-Chippewa County Airport',
    'KJKJ' => 'MN - Moorhead, Moorhead Municipal Airport',
    'KMZH' => 'MN - Moose Lake, Moose Lake Carlton County Airport',
    'KJMR' => 'MN - Mora, Mora Municipal Airport',
    'KMOX' => 'MN - Morris, Morris Municipal Airport',
    'KULM' => 'MN - New Ulm, New Ulm Municipal Airport',
    'KORB' => 'MN - Orr',
    'KVVV' => 'MN - Ortonville, Ortonville Muncipal-Martinson Field Airport',
    'KOWA' => 'MN - Owatonna, Owatonna Degner Regional Airport',
    'KPKD' => 'MN - Park Rapids, Park Rapids Municipal Airport',
    'KPEX' => 'MN - Paynesville, Paynesville Municipal Airport',
    'KPWC' => 'MN - Pine River, Pine River Regional Airport',
    'KPQN' => 'MN - Pipestone, Pipestone Municipal Airport',
    'KFKA' => 'MN - Preston, Fillmore County Airport',
    'KPNM' => 'MN - Princeton',
    'KRGK' => 'MN - Red Wing, Red Wing Municipal Airport',
    'KRWF' => 'MN - Redwood Falls, Redwood Falls Municipal Airport',
    'KRST' => 'MN - Rochester, Rochester International Airport',
    'KROX' => 'MN - Roseau, Roseau Municipal Airport/Rudy Billberg Field',
    'KROS' => 'MN - Rush City, Rush City Regional Airport',
    'KBFW' => 'MN - Silver Bay',
    'KDVP' => 'MN - Slayton, Slayton Municipal Airport',
    'KSGS' => 'MN - South St. Paul, South St. Paul Municipal-Richard E. Fleming Field Airport',
    'KSTC' => 'MN - St Cloud, St Cloud Regional Airport',
    'KJYG' => 'MN - St. James, St. James Municipal Airport',
    'KSTP' => 'MN - St. Paul, St. Paul Downtown Holman Field',
    'KSYN' => 'MN - Stanton, Stanton Airfield',
    'KSAZ' => 'MN - Staples, Staples Municipal Airport',
    'KTVF' => 'MN - Thief River Falls, Thief River Falls Regional Airport',
    'KTWM' => 'MN - Two Harbors',
    'KADC' => 'MN - Wadena, Wadena Municipal Airport',
    'KRRT' => 'MN - Warroad, Warroad International Airport-Swede Carlson Field',
    'KACQ' => 'MN - Waseca, Waseca Municipal Airport',
    'KVWU' => 'MN - Waskish, Waskish Municipal Airport',
    'KETH' => 'MN - Wheaton, Wheaton Municipal Airport',
    'KILL' => 'MN - Willmar, Willmar Municipal Airport-John L Rice Field',
    'KMWM' => 'MN - Windom, Windom Municipal Airport',
    'KONA' => 'MN - Winona, Winona Municipal Airport-Max Conrad Field',
    'KOTG' => 'MN - Worthington, Worthington Municipal Airport',
    'KCGI' => 'MO - Cape Girardeau, Cape Girardeau Regional Airport',
    'KCDJ' => 'MO - Chillicothe, Chillicothe Agri-Science Center',
    'KCOU' => 'MO - Columbia, Columbia Regional Airport',
    'KFAM' => 'MO - Farmington Airport',
    'KTBN' => 'MO - Fort Leonard Wood',
    'KJEF' => 'MO - Jefferson City, Jefferson City Memorial Airport',
    'KJLN' => 'MO - Joplin, Joplin Regional Airport',
    'KAIZ' => 'MO - Kaiser Lake Ozark, Lee C Fine Memorial Airport',
    'KMKC' => 'MO - Kansas City, Kansas City Downtown Airport',
    'KMCI' => 'MO - Kansas City, Kansas City International Airport',
    'KIRK' => 'MO - Kirksville, Kirksville Regional Airport',
    'KLXT' => 'MO - Lee\'s Summit, Lee\'s Summit Municipal Airport',
    'KPOF' => 'MO - Poplar Bluff, Poplar Bluff Municipal Airport',
    'KVIH' => 'MO - Rolla / Vichy, Rolla National Airport',
    'KDMO' => 'MO - Sedalia, Sedalia Memorial Airport',
    'KSGF' => 'MO - Springfield, Springfield Regional Airport',
    'KSET' => 'MO - St. Charles, St. Charles County Smartt Airport',
    'KSTJ' => 'MO - St. Joseph, Rosecrans Memorial Airport',
    'KSTL' => 'MO - St. Louis, Lambert-St. Louis International Airport',
    'KSUS' => 'MO - St. Louis, Spirit Of St. Louis Airport',
    'KUNO' => 'MO - West Plains, West Plains Municipal Airport',
    'KSZL' => 'MO - Whiteman Air Force Base',
    'KCBM' => 'MS - Columbus Air Force Base',
    'KGTR' => 'MS - Columbus/West Point/Starkville, Golden Triangle Regional Airport',
    'KGLH' => 'MS - Greenville, Mid Delta Regional Airport',
    'KGWO' => 'MS - Greenwood, Greenwood-LeFlore Airport',
    'KGPT' => 'MS - Gulfport, Gulfport-Biloxi Regional Airport',
    'KHBG' => 'MS - Hattiesburg, Bobby L Chain Municipal Airport',
    'KPIB' => 'MS - Hattiesburg/Laurel, Hattiesburg-Laurel Regional Airport',
    'KHKS' => 'MS - Jackson, Hawkins Field Airport',
    'KJAN' => 'MS - Jackson, Jackson International Airport',
    'KBIX' => 'MS - Keesler Air Force Base / Biloxi',
    'KMCB' => 'MS - McComb, McComb / Pike County / John E Lewis Field Airport',
    'KMEI' => 'MS - Meridian, Key Field',
    'KNMM' => 'MS - Meridian, Meridian Naval Air Station - McCain Field',
    'KHEZ' => 'MS - Natchez, Hardy-Anders Field Natchez-Adams County Airport',
    'KOLV' => 'MS - Olive Branch, Olive Branch Airport',
    'KPQL' => 'MS - Pascagoula, Lott International Airport',
    'KUTA' => 'MS - Tunica, Tunica Municipal Airport',
    'KTUP' => 'MS - Tupelo, Tupelo Regional Airport',
    'KBHK' => 'MT - Baker, Baker Municipal Airport',
    'KBIL' => 'MT - Billings, Billings Logan International Airport',
    'KBZN' => 'MT - Bozeman, Gallatin Field',
    'K8S0' => 'MT - Browning, Starr-Browning Airstrip',
    'KBTM' => 'MT - Butte, Bert Mooney Airport',
    'KCTB' => 'MT - Cut Bank, Cut Bank Municipal Airport',
    'KDLN' => 'MT - Dillon, Dillon Airport',
    'K3DU' => 'MT - Drummond',
    'KGGW' => 'MT - Glasgow, Glasgow International Airport',
    'KGDV' => 'MT - Glendive, Dawson Community Airport',
    'KGTF' => 'MT - Great Falls, Great Falls International Airport',
    'KHVR' => 'MT - Havre, Havre City-County Airport',
    'KHLN' => 'MT - Helena, Helena Regional Airport',
    'KJDN' => 'MT - Jordan, Jordan Airport',
    'KGPI' => 'MT - Kalispell, Glacier Park International Airport',
    'KLWT' => 'MT - Lewistown, Lewistown Municipal Airport',
    'KLVM' => 'MT - Livingston, Mission Field Airport',
    'KGFA' => 'MT - Malmstrom Air Force Base',
    'KMLS' => 'MT - Miles City, Frank Wiley Field Airport',
    'KMSO' => 'MT - Missoula, Missoula International Airport',
    'KSDY' => 'MT - Sidney-Richland',
    'KWYS' => 'MT - West Yellowstone',
    'KOLF' => 'MT - Wolf Point, Clayton Airport',
    'KASJ' => 'NC - Ahoskie, Tri-County Airport',
    'KVUJ' => 'NC - Albemarle, Stanly County Airport',
    'KRHP' => 'NC - Andrews, Andrews-Murphy Airport',
    'KAVL' => 'NC - Asheville, Asheville Regional Airport',
    'KMRH' => 'NC - Beaufort, Michael J Smith Field Airport',
    'KTNB' => 'NC - Boone, Watauga County Hospital Heliport',
    'KBUY' => 'NC - Burlington, Burlington Alamance Regional Airport',
    'KIGX' => 'NC - Chapel Hill, Williams Airport',
    'KCLT' => 'NC - Charlotte, Charlotte / Douglas International Airport',
    'KNKT' => 'NC - Cherry Point, Marine Corps Air Station',
    'KCTZ' => 'NC - Clinton, Sampson County Airport',
    'KJQF' => 'NC - Concord, Concord Regional Airport',
    'KONX' => 'NC - Currituck, Currituck County Airport',
    'KEDE' => 'NC - Edenton, Northeastern Regional Airport',
    'KECG' => 'NC - Elizabeth City, Elizabeth City Coast Guard Air Station',
    'KEYF' => 'NC - Elizabethtown, Curtis L Brown Jr. Field Airport',
    'KHRJ' => 'NC - Erwin, Harnett County Airport',
    'KFAY' => 'NC - Fayetteville, Fayetteville Regional Airport',
    'KFBG' => 'NC - Fort Bragg / Simmons Army Airfield',
    'K1A5' => 'NC - Franklin, Macon County Airport',
    'KAKH' => 'NC - Gastonia, Gastonia Municipal Airport',
    'KGWW' => 'NC - Goldsboro, Goldsboro-Wayne Municipal Airport',
    'KGSO' => 'NC - Greensboro, Piedmont Triad International Airport',
    'KHSE' => 'NC - Hatteras, Mitchell Field',
    'KHKY' => 'NC - Hickory, Hickory Regional Airport',
    'KOAJ' => 'NC - Jacksonville, Albert J Ellis Airport',
    'KNCA' => 'NC - Jacksonville, New River, Marine Corps Air Station',
    'KGEV' => 'NC - Jefferson, Ashe County Airport',
    'KDPL' => 'NC - Kenansville, Duplin County Airport',
    'KFFA' => 'NC - Kill Devil Hills, First Flight Airport',
    'KISO' => 'NC - Kinston, Kinston Regional Jetport at Stallings Field',
    'KEXX' => 'NC - Lexington, Davidson County Airport',
    'KIPJ' => 'NC - Lincolnton, Lincolnton-Lincoln County Regional Airport',
    'KLHZ' => 'NC - Louisburg, Franklin County Airport',
    'KLBT' => 'NC - Lumberton, Lumberton Municipal Airport',
    'KHFF' => 'NC - Mackall U. S. Army Airfield',
    'KMQI' => 'NC - Manteo / Dare County Regional',
    'KMEB' => 'NC - Maxton, Laurinburg-Maxton Airport',
    'KEQY' => 'NC - Monroe, Monroe Airport',
    'KMRN' => 'NC - Morganton, Morganton-Lenoir Airport',
    'KMWK' => 'NC - Mount Airy, Mount Airy/Surry County Airport',
    'KEWN' => 'NC - New Bern, Craven County Regional Airport',
    'KUKF' => 'NC - North Wilkesboro, Wilkes County Airport',
    'KSUT' => 'NC - Oak Island, Brunswick County Airport',
    'KHNZ' => 'NC - Oxford, Henderson-Oxford Airport',
    'KSOP' => 'NC - Pinehurst/Southern Pines, Moore County Airport',
    'KPGV' => 'NC - Pitt-Greenville Airport',
    'KPOB' => 'NC - Pope Air Force Base',
    'KRDU' => 'NC - Raleigh / Durham, Raleigh-Durham International Airport',
    'K78N' => 'NC - Reidsville, Rockingham County NC Shiloh Airport',
    'KRZZ' => 'NC - Roanoke Rapids, Halifax County Airport',
    'K45J' => 'NC - Rockingham, Rockingham-Hamlet Airport',
    'KRWI' => 'NC - Rocky Mount, Rocky Mount-Wilson Regional Airport',
    'KTDF' => 'NC - Roxboro, Person County Airport',
    'KFQD' => 'NC - Rutherfordton, Rutherford County-Marchman Field Airport',
    'KRUQ' => 'NC - Salisbury, Rowan County Airport',
    'KTTA' => 'NC - Sanford, Sanford-Lee County Regional Airport',
    'KGSB' => 'NC - Seymour-Johnson Air Force Base',
    'KEHO' => 'NC - Shelby, Shelby Municipal Airport',
    'KJNX' => 'NC - Smithfield, Johnston County Airport',
    'KSVH' => 'NC - Statesville, Statesville Municipal Airport',
    'KOCW' => 'NC - Washington, Warren Field Airport',
    'KCPC' => 'NC - Whiteville, Columbus County Municipal Airport',
    'KILM' => 'NC - Wilmington, Wilmington International Airport',
    'KINT' => 'NC - Winston Salem, Smith Reynolds Airport',
    'KBIS' => 'ND - Bismarck, Bismarck Municipal Airport',
    'KDVL' => 'ND - Devils Lake, Devils Lake Municipal Airport',
    'KDIK' => 'ND - Dickinson, Dickinson Municipal Airport',
    'KFAR' => 'ND - Fargo, Hector International Airport',
    'KN60' => 'ND - Garrison',
    'KRDR' => 'ND - Grand Forks Air Force Base',
    'KGFK' => 'ND - Grand Forks, Grand Forks International Airport',
    'KHEI' => 'ND - Hettinger, Hettinger Municipal Airport',
    'KJMS' => 'ND - Jamestown, Jamestown Municipal Airport',
    'KMIB' => 'ND - Minot Air Force Base',
    'KMOT' => 'ND - Minot, Minot International Airport',
    'KBWP' => 'ND - Wahpeton, Harry Stern Airport',
    'KISN' => 'ND - Williston, Sloulin Field International Airport',
    'KANW' => 'NE - Ainsworth Municipal',
    'KBVN' => 'NE - Albion, Albion Municipal Airport',
    'KAIA' => 'NE - Alliance, Alliance Municipal Airport',
    'KAUH' => 'NE - Aurora, Aurora Municipal Airport',
    'KBIE' => 'NE - Beatrice Municipal',
    'KHDE' => 'NE - Brewster Field Airport',
    'KBBW' => 'NE - Broken Bow, Broken Bow Municipal Airport',
    'KCDR' => 'NE - Chadron, Chadron Municipal Airport',
    'KOLU' => 'NE - Columbus, Columbus Municipal Airport',
    'KFNB' => 'NE - Falls City, Brenner Field Airport',
    'KFET' => 'NE - Fremont Municipal Airport',
    'KGRI' => 'NE - Grand Island, Central Nebraska Regional Airport',
    'KHSI' => 'NE - Hastings, Hastings Municipal Airport',
    'KHJH' => 'NE - Hebron, Hebron Municipal Airport',
    'KIML' => 'NE - Imperial, Imperial Municipal Airport',
    'KEAR' => 'NE - Kearney, Kearney Municipal Airport',
    'KIBM' => 'NE - Kimball, Kimball Municipal Airport/Robert E Arraj Field',
    'KLXN' => 'NE - Lexington, Jim Kelly Field Airport',
    'KLNK' => 'NE - Lincoln, Lincoln Municipal Airport',
    'KMCK' => 'NE - McCook, McCook Municipal Airport',
    'KAFK' => 'NE - Nebraska City, Nebraska City Municipal Airport',
    'KOFK' => 'NE - Norfolk, Stefan Memorial Airport',
    'KLBF' => 'NE - North Platte, North Platte Regional Airport',
    'KONL' => 'NE - O\'Neill / Baker Field',
    'KOGA' => 'NE - Ogallala, Searle Field Airport',
    'KOFF' => 'NE - Omaha / Offutt Air Force Base',
    'KOMA' => 'NE - Omaha, Eppley Airfield',
    'KMLE' => 'NE - Omaha, Millard Airport',
    'KODX' => 'NE - Ord, Evelyn Sharp Field Airport',
    'KPMV' => 'NE - Plattsmouth, Plattsmouth Municipal Airport',
    'KBFF' => 'NE - Scottsbluff, Heilig Field',
    'KSNY' => 'NE - Sidney, Sidney Municipal Airport',
    'KTQE' => 'NE - Tekamah, Tekamah Municipal Airport',
    'KTIF' => 'NE - Thedford, Thomas County Airport',
    'KVTN' => 'NE - Valentine, Miller Field',
    'KLCG' => 'NE - Wayne, Wayne Municipal Airport',
    'KJYR' => 'NE - York, York Municipal Airport',
    'KBML' => 'NH - Berlin, Berlin Municipal Airport',
    'KCON' => 'NH - Concord, Concord Municipal Airport',
    'KAFN' => 'NH - Jaffrey, Jaffrey Municipal-Silver Ranch Airport',
    'KEEN' => 'NH - Keene, Dillant-Hopkins Airport',
    'KLCI' => 'NH - Laconia, Laconia Municipal Airport',
    'KLEB' => 'NH - Lebanon, Lebanon Municipal Airport',
    'KMHT' => 'NH - Manchester, Manchester Airport',
    'KMWN' => 'NH - Mount Washington',
    'KASH' => 'NH - Nashua, Boire Field Airport',
    'KPSM' => 'NH - Pease Air Force Base / Portsmouth',
    'K1P1' => 'NH - Plymouth, Plymouth Municipal Airport',
    'KDAW' => 'NH - Rochester, Skyhaven Airport',
    'KHIE' => 'NH - Whitefield, Mount Washington Regional Airport',
    'K12N' => 'NJ - Andover, Aeroflex-Andover Airport',
    'KACY' => 'NJ - Atlantic City, Atlantic City International Airport',
    'KBLM' => 'NJ - Belmar-Farmingdale',
    'KCDW' => 'NJ - Caldwell, Essex County Airport',
    'KNEL' => 'NJ - Lakehurst Naval Air Station',
    'KWRI' => 'NJ - Mcguire Air Force Base',
    'KMIV' => 'NJ - Millville, Millville Municipal Airport',
    'KMMU' => 'NJ - Morristown Municipal',
    'KVAY' => 'NJ - Mount Holly, South Jersey Regional Airport',
    'KEWR' => 'NJ - Newark, Newark International Airport',
    'KSMQ' => 'NJ - Somerville, Somerset Airport',
    'KFWN' => 'NJ - Sussex, Sussex Airport',
    'KTEB' => 'NJ - Teterboro, Teterboro Airport',
    'KTTN' => 'NJ - Trenton, Mercer County Airport',
    'KWWD' => 'NJ - Wildwood, Cape May County Airport',
    'KALM' => 'NM - Alamogordo-White',
    'KABQ' => 'NM - Albuquerque, Albuquerque International Airport',
    'KAEG' => 'NM - Albuquerque, Double Eagle II Airport',
    'KATS' => 'NM - Artesia, Artesia Municipal Airport',
    'KCVS' => 'NM - Cannon Air Force Base / Clovis',
    'KCNM' => 'NM - Carlsbad, Cavern City Air Terminal Airport',
    'KE33' => 'NM - Chama',
    'KCAO' => 'NM - Clayton, Clayton Municipal Airpark',
    'KCQC' => 'NM - Clines Corners',
    'KCVN' => 'NM - Clovis, Clovis Municipal Airport',
    'K4CR' => 'NM - Corona / Lincoln',
    'KDMN' => 'NM - Deming, Deming Municipal Airport',
    'KFMN' => 'NM - Farmington, Four Corners Regional Airport',
    'KGUP' => 'NM - Gallup, Gallup Municipal Airport',
    'KGNT' => 'NM - Grants, Grants-Milan Municipal Airport',
    'KHOB' => 'NM - Hobbs / Lea County',
    'KHMN' => 'NM - Holloman Air Force Base',
    'KLRU' => 'NM - Las Cruces, Las Cruces International Airport',
    'KLVS' => 'NM - Las Vegas, Las Vegas Municipal Airport',
    'KLAM' => 'NM - Los Alamos, Los Alamos Airport',
    'K4MY' => 'NM - Moriarty',
    'KRTN' => 'NM - Raton, Raton Municipal \ Crews Field Airport',
    'KROW' => 'NM - Roswell, Roswell Industrial Air Center Airport',
    'KSRR' => 'NM - Ruidoso Regional',
    'KSAF' => 'NM - Santa Fe, Santa Fe County Municipal Airport',
    'K5T6' => 'NM - Santa Teresa, Dona Ana County Airport at Santa Teresa',
    'KSVC' => 'NM - Silver City / Grant',
    'KSKX' => 'NM - Taos, Taos Regional Airport',
    'K4SL' => 'NM - Torreon',
    'KTCS' => 'NM - Truth Or Consequences, Truth Or Consequences Municipal Airport',
    'KTCC' => 'NM - Tucumcari, Tucumcari Municipal Airport',
    'KB23' => 'NV - Battle Mountain',
    'KEKO' => 'NV - Elko, Elko Regional Airport',
    'KELY' => 'NV - Ely, Ely Airport',
    'KP68' => 'NV - Eureka',
    'KNFL' => 'NV - Fallon, Naval Air Station',
    'KINS' => 'NV - Indian Springs, Indian Springs Auxiliary AFLD Nellis AFB',
    'KHND' => 'NV - Las Vegas, Henderson Executive Airport',
    'KLAS' => 'NV - Las Vegas, McCarran International Airport',
    'KVGT' => 'NV - Las Vegas, North Las Vegas Airport',
    'KBJN' => 'NV - Las Vegas, Tonopah Range #74 Nellis AFB',
    'KLOL' => 'NV - Lovelock, Derby Field Airport',
    'KDRA' => 'NV - Mercury, Desert Rock Airport',
    'KLSV' => 'NV - Nellis Air Force Base',
    'KRNO' => 'NV - Reno, Reno Tahoe International Airport',
    'KTPH' => 'NV - Tonopah, Tonopah Airport',
    'K9BB' => 'NV - Wells',
    'KAWH' => 'NV - Wildhorse Reservation / Elko',
    'KWMC' => 'NV - Winnemucca, Winnemucca Municipal Airport',
    'KALB' => 'NY - Albany, Albany International Airport',
    'KBGM' => 'NY - Binghamton, Binghamton Regional Airport',
    'KBUF' => 'NY - Buffalo, Greater Buffalo International Airport',
    'KDSV' => 'NY - Dansville, Dansville Municipal Airport',
    'KDKK' => 'NY - Dunkirk, Chautauqua County / Dunkirk Airport',
    'KHTO' => 'NY - East Hampton, East Hampton Airport',
    'KELM' => 'NY - Elmira, Elmira / Corning Regional Airport',
    'KFRG' => 'NY - Farmingdale, Republic Airport',
    'KGTB' => 'NY - Fort Drum / Wheeler-Sack U. S. Army Airfield',
    'KGFL' => 'NY - Glens Falls, Floyd Bennett Memorial Airport',
    'KISP' => 'NY - Islip, Long Island Mac Arthur Airport',
    'KITH' => 'NY - Ithaca, Ithaca Tompkins Regional Airport',
    'KJHW' => 'NY - Jamestown, Chautauqua County/Jamestown Airport',
    'KMSS' => 'NY - Massena, Massena International-Richards Field',
    'KMTP' => 'NY - Montauk, Montauk Airport',
    'KMGJ' => 'NY - Montgomery, Orange County Airport',
    'KMSV' => 'NY - Monticello, Sullivan County International Airport',
    'KNYC' => 'NY - New York City, Central Park',
    'KJFK' => 'NY - New York, Kennedy International Airport',
    'KLGA' => 'NY - New York, La Guardia Airport',
    'KSWF' => 'NY - Newburgh / Stewart',
    'KIAG' => 'NY - Niagara Falls, Niagara Falls International Airport',
    'KOGS' => 'NY - Ogdensburg International',
    'KPEO' => 'NY - Penn Yan, Penn Yan Airport',
    'KPLB' => 'NY - Plattsburgh, Clinton County Airport',
    'KPOU' => 'NY - Poughkeepsie, Dutchess County Airport',
    'KROC' => 'NY - Rochester, Greater Rochester International Airport',
    'KSLK' => 'NY - Saranac Lake, Adirondack Regional Airport',
    'KSCH' => 'NY - Schenectady Airport',
    'KHWV' => 'NY - Shirley, Brookhaven Airport',
    'KSYR' => 'NY - Syracuse, Syracuse Hancock International Airport',
    'KUCA' => 'NY - Utica, Oneida County Airport',
    'KART' => 'NY - Watertown, Watertown International Airport',
    'KELZ' => 'NY - Wellsville, Wellsville Municipal Airport',
    'KFOK' => 'NY - Westhampton Beach, The Gabreski Airport',
    'KHPN' => 'NY - White Plains, Westchester County Airport',
    'KAKR' => 'OH - Akron, Akron Fulton International Airport',
    'KCAK' => 'OH - Akron, Akron-Canton Regional Airport',
    'KLUK' => 'OH - Cincinnati, Cincinnati Municipal Airport Lunken Field',
    'KCGF' => 'OH - Cleveland / Cuyahoga',
    'KBKL' => 'OH - Cleveland, Burke Lakefront Airport',
    'KCLE' => 'OH - Cleveland, Cleveland-Hopkins International Airport',
    'KTZR' => 'OH - Columbus, Bolton Field Airport',
    'KOSU' => 'OH - Columbus, Ohio State University Airport',
    'KCMH' => 'OH - Columbus, Port Columbus International Airport',
    'KFFO' => 'OH - Dayton / Wright-Patterson Air Force Base',
    'KDAY' => 'OH - Dayton, Cox Dayton International Airport',
    'KMGY' => 'OH - Dayton, Dayton-Wright Brothers Airport',
    'KDFI' => 'OH - Defiance, Defiance Memorial Airport',
    'KFDY' => 'OH - Findlay, Findlay Airport',
    'KHAO' => 'OH - Hamilton, Butler County Regional Airport',
    'KLHQ' => 'OH - Lancaster, Fairfield County Airport',
    'KAOH' => 'OH - Lima, Lima Allen County Airport',
    'KLPR' => 'OH - Lorain / Elyria, Lorain County Regional Airport',
    'KMFD' => 'OH - Mansfield, Mansfield Lahm Municipal Airport',
    'KMNN' => 'OH - Marion, Marion Municipal Airport',
    'KPHD' => 'OH - New Philadelphia, Harry Clever Field',
    'KVTA' => 'OH - Newark, Newark Heath Airport',
    'KLCK' => 'OH - Rickenbacker Air National Guard Base',
    'KSGH' => 'OH - Springfield, Springfield-Beckley Municipal Airport',
    'KTDZ' => 'OH - Toledo, Metcalf Field',
    'KTOL' => 'OH - Toledo, Toledo Express Airport',
    'KILN' => 'OH - Wilmington, Airborne Airpark Airport',
    'KBJJ' => 'OH - Wooster, Wayne County Airport',
    'KYNG' => 'OH - Youngstown, Youngstown-Warren Regional Airport',
    'KZZV' => 'OH - Zanesville, Zanesville Municipal Airport',
    'KADH' => 'OK - Ada, Ada Municipal Airport',
    'KLTS' => 'OK - Altus Air Force Base',
    'KAXS' => 'OK - Altus, Altus/Quartz Mountain Regional Airport',
    'KAVK' => 'OK - Alva, Alva Regional Airport',
    'K1F0' => 'OK - Ardmore, Ardmore Downtown Executive Airport',
    'KADM' => 'OK - Ardmore, Ardmore Municipal Airport',
    'KBVO' => 'OK - Bartlesville, Bartlesville Municipal Airport',
    'KCQB' => 'OK - Chandler, Chandler Municipal Airport',
    'KCHK' => 'OK - Chickasha, Chickasha Municipal Airport',
    'KGCM' => 'OK - Claremore, Claremore Regional Airport',
    'KCLK' => 'OK - Clinton, Clinton Regional Airport',
    'KCSM' => 'OK - Clinton, Clinton-Sherman Airport',
    'KCUH' => 'OK - Cushing, Cushing Municipal Airport',
    'KDUC' => 'OK - Duncan, Halliburton Field Airport',
    'KDUA' => 'OK - Durant, Eaker Field Airport',
    'KRQO' => 'OK - El Reno, El Reno Regional Airport',
    'KWDG' => 'OK - Enid, Enid Woodring Regional Airport',
    'KFSI' => 'OK - Fort Sill',
    'KFDR' => 'OK - Frederick, Frederick Municipal Airport',
    'KGAG' => 'OK - Gage, Gage Airport',
    'KGMJ' => 'OK - Grove, Grove Municipal Airport',
    'KGOK' => 'OK - Guthrie, Guthrie Municipal Airport',
    'KGUY' => 'OK - Guymon / Guymon Municipal Airport',
    'KHBR' => 'OK - Hobart, Hobart Municipal Airport',
    'K4O4' => 'OK - Idabel, Mc Curtain County Regional Airport',
    'KLAW' => 'OK - Lawton, Lawton Municipal Airport',
    'KMLC' => 'OK - McAlester, McAlester Regional Airport',
    'KMKO' => 'OK - Muskogee, Davis Field',
    'KOUN' => 'OK - Norman / Max Westheimer',
    'KPWA' => 'OK - Oklahoma City, Wiley Post Airport',
    'KOKC' => 'OK - Oklahoma City, Will Rogers World Airport',
    'KOKM' => 'OK - Okmulgee, Okmulgee Municipal Airport',
    'KPVJ' => 'OK - Pauls Valley, Pauls Valley Municipal Airport',
    'KPNC' => 'OK - Ponca City, Ponca City Municipal Airport',
    'KRKR' => 'OK - Poteau, Robert S Kerr Airport',
    'KJSV' => 'OK - Sallisaw, Sallisaw Municipal Airport',
    'KSRE' => 'OK - Seminole, Seminole Municipal Airport',
    'KSNL' => 'OK - Shawnee, Shawnee Municipal Airport',
    'KSWO' => 'OK - Stillwater, Stillwater Regional Airport',
    'KTQH' => 'OK - Tahlequah, Tahlequah Municipal Airport',
    'KTIK' => 'OK - Tinker Air Force Base',
    'KRVS' => 'OK - Tulsa, Jones Jr. Airport',
    'KTUL' => 'OK - Tulsa, Tulsa International Airport',
    'KEND' => 'OK - Vance Air Force Base / Enid',
    'KJWG' => 'OK - Watonga, Watonga Airport',
    'KWWR' => 'OK - Woodward, West Woodward Airport',
    'KAST' => 'OR - Astoria, Astoria Regional Airport',
    'KUAO' => 'OR - Aurora, Aurora State Airport',
    'KBKE' => 'OR - Baker City, Baker City Municipal Airport',
    'KBOK' => 'OR - Brookings, Brookings Airport',
    'KBNO' => 'OR - Burns, Burns Municipal Airport',
    'KCZK' => 'OR - Cascade Locks State',
    'KCVO' => 'OR - Corvallis, Corvallis Municipal Airport',
    'KEUG' => 'OR - Eugene, Mahlon Sweet Field',
    'KHRI' => 'OR - Hermiston, Hermiston Municipal Airport',
    'K5J0' => 'OR - John Day, John Day State Airport',
    'KLMT' => 'OR - Klamath Falls, Klamath Falls International Airport',
    'KLGD' => 'OR - La Grande, La Grande/Union County Airport',
    'KLKV' => 'OR - Lakeview, Lake County Airport',
    'KMMV' => 'OR - McMinnville, McMinnville Municipal Airport',
    'KMEH' => 'OR - Meacham, Meacham',
    'KMFR' => 'OR - Medford, Rogue Valley International Airport',
    'KONP' => 'OR - Newport, Newport Municipal Airport',
    'KOTH' => 'OR - North Bend, North Bend Municipal Airport',
    'KONO' => 'OR - Ontario, Ontario Municipal Airport',
    'KPDT' => 'OR - Pendleton, Eastern Oregon Regional At Pendleton Airport',
    'KPDX' => 'OR - Portland, Portland International Airport',
    'KHIO' => 'OR - Portland, Portland-Hillsboro Airport',
    'KTTD' => 'OR - Portland, Portland-Troutdale Airport',
    'KRDM' => 'OR - Redmond, Roberts Field Airport',
    'KREO' => 'OR - Rome, Rome',
    'KRBG' => 'OR - Roseburg, Roseburg Regional Airport',
    'KSLE' => 'OR - Salem, McNary Field',
    'KSPB' => 'OR - Scappoose, Scappoose Industrial Airpark',
    'KSXT' => 'OR - Sexton Summit,',
    'KDLS' => 'OR - The Dalles, Columbia Gorge Regional / The Dalles Municipal Airport',
    'KS47' => 'OR - Tillamook, Tillamook Airport',
    'KABE' => 'PA - Allentown, Lehigh Valley International Airport',
    'KAOO' => 'PA - Altoona, Altoona-Blair County Airport',
    'KBVI' => 'PA - Beaver Falls Airport',
    'KBFD' => 'PA - Bradford, Bradford Regional Airport',
    'KBTP' => 'PA - Butler, Butler County Airport/K W Scholter Field',
    'KFIG' => 'PA - Clearfield, Clearfield-Lawrence Airport',
    'KDYL' => 'PA - Doylestown, Doylestown Airport',
    'KDUJ' => 'PA - Du Bois, Du Bois-Jefferson County Airport',
    'KERI' => 'PA - Erie, Erie International Airport',
    'KFKL' => 'PA - Franklin, Venango Regional Airport',
    'KCXY' => 'PA - Harrisburg, Capital City Airport',
    'KMDT' => 'PA - Harrisburg, Harrisburg International Airport',
    'KIDI' => 'PA - Indiana / Stewart Field',
    'KJST' => 'PA - Johnstown, Johnstown-Cambria County Airport',
    'KLNS' => 'PA - Lancaster, Lancaster Airport',
    'KLBE' => 'PA - Latrobe / Westmorland',
    'KGKJ' => 'PA - Meadville, Port Meadville Airport',
    'KMPO' => 'PA - Mount Pocono, Pocono Mountains Municipal Airport',
    'KMUI' => 'PA - Muir Army Air Field / Indiantown',
    'KUCP' => 'PA - New Castle, New Castle Municipal Airport',
    'KPNE' => 'PA - Philadelphia, Northeast Philadelphia Airport',
    'KPHL' => 'PA - Philadelphia, Philadelphia International Airport',
    'KAGC' => 'PA - Pittsburgh, Allegheny County Airport',
    'KPIT' => 'PA - Pittsburgh, Pittsburgh International Airport',
    'KPTW' => 'PA - Pottstown, Pottstown Limerick Airport',
    'KUKT' => 'PA - Quakertown, Quakertown Airport',
    'KRDG' => 'PA - Reading, Reading Regional Airport',
    'KSEG' => 'PA - Selinsgrove, Penn Valley Airport',
    'KUNV' => 'PA - State College, University Park Airport',
    'KAFJ' => 'PA - Washington, Washington County Airport',
    'KAVP' => 'PA - Wilkes-Barre - Scranton, Wilkes-Barre / Scranton International Airport',
    'KIPT' => 'PA - Williamsport, Williamsport Regional Airport',
    'KNXX' => 'PA - Willow Grove, Naval Air Station',
    'KTHV' => 'PA - York, York Airport',
    'TJBQ' => 'PR - Aquadilla, Rafael Hernandez Airport',
    'TJMZ' => 'PR - Mayaguez, Eugenio Maria de Hostos Airport',
    'TJPS' => 'PR - Ponce, Mercedita Airport',
    'TJNR' => 'PR - Roosevelt Roads, Roosevelt Roads Naval Station, Ofstie Field',
    'TJSJ' => 'PR - San Juan, Luis Munoz Marin International Airport',
    'KBID' => 'RI - Block Island, Block Island State Airport',
    'KOQU' => 'RI - N. Kingston / Quonset',
    'KUUU' => 'RI - Newport, Newport State Airport',
    'KSFZ' => 'RI - Pawtucket, North Central State Airport',
    'KPVD' => 'RI - Providence, Theodore Francis Green State Airport',
    'KWST' => 'RI - Westerly, Westerly State Airport',
    'KAND' => 'SC - Anderson, Anderson County Airport',
    'KNBC' => 'SC - Beaufort, Marine Corps Air Station',
    'KCHS' => 'SC - Charleston, Charleston Air Force Base',
    'KCEU' => 'SC - Clemson, Clemson-Oconee County Airport',
    'KCAE' => 'SC - Columbia, Columbia Metropolitan Airport',
    'KCUB' => 'SC - Columbia, Columbia Owens Downtown Airport',
    'KUDG' => 'SC - Darlington, Darlington County Jetport Airport',
    'KFLO' => 'SC - Florence, Florence Regional Airport',
    'KGMU' => 'SC - Greenville, Greenville Downtown Airport',
    'KGRD' => 'SC - Greenwood, Greenwood County Airport',
    'KGSP' => 'SC - Greer, Greenville-Spartanburg Airport',
    'KHXD' => 'SC - Hilton Head Island, Hilton Head Airport',
    'KMMT' => 'SC - McEntire Air National Guard Weather Facility Base',
    'KMYR' => 'SC - Myrtle Beach Air Force Base',
    'KCRE' => 'SC - North Myrtle Beach, Grand Strand Airport',
    'KOGB' => 'SC - Orangeburg, Orangeburg Municipal Airport',
    'KUZA' => 'SC - Rock Hill, Rock Hill - York County Airport',
    'KSSC' => 'SC - Shaw Air Force Base',
    'KABR' => 'SD - Aberdeen, Aberdeen Regional Airport',
    'KBKX' => 'SD - Brookings, Brookings Municipal Airport',
    'K2WX' => 'SD - Buffalo',
    'K9V9' => 'SD - Chamberlain, Chamberlain Municipal Airport',
    'KCUT' => 'SD - Custer, Custer County Airport',
    'KRCA' => 'SD - Ellsworth Air Force Base',
    'KD07' => 'SD - Faith',
    'KHON' => 'SD - Huron, Huron Regional Airport',
    'KMHE' => 'SD - Mitchell, Mitchell Municipal Airport',
    'KMBG' => 'SD - Mobridge, Mobridge Municipal Airport',
    'KPHP' => 'SD - Philip, Philip Airport',
    'KPIR' => 'SD - Pierre, Pierre Regional Airport',
    'KIEN' => 'SD - Pine Ridge, Pine Ridge Airport',
    'KRAP' => 'SD - Rapid City, Rapid City Regional Airport',
    'KFSD' => 'SD - Sioux Falls, Foss Field',
    'K8D3' => 'SD - Sisseton, Sisseton Municipal Airport',
    'KATY' => 'SD - Watertown, Watertown Municipal Airport',
    'KSFD' => 'SD - Winner, Bob Wiley Field Airport',
    'KYKN' => 'SD - Yankton, Chan Gurney Municipal Airport',
    'KTRI' => 'TN - Bristol / Johnson / Kingsport, Tri-City Regional Airport',
    'KCHA' => 'TN - Chattanooga, Lovell Field',
    'KCKV' => 'TN - Clarksville, Outlaw Field Airport',
    'KCSV' => 'TN - Crossville, Crossville Memorial-Whitson Field Airport',
    'KDYR' => 'TN - Dyersburg, Dyersburg Municipal Airport',
    'KMKL' => 'TN - Jackson, McKellar-Sipes Regional Airport',
    'KTYS' => 'TN - Knoxville, McGhee Tyson Airport',
    'KMEM' => 'TN - Memphis, Memphis International Airport',
    'KNQA' => 'TN - Millington, Millington Municipal Airport',
    'KBNA' => 'TN - Nashville, Nashville International Airport',
    'KOQT' => 'TN - Oak Ridge',
    'KMQY' => 'TN - Smyrna, Smyrna Airport',
    'KABI' => 'TX - Abilene, Abilene Regional Airport',
    'KDYS' => 'TX - Abilene, Dyess Air Force Base',
    'KALI' => 'TX - Alice, Alice International Airport',
    'KE38' => 'TX - Alpine, Alpine-Casparis Municipal Airport',
    'KAMA' => 'TX - Amarillo, Amarillo International Airport',
    'KLBX' => 'TX - Angleton / Lake Jackson, Brazoria County Airport',
    'KGKY' => 'TX - Arlington, Arlington Municipal Airport',
    'KATT' => 'TX - Austin City, Austin Camp Mabry',
    'KAUS' => 'TX - Austin, Austin-Bergstrom International Airport',
    'KBYY' => 'TX - Bay City, Bay City Municipal Airport',
    'KBPT' => 'TX - Beaumont / Port Arthur, Southeast Texas Regional Airport',
    'KBGD' => 'TX - Borger, Hutchinson County Airport',
    'KBBD' => 'TX - Brady, Curtis Field Airport',
    'K11R' => 'TX - Brenham, Brenham Municipal Airport',
    'KXBP' => 'TX - Bridgeport, Bridgeport Municipal Airport',
    'KBRO' => 'TX - Brownsville, Brownsville / South Padre Island International Airport',
    'KBWD' => 'TX - Brownwood, Brownwood Regional Airport',
    'KBMQ' => 'TX - Burnet, Burnet Municipal Craddock Field',
    'KRWV' => 'TX - Caldwell, Caldwell Municipal Airport',
    'KHHF' => 'TX - Canadian, Hemphill County Airport',
    'KCDS' => 'TX - Childress, Childress Municipal Airport',
    'KLBR' => 'TX - Clarksville, Clarksville/Red River County-J D Trissell Field Airport',
    'KCLL' => 'TX - College Station, Easterwood Field',
    'KMKN' => 'TX - Comanche, Comanche County-City Airport',
    'KCXO' => 'TX - Conroe, Montgomery County Airport',
    'KCRP' => 'TX - Corpus Christi, Corpus Christi International Airport',
    'KNGP' => 'TX - Corpus Christi, Corpus Christi Naval Air Station/Truax Field',
    'KCRS' => 'TX - Corsicana, Campbell Field-Corsicana Municipal Airport',
    'KCOT' => 'TX - Cotulla, Cotulla-La Salle County Airport',
    'KDHT' => 'TX - Dalhart, Dalhart Municipal Airport',
    'KADS' => 'TX - Dallas / Addison Airport',
    'KDFW' => 'TX - Dallas / Fort Worth, Dallas / Fort Worth International Airport',
    'KDAL' => 'TX - Dallas, Dallas Love Field',
    'KRBD' => 'TX - Dallas, Redbird Airport',
    'KLUD' => 'TX - Decatur, Decatur Municipal Airport',
    'KDRT' => 'TX - Del Rio, Del Rio International Airport',
    'KDTO' => 'TX - Denton, Denton Municipal Airport',
    'K6R6' => 'TX - Dryden, Terrel County Airport',
    'KDUX' => 'TX - Dumas, Moore County Airport',
    'KEBG' => 'TX - Edinburg, Edinburg International Airport',
    'KELP' => 'TX - El Paso, El Paso International Airport',
    'KHLR' => 'TX - Fort Hood, Hood AAF Ft Hood',
    'KGRK' => 'TX - Fort Hood, Robert Gray AAF Ft Hood',
    'KFST' => 'TX - Fort Stockton, Fort Stockton-Pecos County Airport',
    'KAFW' => 'TX - Fort Worth, Fort Worth Alliance Airport',
    'KFWS' => 'TX - Fort Worth, Fort Worth Spinks Airport',
    'KFTW' => 'TX - Fort Worth, Meacham International Airport',
    'KNFW' => 'TX - Fort Worth, Naval Air Station',
    'KT82' => 'TX - Fredericksburg, Gillespie County Airport',
    'KGLE' => 'TX - Gainesville, Gainesville Municipal Airport',
    'KGLS' => 'TX - Galveston, Scholes Field',
    'KGOP' => 'TX - Gatesville, City-County Airport',
    'KGTU' => 'TX - Georgetown, Georgetown Municipal Airport',
    'KGYB' => 'TX - Giddings, Giddings-Lee County Airport',
    'KJXI' => 'TX - Gilmer, Fox Stephens Field - Gilmer Municipal Airport',
    'KRPH' => 'TX - Graham, Graham Municipal Airport',
    'KGDJ' => 'TX - Granbury, Granbury Municipal Airport',
    'KGPM' => 'TX - Grand Prairie, Grand Prairie Municipal Airport',
    'KGVT' => 'TX - Greenville / Majors',
    'KHRL' => 'TX - Harlingen, Rio Grande Valley International Airport',
    'KHBV' => 'TX - Hebbronville, Jim Hogg County Airport',
    'KINJ' => 'TX - Hillsboro, Hillsboro Municipal Airport',
    'KHDO' => 'TX - Hondo, Hondo Municipal Airport',
    'KEFD' => 'TX - Houston / Ellington',
    'KDWH' => 'TX - Houston, Hooks Memorial Airport',
    'KHOU' => 'TX - Houston, Houston Hobby Airport',
    'KIAH' => 'TX - Houston, Houston Intercontinental Airport',
    'KLVJ' => 'TX - Houston, Pearland Regional Airport',
    'KSGR' => 'TX - Houston, Sugar Land Municipal / Hull Field Airport',
    'KUTS' => 'TX - Huntsville, Huntsville Municipal Airport',
    'KJSO' => 'TX - Jacksonville, Cherokee County Airport',
    'KJAS' => 'TX - Jasper, Jasper County-Bell Field Airport',
    'KJCT' => 'TX - Junction, Kimble County Airport',
    'KSKF' => 'TX - Kelly Air Force Base',
    'KERV' => 'TX - Kerrville, Kerrville Municipal Airport/Louis Schreiner Field',
    'KILE' => 'TX - Killeen, Skylark Field Airport',
    'KNQI' => 'TX - Kingsville, Naval Air Station',
    'K3T5' => 'TX - La Grange, Fayette Regional Air Center Airport',
    'KLNC' => 'TX - Lancaster, Lancaster Airport',
    'KLRD' => 'TX - Laredo, Laredo International Airport',
    'KDLF' => 'TX - Laughlin, Laughlin Air Force Base Auxiliary Airfield',
    'KAQO' => 'TX - Llano, Llano Municipal Airport',
    'KGGG' => 'TX - Longview, Gregg County Airport',
    'KLBB' => 'TX - Lubbock, Lubbock International Airport',
    'KLFK' => 'TX - Lufkin, Angelina County Airport',
    'KMRF' => 'TX - Marfa',
    'KTKI' => 'TX - Mc Kinney, Collin County Regional Airport at Mc Kinney',
    'KMFE' => 'TX - McAllen, Miller International Airport',
    'KHQZ' => 'TX - Mesquite, Mesquite Metro Airport',
    'KMDD' => 'TX - Midland, Midland Airpark',
    'KMAF' => 'TX - Midland, Midland International Airport',
    'KJWY' => 'TX - Midlothian/Waxahachie, Mid-Way Regional Airport',
    'KJDD' => 'TX - Mineola/Quitman, Wood County Airport',
    'KMWL' => 'TX - Mineral Wells, Mineral Wells Airport',
    'KOSA' => 'TX - Mount Pleasant, Mount Pleasant Regional Airport',
    'KOCH' => 'TX - Nacogdoches, A L Mangham Jr. Regional Airport',
    'KBAZ' => 'TX - New Braunfels, New Braunfels Municipal Airport',
    'KODO' => 'TX - Odessa, Odessa-Schlemeyer Field',
    'KORG' => 'TX - Orange, Orange County Airport',
    'KPSX' => 'TX - Palacios, Palacios Municipal Airport',
    'KPSN' => 'TX - Palestine, Palestine Municipal Airport',
    'KPPA' => 'TX - Pampa, Perry Lefors Field Airport',
    'KPRX' => 'TX - Paris / Cox Field',
    'KPEQ' => 'TX - Pecos, Pecos Municipal Airport',
    'KPYX' => 'TX - Perryton, Perryton Ochiltree County Airport',
    'KGDP' => 'TX - Pine Springs, Guadalupe Mountains National Park',
    'KPVW' => 'TX - Plainview, Hale County Airport',
    'KRAS' => 'TX - Port Aransas, Mustang Beach Airport',
    'KPIL' => 'TX - Port Isabel, Port Isabel-Cameron County Airport',
    'KRND' => 'TX - Randolph Air Force Base',
    'KRKP' => 'TX - Rockport, Aransas County Airport',
    'KECU' => 'TX - Rocksprings, Edwards County Airport',
    'KRPE' => 'TX - Sabine Pass',
    'KSJT' => 'TX - San Angelo, Mathis Field',
    'KSAT' => 'TX - San Antonio, San Antonio International Airport',
    'KSSF' => 'TX - San Antonio, Stinson Municipal Airport',
    'KHYI' => 'TX - San Marcos, San Marcos Municipal Airport',
    'KGNC' => 'TX - Seminole, Gaines County Airport',
    'KGYI' => 'TX - Sherman/Denison, Grayson County Airport',
    'KSNK' => 'TX - Snyder, Winston Field Airport',
    'KSOA' => 'TX - Sonora, Sonora Municipal Airport',
    'KSEP' => 'TX - Stephenville, Clark Field Municipal Airport',
    'KSLR' => 'TX - Sulphur Springs, Sulphur Springs Municipal Airport',
    'KSWW' => 'TX - Sweetwater, Avenger Field Airport',
    'KTPL' => 'TX - Temple, Draughon-Miller Central Texas Regional Airport',
    'KTRL' => 'TX - Terrell, Terrell Municipal Airport',
    'KTYR' => 'TX - Tyler, Tyler Pounds Field',
    'KUVA' => 'TX - Uvalde, Garner Field Airport',
    'KF05' => 'TX - Vernon, Wilbarger County Airport',
    'KVCT' => 'TX - Victoria, Victoria Regional Airport',
    'KPWG' => 'TX - Waco, Mc Gregor Executive Airport',
    'KACT' => 'TX - Waco, Waco Regional Airport',
    'KT65' => 'TX - Weslaco, Mid Valley Airport',
    'KARM' => 'TX - Wharton, Wharton Regional Airport',
    'KSPS' => 'TX - Wichita Falls, Sheppard Air Force Base',
    'KINK' => 'TX - Wink, Winkler County Airport',
    'K4BL' => 'UT - Blanding',
    'KBCE' => 'UT - Bryce Canyon, Bryce Canyon Airport',
    'KCDC' => 'UT - Cedar City, Cedar City Municipal Airport',
    'KU24' => 'UT - Delta',
    'KDPG' => 'UT - Dugway Proving Grounds',
    'KU28' => 'UT - Green River Range',
    'K4HV' => 'UT - Hanksville',
    'KHIF' => 'UT - Hill Air Force Base / Ogden',
    'KLGU' => 'UT - Logan, Logan-Cache Airport',
    'KMLF' => 'UT - Milford, Milford Municipal Airport',
    'KCNY' => 'UT - Moab, Canyonlands Field',
    'KOGD' => 'UT - Ogden, Ogden-Hinckley Airport',
    'KPUC' => 'UT - Price, Carbon County Airport',
    'KPVU' => 'UT - Provo, Provo Municipal Airport',
    'KSLC' => 'UT - Salt Lake City, Salt Lake City International Airport',
    'KSGU' => 'UT - St George, St George Municipal Airport',
    'KVEL' => 'UT - Vernal, Vernal Airport',
    'KENV' => 'UT - Wendover / Air Force Auxillary Field',
    'KVJI' => 'VA - Abingdon',
    'KOFP' => 'VA - Ashland, Hanover County Municipal Airport',
    'KCHO' => 'VA - Charlottesville, Charlottesville-Albemarle Airport',
    'KCPK' => 'VA - Chesapeake, Chesapeake Municipal Airport',
    'KCJR' => 'VA - Culpeper, Culpeper County Airport',
    'KDAN' => 'VA - Danville, Danville Regional Airport',
    'KPSK' => 'VA - Dublin / New River Valley',
    'KEMV' => 'VA - Emporia, Emporia-Greensville Regional Airport',
    'KFVX' => 'VA - Farmville',
    'KDAA' => 'VA - Fort Belvoir',
    'KFAF' => 'VA - Fort Eustis / Felker',
    'KFKN' => 'VA - Franklin / J B Rose',
    'KEZF' => 'VA - Fredericksburg, Shannon Airport',
    'KHLX' => 'VA - Hillsville',
    'KHSP' => 'VA - Hot Springs / Ingalls',
    'KLFI' => 'VA - Langley Air Force Base',
    'KJYO' => 'VA - Leesburg / Godfrey',
    'KLKU' => 'VA - Louisa, Louisa County Airport/Freeman Field',
    'KLYH' => 'VA - Lynchburg, Lynchburg Regional Airport',
    'KHEF' => 'VA - Manassas, Manassas Regional Airport/Harry P. Davis Field',
    'KMKJ' => 'VA - Marion / Wytheville',
    'KMTV' => 'VA - Martinsville',
    'KMFV' => 'VA - Melfa / Accomack Airport',
    'KPHF' => 'VA - Newport News, Newport News / Williamsburg International Airport',
    'KNGU' => 'VA - Norfolk, Naval Air Station',
    'KORF' => 'VA - Norfolk, Norfolk International Airport',
    'KOMH' => 'VA - Orange, Orange County Airport',
    'KPTB' => 'VA - Petersburg, Dinwiddie County Airport',
    'KNYG' => 'VA - Quantico, Marine Corps Air Facility',
    'K6V3' => 'VA - Richlands, Tazewell County Airport',
    'KRIC' => 'VA - Richmond, Richmond International Airport',
    'KROA' => 'VA - Roanoke, Roanoke Regional Airport',
    'KAVC' => 'VA - South Hill, Mecklenburg-Brunswick Regional Airport',
    'KRMN' => 'VA - Stafford, Stafford Regional Airport',
    'KSHD' => 'VA - Staunton / Shenandoah',
    'KSFQ' => 'VA - Suffolk, Suffolk Municipal Airport',
    'KNTU' => 'VA - Virginia Beach, Oceana, Naval Air Station',
    'KBCB' => 'VA - Virginia Tech Airport',
    'KAKQ' => 'VA - Wakefield, Wakefield Municipal Airport',
    'KWAL' => 'VA - Wallops Island, Wallops Flight Facility Airport',
    'KDCA' => 'VA - Washington DC, Reagan National Airport',
    'KIAD' => 'VA - Washington DC, Washington-Dulles International Airport',
    'KFYJ' => 'VA - West Point, Middle Peninsula Regional Airport',
    'KJGG' => 'VA - Williamsburg, Williamsburg-Jamestown Airport',
    'KOKV' => 'VA - Winchester Regional',
    'KLNP' => 'VA - Wise / Lonesome Pine',
    'KMPV' => 'VT - Barre / Montpelier, Knapp State Airport',
    'KDDH' => 'VT - Bennington, Bennington Morse State Airport',
    'KBTV' => 'VT - Burlington, Burlington International Airport',
    'KMVL' => 'VT - Morrisville, Morrisville-Stowe State Airport',
    'KRUT' => 'VT - Rutland, Rutland State Airport',
    'K1V4' => 'VT - Saint Johnsbury',
    'KVSF' => 'VT - Springfield, Hartness State Springfield Airport',
    'KAWO' => 'WA - Arlington Municipal',
    'KBLI' => 'WA - Bellingham, Bellingham International Airport',
    'KPWT' => 'WA - Bremerton, Bremerton National Airport',
    'KBVS' => 'WA - Burlington/Mount Vernon, Skagit Regional Airport',
    'KDEW' => 'WA - Deer Park, Deer Park Airport',
    'KORS' => 'WA - Eastsound, Orcas Island Airport',
    'KELN' => 'WA - Ellensburg, Ellensburg Bowers Field',
    'KEPH' => 'WA - Ephrata, Ephrata Municipal Airport',
    'KPAE' => 'WA - Everett, Snohomish County Airport',
    'KSKA' => 'WA - Fairchild Air Force Base',
    'KGRF' => 'WA - Fort Lewis / Gray U. S. Army Airfield',
    'KFHR' => 'WA - Friday Harbor, Friday Harbor Airport',
    'KHMS' => 'WA - Hanford',
    'KHQM' => 'WA - Hoquiam, Bowerman Airport',
    'KKLS' => 'WA - Kelso, Kelso-Longview Airport',
    'KMWH' => 'WA - Moses Lake, Grant County Airport',
    'K76S' => 'WA - Oak Harbor Airpark',
    'KOLM' => 'WA - Olympia, Olympia Airport',
    'KOMK' => 'WA - Omak, Omak Airport',
    'KPSC' => 'WA - Pasco, Tri-Cities Airport',
    'KCLM' => 'WA - Port Angeles, William R. Fairchild International Airport',
    'KPUW' => 'WA - Pullman / Moscow, Pullman / Moscow Regional Airport',
    'KUIL' => 'WA - Quillayute, Quillayute State Airport',
    'KRNT' => 'WA - Renton, Renton Municipal Airport',
    'KBFI' => 'WA - Seattle, Seattle Boeing Field',
    'KSEA' => 'WA - Seattle, Seattle-Tacoma International Airport',
    'KSHN' => 'WA - Shelton, Shelton Sanderson Field',
    'KSFF' => 'WA - Spokane, Felts Field',
    'KGEG' => 'WA - Spokane, Spokane International Airport',
    'KSMP' => 'WA - Stampede Pass',
    'KTCM' => 'WA - Tacoma / McChord Air Force Base',
    'KTIW' => 'WA - Tacoma, Tacoma Narrows Airport',
    'KTDO' => 'WA - Toledo-Winlock Memorial',
    'KVUO' => 'WA - Vancouver, Pearson Field Airport',
    'KALW' => 'WA - Walla Walla, Walla Walla Regional Airport',
    'KEAT' => 'WA - Wenatchee, Pangborn Memorial Airport',
    'KNUW' => 'WA - Whidbey Island, Naval Air Station',
    'KYKM' => 'WA - Yakima, Yakima Air Terminal',
    'KAIG' => 'WI - Antigo, Langlade County Airport',
    'KATW' => 'WI - Appleton / Outagamie',
    'KASX' => 'WI - Ashland, Kennedy Memorial Airport',
    'KDLL' => 'WI - Baraboo, Baraboo Wisconsin Dells Airport',
    'KOVS' => 'WI - Boscobel, Boscobel Airport',
    'KCLI' => 'WI - Clintonville, Clintonville Municipal Airport',
    'KEGV' => 'WI - Eagle River, Eagle River Union Airport',
    'KEAU' => 'WI - Eau Claire, Chippewa Valley Regional Airport',
    'KFLD' => 'WI - Fond Du Lac, Fond Du Lac County Airport',
    'KGRB' => 'WI - Green Bay, Austin Straubel International Airport',
    'KHYR' => 'WI - Hayward, Hayward Municipal Airport',
    'KJVL' => 'WI - Janesville / Rock County',
    'KUNU' => 'WI - Juneau, Dodge County Airport',
    'KENW' => 'WI - Kenosha, Kenosha Regional Airport',
    'KLSE' => 'WI - La Crosse, La Crosse Municipal Airport',
    'KRCX' => 'WI - Ladysmith, Ruck County Airport',
    'KLNL' => 'WI - Land O\' Lakes, Kings Land O\' Lakes Airport',
    'KLNR' => 'WI - Lone Rock, Tri-County Regional Airport',
    'KMSN' => 'WI - Madison, Dane County Regional-Truax Field',
    'KMTW' => 'WI - Manitowoc, Manitowoc County Airport',
    'KMFI' => 'WI - Marshfield, Marshfield Municipal Airport',
    'KMDZ' => 'WI - Medford, Taylor County Airport',
    'KRRL' => 'WI - Merrill, Merrill Municipal Airport',
    'KMWC' => 'WI - Milwaukee / Timmerman',
    'KMKE' => 'WI - Milwaukee, General Mitchell International Airport',
    'KMRJ' => 'WI - Mineral Point, Iowa County Airport',
    'KARV' => 'WI - Minocqua/Woodruff, Lakeland Airport/Noble F. Lee Memorial Field',
    'KEFT' => 'WI - Monroe, Monroe Municipal Airport',
    'KCWA' => 'WI - Mosinee / Central Wisconsin',
    'KRNH' => 'WI - New Richmond, New Richmond Municipal Airport',
    'KOEO' => 'WI - Osceola, L O Simenstad Municipal Airport',
    'KOSH' => 'WI - Oshkosh, Wittman Regional Airport',
    'KPBH' => 'WI - Phillips / Price County',
    'KPDC' => 'WI - Prairie Du Chien, Prairie Du Chien Municipal Airport',
    'KRAC' => 'WI - Racine, Batten International Airport',
    'KRHI' => 'WI - Rhinelander, Rhinelander-Oneida County Airport',
    'KRPD' => 'WI - Rice Lake, Rice Lake Regional-Carl\'s Field Airport',
    'KSBM' => 'WI - Sheboygan, Sheboygan County Memorial Airport',
    'KRZN' => 'WI - Siren, Burnett County Airport',
    'KCMY' => 'WI - Sparta, Sparta / Fort McCoy Airport',
    'KSTE' => 'WI - Stevens Point, Stevens Point Municipal Airport',
    'KSUE' => 'WI - Sturgeon Bay',
    'KSUW' => 'WI - Superior, Richard I. Bong Airport',
    'KTKV' => 'WI - Tomahawk, Tomahawk Regional Airport',
    'KVOK' => 'WI - Volk / Camp Douglas',
    'KRYV' => 'WI - Watertown',
    'KUES' => 'WI - Waukesha, Waukesha County Airport',
    'KPCZ' => 'WI - Waupaca, Waupaca Municipal Airport',
    'KAUW' => 'WI - Wausau, Wausau Downtown Airport',
    'KETB' => 'WI - West Bend, West Bend Municipal Airport',
    'KISW' => 'WI - Wisconsin Rapids, Alexander Field South Wood County Airport',
    'KBKW' => 'WV - Beckley, Raleigh County Memorial Airport',
    'KBLF' => 'WV - Bluefield, Mercer County Airport',
    'KW22' => 'WV - Buckhannon, Upshur County Regional Airport',
    'KCRW' => 'WV - Charleston, Yeager Airport',
    'KCKB' => 'WV - Clarksburg, Clarksburg Benedum Airport',
    'KEKN' => 'WV - Elkins, Elkins-Randolph County-Jennings Randolph Field',
    'KHTS' => 'WV - Huntington, Tri-State Airport',
    'KLWB' => 'WV - Lewisburg / Greenbrier',
    'KMRB' => 'WV - Martinsburg, Eastern West Virginia Regional/Shepherd Airport',
    'KMGW' => 'WV - Morgantown, Morgantown Municipal-Hart Field',
    'KPKB' => 'WV - Parkersburg, Mid-Ohio Valley Regional Airport',
    'KW99' => 'WV - Petersburg, Grant County Airport',
    'KI16' => 'WV - Pineville, Kee Field Airport',
    'K3I2' => 'WV - Point Pleasant, Mason County Airport',
    'K48I' => 'WV - Sutton, Braxton County Airport',
    'KHLG' => 'WV - Wheeling, Wheeling Ohio County Airport',
    'KARL' => 'WY - Arlington',
    'KBPI' => 'WY - Big Piney, Big Piney-Marbleton Airport',
    'KBRX' => 'WY - Bordeaux',
    'KBYG' => 'WY - Buffalo, Buffalo Johnson County Airport',
    'KCPR' => 'WY - Casper, Natrona County International Airport',
    'KCMS' => 'WY - Cemetery Separa',
    'KCYS' => 'WY - Cheyenne, Cheyenne Airport',
    'KCOD' => 'WY - Cody',
    'KDGW' => 'WY - Douglas, Converse County Airport',
    'KEVW' => 'WY - Evanston, Evanston-Uninta County Burns Field',
    'KGCC' => 'WY - Gillette, Gillette-Campbell County Airport',
    'KGEY' => 'WY - Greybull, South Big Horn County Airport',
    'KJAC' => 'WY - Jackson, Jackson Hole Airport',
    'KLND' => 'WY - Lander',
    'KLAR' => 'WY - Laramie, Laramie Regional Airport',
    'KPNA' => 'WY - Pinedale, Ralph Wenz Field Airport',
    'KPUM' => 'WY - Pumpkin Vine',
    'KRWL' => 'WY - Rawlins, Rawlins Municipal Airport',
    'KRIW' => 'WY - Riverton, Riverton Regional Airport',
    'KRKS' => 'WY - Rock Springs, Rock Springs-Sweetwater County Airport',
    'KSHR' => 'WY - Sheridan, Sheridan County Airport',
    'KSIB' => 'WY - Sibley Peak',
    'KTOR' => 'WY - Torrington, Torrington Municipal Airport',
    'KVDW' => 'WY - Vedauwoo',
    'KWRL' => 'WY - Worland, Worland Municipal Airport',
    'KP60' => 'WY - Yellowstone Lake',
  );
  
  $icao_codes['Uruguay'] = array(
    'SUAG' => 'Artigas',
    'SULS' => 'Capitan Corbeta',
    'SUMU' => 'Carrasco',
    'SUCA' => 'Colonia',
    'SUDU' => 'Durazno',
    'SUAA' => 'Melilla',
    'SUME' => 'Mercedes',
    'SUSO' => 'Salto',
  );
  
  $icao_codes['Uzbekistan'] = array(
    'UTNN' => 'Nukus / Karakalpakstan',
    'UTSS' => 'Samarkand',
    'UTTT' => 'Tashkent',
    'UTST' => 'Termez',
    'UTNU' => 'Urgench',
  );
  
  $icao_codes['Vanuatu'] = array(
    'NVVV' => 'Bauerfield Efate',
    'NVSL' => 'Lamap Malekula',
    'NVSS' => 'Pekoa Airport Santo',
    'NVSC' => 'Sola Vanua Lava',
  );
  
  $icao_codes['Venezuela'] = array(
    'SVAC' => 'Acarigua',
    'SVBC' => 'Barcelona',
    'SVBI' => 'Barinas',
    'SVBM' => 'Barquisimeto',
    'SVCL' => 'Calabozo',
    'SVMI' => 'Caracas / Maiquetia Aerop. Intl. Simon Bolivar',
    'SVCB' => 'Ciudad Bolivar',
    'SVCR' => 'Coro',
    'SVCU' => 'Cumana',
    'SVVG' => 'El Vigia / Perez Alph',
    'SVGU' => 'Guanare',
    'SVGD' => 'Guasdualito',
    'SVMC' => 'Maracaibo-La Chinita',
    'SVBS' => 'Maracay-B. A. Sucre',
    'SVMG' => 'Margarita / Del Carib',
    'SVMT' => 'Maturin',
    'SVMN' => 'Mene Grande',
    'SVMD' => 'Merida',
    'SVJC' => 'Paraguana / Josefa',
    'SVPM' => 'Paramillo Private',
    'SVPC' => 'Pto. Cabello',
    'SVPA' => 'Puerto Ayacucho',
    'SVSA' => 'San Antonio Del Tachira',
    'SVSR' => 'San Fernando De Apure',
    'SVJM' => 'San Juan De Los Morros',
    'SVSZ' => 'Santa Barbara Zulia',
    'SVSO' => 'Sto. Domingo',
    'SVVA' => 'Valencia',
    'SVVL' => 'Valera',
  );
  
  $icao_codes['Vietnam'] = array(
    'VVDN' => 'Da Nang',
    'VVNB' => 'Ha Noi',
    'VVTS' => 'Ho Chi Minh',
  );
  
  $icao_codes['Yemen'] = array(
    'OYAA' => 'Aden',
    'OYAT' => 'Ataq',
    'OYHD' => 'Hodeidah',
    'OYMB' => 'Marib',
    'OYSH' => 'Sa\'Ada / Sadah',
    'OYSN' => 'Sana\'A',
    'OYSY' => 'Sayun',
    'OYSQ' => 'Socotra',
    'OYTZ' => 'Taiz',
  );
  
  $icao_codes['Zambia'] = array(
    'FLLI' => 'Livingstone',
    'FLLS' => 'Lusaka International Airport',
    'FLMF' => 'Mfuwe',
    'FLND' => 'Ndola',
  );
  
  $icao_codes['Zimbabwe'] = array(
    'FVCZ' => 'Buffalo Range',
    'FVBU' => 'Bulawayo Airport',
    'FVTL' => 'Gweru',
    'FVHA' => 'Harare Kutsaga',
    'FVMV' => 'Masvingo',
  );
  
  return $icao_codes;
}
